import{cv as a0,cw as u0,cx as Kn,cy as n0}from"./vendor-main-DSi3UDf9.js";var rc={exports:{}},Su={};/**
 * @license React
 * react-jsx-runtime.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var rd;function i0(){if(rd)return Su;rd=1;var D=Symbol.for("react.transitional.element"),K=Symbol.for("react.fragment");function Z(h,F,Y){var j=null;if(Y!==void 0&&(j=""+Y),F.key!==void 0&&(j=""+F.key),"key"in F){Y={};for(var J in F)J!=="key"&&(Y[J]=F[J])}else Y=F;return F=Y.ref,{$$typeof:D,type:h,key:j,ref:F!==void 0?F:null,props:Y}}return Su.Fragment=K,Su.jsx=Z,Su.jsxs=Z,Su}var sd;function f0(){return sd||(sd=1,rc.exports=i0()),rc.exports}var S0=f0(),sc={exports:{}},nt={};/**
 * @license React
 * react.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var od;function c0(){if(od)return nt;od=1;var D=Symbol.for("react.transitional.element"),K=Symbol.for("react.portal"),Z=Symbol.for("react.fragment"),h=Symbol.for("react.strict_mode"),F=Symbol.for("react.profiler"),Y=Symbol.for("react.consumer"),j=Symbol.for("react.context"),J=Symbol.for("react.forward_ref"),U=Symbol.for("react.suspense"),S=Symbol.for("react.memo"),H=Symbol.for("react.lazy"),B=Symbol.iterator;function L(o){return o===null||typeof o!="object"?null:(o=B&&o[B]||o["@@iterator"],typeof o=="function"?o:null)}var W={isMounted:function(){return!1},enqueueForceUpdate:function(){},enqueueReplaceState:function(){},enqueueSetState:function(){}},tt=Object.assign,V={};function x(o,N,G){this.props=o,this.context=N,this.refs=V,this.updater=G||W}x.prototype.isReactComponent={},x.prototype.setState=function(o,N){if(typeof o!="object"&&typeof o!="function"&&o!=null)throw Error("takes an object of state variables to update or a function which returns an object of state variables.");this.updater.enqueueSetState(this,o,N,"setState")},x.prototype.forceUpdate=function(o){this.updater.enqueueForceUpdate(this,o,"forceUpdate")};function _(){}_.prototype=x.prototype;function y(o,N,G){this.props=o,this.context=N,this.refs=V,this.updater=G||W}var T=y.prototype=new _;T.constructor=y,tt(T,x.prototype),T.isPureReactComponent=!0;var E=Array.isArray,v={H:null,A:null,T:null,S:null,V:null},p=Object.prototype.hasOwnProperty;function s(o,N,G,X,lt,vt){return G=vt.ref,{$$typeof:D,type:o,key:N,ref:G!==void 0?G:null,props:vt}}function z(o,N){return s(o.type,N,void 0,void 0,void 0,o.props)}function q(o){return typeof o=="object"&&o!==null&&o.$$typeof===D}function ut(o){var N={"=":"=0",":":"=2"};return"$"+o.replace(/[=:]/g,function(G){return N[G]})}var P=/\/+/g;function ct(o,N){return typeof o=="object"&&o!==null&&o.key!=null?ut(""+o.key):N.toString(36)}function mt(){}function Et(o){switch(o.status){case"fulfilled":return o.value;case"rejected":throw o.reason;default:switch(typeof o.status=="string"?o.then(mt,mt):(o.status="pending",o.then(function(N){o.status==="pending"&&(o.status="fulfilled",o.value=N)},function(N){o.status==="pending"&&(o.status="rejected",o.reason=N)})),o.status){case"fulfilled":return o.value;case"rejected":throw o.reason}}throw o}function Tt(o,N,G,X,lt){var vt=typeof o;(vt==="undefined"||vt==="boolean")&&(o=null);var at=!1;if(o===null)at=!0;else switch(vt){case"bigint":case"string":case"number":at=!0;break;case"object":switch(o.$$typeof){case D:case K:at=!0;break;case H:return at=o._init,Tt(at(o._payload),N,G,X,lt)}}if(at)return lt=lt(o),at=X===""?"."+ct(o,0):X,E(lt)?(G="",at!=null&&(G=at.replace(P,"$&/")+"/"),Tt(lt,N,G,"",function(Kl){return Kl})):lt!=null&&(q(lt)&&(lt=z(lt,G+(lt.key==null||o&&o.key===lt.key?"":(""+lt.key).replace(P,"$&/")+"/")+at)),N.push(lt)),1;at=0;var tl=X===""?".":X+":";if(E(o))for(var zt=0;zt<o.length;zt++)X=o[zt],vt=tl+ct(X,zt),at+=Tt(X,N,G,vt,lt);else if(zt=L(o),typeof zt=="function")for(o=zt.call(o),zt=0;!(X=o.next()).done;)X=X.value,vt=tl+ct(X,zt++),at+=Tt(X,N,G,vt,lt);else if(vt==="object"){if(typeof o.then=="function")return Tt(Et(o),N,G,X,lt);throw N=String(o),Error("Objects are not valid as a React child (found: "+(N==="[object Object]"?"object with keys {"+Object.keys(o).join(", ")+"}":N)+"). If you meant to render a collection of children, use an array instead.")}return at}function C(o,N,G){if(o==null)return o;var X=[],lt=0;return Tt(o,X,"","",function(vt){return N.call(G,vt,lt++)}),X}function et(o){if(o._status===-1){var N=o._result;N=N(),N.then(function(G){(o._status===0||o._status===-1)&&(o._status=1,o._result=G)},function(G){(o._status===0||o._status===-1)&&(o._status=2,o._result=G)}),o._status===-1&&(o._status=0,o._result=N)}if(o._status===1)return o._result.default;throw o._result}var xt=typeof reportError=="function"?reportError:function(o){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var N=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof o=="object"&&o!==null&&typeof o.message=="string"?String(o.message):String(o),error:o});if(!window.dispatchEvent(N))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",o);return}console.error(o)};function Sl(){}return nt.Children={map:C,forEach:function(o,N,G){C(o,function(){N.apply(this,arguments)},G)},count:function(o){var N=0;return C(o,function(){N++}),N},toArray:function(o){return C(o,function(N){return N})||[]},only:function(o){if(!q(o))throw Error("React.Children.only expected to receive a single React element child.");return o}},nt.Component=x,nt.Fragment=Z,nt.Profiler=F,nt.PureComponent=y,nt.StrictMode=h,nt.Suspense=U,nt.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=v,nt.__COMPILER_RUNTIME={__proto__:null,c:function(o){return v.H.useMemoCache(o)}},nt.cache=function(o){return function(){return o.apply(null,arguments)}},nt.cloneElement=function(o,N,G){if(o==null)throw Error("The argument must be a React element, but you passed "+o+".");var X=tt({},o.props),lt=o.key,vt=void 0;if(N!=null)for(at in N.ref!==void 0&&(vt=void 0),N.key!==void 0&&(lt=""+N.key),N)!p.call(N,at)||at==="key"||at==="__self"||at==="__source"||at==="ref"&&N.ref===void 0||(X[at]=N[at]);var at=arguments.length-2;if(at===1)X.children=G;else if(1<at){for(var tl=Array(at),zt=0;zt<at;zt++)tl[zt]=arguments[zt+2];X.children=tl}return s(o.type,lt,void 0,void 0,vt,X)},nt.createContext=function(o){return o={$$typeof:j,_currentValue:o,_currentValue2:o,_threadCount:0,Provider:null,Consumer:null},o.Provider=o,o.Consumer={$$typeof:Y,_context:o},o},nt.createElement=function(o,N,G){var X,lt={},vt=null;if(N!=null)for(X in N.key!==void 0&&(vt=""+N.key),N)p.call(N,X)&&X!=="key"&&X!=="__self"&&X!=="__source"&&(lt[X]=N[X]);var at=arguments.length-2;if(at===1)lt.children=G;else if(1<at){for(var tl=Array(at),zt=0;zt<at;zt++)tl[zt]=arguments[zt+2];lt.children=tl}if(o&&o.defaultProps)for(X in at=o.defaultProps,at)lt[X]===void 0&&(lt[X]=at[X]);return s(o,vt,void 0,void 0,null,lt)},nt.createRef=function(){return{current:null}},nt.forwardRef=function(o){return{$$typeof:J,render:o}},nt.isValidElement=q,nt.lazy=function(o){return{$$typeof:H,_payload:{_status:-1,_result:o},_init:et}},nt.memo=function(o,N){return{$$typeof:S,type:o,compare:N===void 0?null:N}},nt.startTransition=function(o){var N=v.T,G={};v.T=G;try{var X=o(),lt=v.S;lt!==null&&lt(G,X),typeof X=="object"&&X!==null&&typeof X.then=="function"&&X.then(Sl,xt)}catch(vt){xt(vt)}finally{v.T=N}},nt.unstable_useCacheRefresh=function(){return v.H.useCacheRefresh()},nt.use=function(o){return v.H.use(o)},nt.useActionState=function(o,N,G){return v.H.useActionState(o,N,G)},nt.useCallback=function(o,N){return v.H.useCallback(o,N)},nt.useContext=function(o){return v.H.useContext(o)},nt.useDebugValue=function(){},nt.useDeferredValue=function(o,N){return v.H.useDeferredValue(o,N)},nt.useEffect=function(o,N,G){var X=v.H;if(typeof G=="function")throw Error("useEffect CRUD overload is not enabled in this build of React.");return X.useEffect(o,N)},nt.useId=function(){return v.H.useId()},nt.useImperativeHandle=function(o,N,G){return v.H.useImperativeHandle(o,N,G)},nt.useInsertionEffect=function(o,N){return v.H.useInsertionEffect(o,N)},nt.useLayoutEffect=function(o,N){return v.H.useLayoutEffect(o,N)},nt.useMemo=function(o,N){return v.H.useMemo(o,N)},nt.useOptimistic=function(o,N){return v.H.useOptimistic(o,N)},nt.useReducer=function(o,N,G){return v.H.useReducer(o,N,G)},nt.useRef=function(o){return v.H.useRef(o)},nt.useState=function(o){return v.H.useState(o)},nt.useSyncExternalStore=function(o,N,G){return v.H.useSyncExternalStore(o,N,G)},nt.useTransition=function(){return v.H.useTransition()},nt.version="19.1.1",nt}var dd;function pe(){return dd||(dd=1,sc.exports=c0()),sc.exports}var r0=pe();const b0=a0(r0);var oc={exports:{}},bu={},dc={exports:{}},Jt={};/**
 * @license React
 * react-dom.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var hd;function s0(){if(hd)return Jt;hd=1;var D=pe();function K(U){var S="https://react.dev/errors/"+U;if(1<arguments.length){S+="?args[]="+encodeURIComponent(arguments[1]);for(var H=2;H<arguments.length;H++)S+="&args[]="+encodeURIComponent(arguments[H])}return"Minified React error #"+U+"; visit "+S+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function Z(){}var h={d:{f:Z,r:function(){throw Error(K(522))},D:Z,C:Z,L:Z,m:Z,X:Z,S:Z,M:Z},p:0,findDOMNode:null},F=Symbol.for("react.portal");function Y(U,S,H){var B=3<arguments.length&&arguments[3]!==void 0?arguments[3]:null;return{$$typeof:F,key:B==null?null:""+B,children:U,containerInfo:S,implementation:H}}var j=D.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE;function J(U,S){if(U==="font")return"";if(typeof S=="string")return S==="use-credentials"?S:""}return Jt.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=h,Jt.createPortal=function(U,S){var H=2<arguments.length&&arguments[2]!==void 0?arguments[2]:null;if(!S||S.nodeType!==1&&S.nodeType!==9&&S.nodeType!==11)throw Error(K(299));return Y(U,S,null,H)},Jt.flushSync=function(U){var S=j.T,H=h.p;try{if(j.T=null,h.p=2,U)return U()}finally{j.T=S,h.p=H,h.d.f()}},Jt.preconnect=function(U,S){typeof U=="string"&&(S?(S=S.crossOrigin,S=typeof S=="string"?S==="use-credentials"?S:"":void 0):S=null,h.d.C(U,S))},Jt.prefetchDNS=function(U){typeof U=="string"&&h.d.D(U)},Jt.preinit=function(U,S){if(typeof U=="string"&&S&&typeof S.as=="string"){var H=S.as,B=J(H,S.crossOrigin),L=typeof S.integrity=="string"?S.integrity:void 0,W=typeof S.fetchPriority=="string"?S.fetchPriority:void 0;H==="style"?h.d.S(U,typeof S.precedence=="string"?S.precedence:void 0,{crossOrigin:B,integrity:L,fetchPriority:W}):H==="script"&&h.d.X(U,{crossOrigin:B,integrity:L,fetchPriority:W,nonce:typeof S.nonce=="string"?S.nonce:void 0})}},Jt.preinitModule=function(U,S){if(typeof U=="string")if(typeof S=="object"&&S!==null){if(S.as==null||S.as==="script"){var H=J(S.as,S.crossOrigin);h.d.M(U,{crossOrigin:H,integrity:typeof S.integrity=="string"?S.integrity:void 0,nonce:typeof S.nonce=="string"?S.nonce:void 0})}}else S==null&&h.d.M(U)},Jt.preload=function(U,S){if(typeof U=="string"&&typeof S=="object"&&S!==null&&typeof S.as=="string"){var H=S.as,B=J(H,S.crossOrigin);h.d.L(U,H,{crossOrigin:B,integrity:typeof S.integrity=="string"?S.integrity:void 0,nonce:typeof S.nonce=="string"?S.nonce:void 0,type:typeof S.type=="string"?S.type:void 0,fetchPriority:typeof S.fetchPriority=="string"?S.fetchPriority:void 0,referrerPolicy:typeof S.referrerPolicy=="string"?S.referrerPolicy:void 0,imageSrcSet:typeof S.imageSrcSet=="string"?S.imageSrcSet:void 0,imageSizes:typeof S.imageSizes=="string"?S.imageSizes:void 0,media:typeof S.media=="string"?S.media:void 0})}},Jt.preloadModule=function(U,S){if(typeof U=="string")if(S){var H=J(S.as,S.crossOrigin);h.d.m(U,{as:typeof S.as=="string"&&S.as!=="script"?S.as:void 0,crossOrigin:H,integrity:typeof S.integrity=="string"?S.integrity:void 0})}else h.d.m(U)},Jt.requestFormReset=function(U){h.d.r(U)},Jt.unstable_batchedUpdates=function(U,S){return U(S)},Jt.useFormState=function(U,S,H){return j.H.useFormState(U,S,H)},Jt.useFormStatus=function(){return j.H.useHostTransitionStatus()},Jt.version="19.1.1",Jt}var vd;function vc(){if(vd)return dc.exports;vd=1;function D(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(D)}catch(K){console.error(K)}}return D(),dc.exports=s0(),dc.exports}/**
 * @license React
 * react-dom-client.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var yd;function o0(){if(yd)return bu;yd=1;var D=u0(),K=pe(),Z=vc();function h(t){var l="https://react.dev/errors/"+t;if(1<arguments.length){l+="?args[]="+encodeURIComponent(arguments[1]);for(var e=2;e<arguments.length;e++)l+="&args[]="+encodeURIComponent(arguments[e])}return"Minified React error #"+t+"; visit "+l+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function F(t){return!(!t||t.nodeType!==1&&t.nodeType!==9&&t.nodeType!==11)}function Y(t){var l=t,e=t;if(t.alternate)for(;l.return;)l=l.return;else{t=l;do l=t,(l.flags&4098)!==0&&(e=l.return),t=l.return;while(t)}return l.tag===3?e:null}function j(t){if(t.tag===13){var l=t.memoizedState;if(l===null&&(t=t.alternate,t!==null&&(l=t.memoizedState)),l!==null)return l.dehydrated}return null}function J(t){if(Y(t)!==t)throw Error(h(188))}function U(t){var l=t.alternate;if(!l){if(l=Y(t),l===null)throw Error(h(188));return l!==t?null:t}for(var e=t,a=l;;){var u=e.return;if(u===null)break;var n=u.alternate;if(n===null){if(a=u.return,a!==null){e=a;continue}break}if(u.child===n.child){for(n=u.child;n;){if(n===e)return J(u),t;if(n===a)return J(u),l;n=n.sibling}throw Error(h(188))}if(e.return!==a.return)e=u,a=n;else{for(var i=!1,f=u.child;f;){if(f===e){i=!0,e=u,a=n;break}if(f===a){i=!0,a=u,e=n;break}f=f.sibling}if(!i){for(f=n.child;f;){if(f===e){i=!0,e=n,a=u;break}if(f===a){i=!0,a=n,e=u;break}f=f.sibling}if(!i)throw Error(h(189))}}if(e.alternate!==a)throw Error(h(190))}if(e.tag!==3)throw Error(h(188));return e.stateNode.current===e?t:l}function S(t){var l=t.tag;if(l===5||l===26||l===27||l===6)return t;for(t=t.child;t!==null;){if(l=S(t),l!==null)return l;t=t.sibling}return null}var H=Object.assign,B=Symbol.for("react.element"),L=Symbol.for("react.transitional.element"),W=Symbol.for("react.portal"),tt=Symbol.for("react.fragment"),V=Symbol.for("react.strict_mode"),x=Symbol.for("react.profiler"),_=Symbol.for("react.provider"),y=Symbol.for("react.consumer"),T=Symbol.for("react.context"),E=Symbol.for("react.forward_ref"),v=Symbol.for("react.suspense"),p=Symbol.for("react.suspense_list"),s=Symbol.for("react.memo"),z=Symbol.for("react.lazy"),q=Symbol.for("react.activity"),ut=Symbol.for("react.memo_cache_sentinel"),P=Symbol.iterator;function ct(t){return t===null||typeof t!="object"?null:(t=P&&t[P]||t["@@iterator"],typeof t=="function"?t:null)}var mt=Symbol.for("react.client.reference");function Et(t){if(t==null)return null;if(typeof t=="function")return t.$$typeof===mt?null:t.displayName||t.name||null;if(typeof t=="string")return t;switch(t){case tt:return"Fragment";case x:return"Profiler";case V:return"StrictMode";case v:return"Suspense";case p:return"SuspenseList";case q:return"Activity"}if(typeof t=="object")switch(t.$$typeof){case W:return"Portal";case T:return(t.displayName||"Context")+".Provider";case y:return(t._context.displayName||"Context")+".Consumer";case E:var l=t.render;return t=t.displayName,t||(t=l.displayName||l.name||"",t=t!==""?"ForwardRef("+t+")":"ForwardRef"),t;case s:return l=t.displayName||null,l!==null?l:Et(t.type)||"Memo";case z:l=t._payload,t=t._init;try{return Et(t(l))}catch{}}return null}var Tt=Array.isArray,C=K.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,et=Z.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,xt={pending:!1,data:null,method:null,action:null},Sl=[],o=-1;function N(t){return{current:t}}function G(t){0>o||(t.current=Sl[o],Sl[o]=null,o--)}function X(t,l){o++,Sl[o]=t.current,t.current=l}var lt=N(null),vt=N(null),at=N(null),tl=N(null);function zt(t,l){switch(X(at,l),X(vt,t),X(lt,null),l.nodeType){case 9:case 11:t=(t=l.documentElement)&&(t=t.namespaceURI)?Co(t):0;break;default:if(t=l.tagName,l=l.namespaceURI)l=Co(l),t=Xo(l,t);else switch(t){case"svg":t=1;break;case"math":t=2;break;default:t=0}}G(lt),X(lt,t)}function Kl(){G(lt),G(vt),G(at)}function Jn(t){t.memoizedState!==null&&X(tl,t);var l=lt.current,e=Xo(l,t.type);l!==e&&(X(vt,t),X(lt,e))}function Mu(t){vt.current===t&&(G(lt),G(vt)),tl.current===t&&(G(tl),vu._currentValue=xt)}var Wn=Object.prototype.hasOwnProperty,$n=D.unstable_scheduleCallback,kn=D.unstable_cancelCallback,Yd=D.unstable_shouldYield,Bd=D.unstable_requestPaint,Dl=D.unstable_now,Cd=D.unstable_getCurrentPriorityLevel,gc=D.unstable_ImmediatePriority,mc=D.unstable_UserBlockingPriority,Au=D.unstable_NormalPriority,Xd=D.unstable_LowPriority,pc=D.unstable_IdlePriority,jd=D.log,Gd=D.unstable_setDisableYieldValue,Ta=null,ll=null;function wl(t){if(typeof jd=="function"&&Gd(t),ll&&typeof ll.setStrictMode=="function")try{ll.setStrictMode(Ta,t)}catch{}}var el=Math.clz32?Math.clz32:Vd,Qd=Math.log,Zd=Math.LN2;function Vd(t){return t>>>=0,t===0?32:31-(Qd(t)/Zd|0)|0}var Ru=256,Uu=4194304;function Se(t){var l=t&42;if(l!==0)return l;switch(t&-t){case 1:return 1;case 2:return 2;case 4:return 4;case 8:return 8;case 16:return 16;case 32:return 32;case 64:return 64;case 128:return 128;case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:return t&4194048;case 4194304:case 8388608:case 16777216:case 33554432:return t&62914560;case 67108864:return 67108864;case 134217728:return 134217728;case 268435456:return 268435456;case 536870912:return 536870912;case 1073741824:return 0;default:return t}}function Nu(t,l,e){var a=t.pendingLanes;if(a===0)return 0;var u=0,n=t.suspendedLanes,i=t.pingedLanes;t=t.warmLanes;var f=a&134217727;return f!==0?(a=f&~n,a!==0?u=Se(a):(i&=f,i!==0?u=Se(i):e||(e=f&~t,e!==0&&(u=Se(e))))):(f=a&~n,f!==0?u=Se(f):i!==0?u=Se(i):e||(e=a&~t,e!==0&&(u=Se(e)))),u===0?0:l!==0&&l!==u&&(l&n)===0&&(n=u&-u,e=l&-l,n>=e||n===32&&(e&4194048)!==0)?l:u}function Da(t,l){return(t.pendingLanes&~(t.suspendedLanes&~t.pingedLanes)&l)===0}function Ld(t,l){switch(t){case 1:case 2:case 4:case 8:case 64:return l+250;case 16:case 32:case 128:case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:return l+5e3;case 4194304:case 8388608:case 16777216:case 33554432:return-1;case 67108864:case 134217728:case 268435456:case 536870912:case 1073741824:return-1;default:return-1}}function Sc(){var t=Ru;return Ru<<=1,(Ru&4194048)===0&&(Ru=256),t}function bc(){var t=Uu;return Uu<<=1,(Uu&62914560)===0&&(Uu=4194304),t}function Fn(t){for(var l=[],e=0;31>e;e++)l.push(t);return l}function Ea(t,l){t.pendingLanes|=l,l!==268435456&&(t.suspendedLanes=0,t.pingedLanes=0,t.warmLanes=0)}function Kd(t,l,e,a,u,n){var i=t.pendingLanes;t.pendingLanes=e,t.suspendedLanes=0,t.pingedLanes=0,t.warmLanes=0,t.expiredLanes&=e,t.entangledLanes&=e,t.errorRecoveryDisabledLanes&=e,t.shellSuspendCounter=0;var f=t.entanglements,c=t.expirationTimes,m=t.hiddenUpdates;for(e=i&~e;0<e;){var M=31-el(e),R=1<<M;f[M]=0,c[M]=-1;var b=m[M];if(b!==null)for(m[M]=null,M=0;M<b.length;M++){var O=b[M];O!==null&&(O.lane&=-536870913)}e&=~R}a!==0&&Oc(t,a,0),n!==0&&u===0&&t.tag!==0&&(t.suspendedLanes|=n&~(i&~l))}function Oc(t,l,e){t.pendingLanes|=l,t.suspendedLanes&=~l;var a=31-el(l);t.entangledLanes|=l,t.entanglements[a]=t.entanglements[a]|1073741824|e&4194090}function Tc(t,l){var e=t.entangledLanes|=l;for(t=t.entanglements;e;){var a=31-el(e),u=1<<a;u&l|t[a]&l&&(t[a]|=l),e&=~u}}function Pn(t){switch(t){case 2:t=1;break;case 8:t=4;break;case 32:t=16;break;case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:case 4194304:case 8388608:case 16777216:case 33554432:t=128;break;case 268435456:t=134217728;break;default:t=0}return t}function In(t){return t&=-t,2<t?8<t?(t&134217727)!==0?32:268435456:8:2}function Dc(){var t=et.p;return t!==0?t:(t=window.event,t===void 0?32:ad(t.type))}function wd(t,l){var e=et.p;try{return et.p=t,l()}finally{et.p=e}}var Jl=Math.random().toString(36).slice(2),Kt="__reactFiber$"+Jl,$t="__reactProps$"+Jl,Ce="__reactContainer$"+Jl,ti="__reactEvents$"+Jl,Jd="__reactListeners$"+Jl,Wd="__reactHandles$"+Jl,Ec="__reactResources$"+Jl,za="__reactMarker$"+Jl;function li(t){delete t[Kt],delete t[$t],delete t[ti],delete t[Jd],delete t[Wd]}function Xe(t){var l=t[Kt];if(l)return l;for(var e=t.parentNode;e;){if(l=e[Ce]||e[Kt]){if(e=l.alternate,l.child!==null||e!==null&&e.child!==null)for(t=Zo(t);t!==null;){if(e=t[Kt])return e;t=Zo(t)}return l}t=e,e=t.parentNode}return null}function je(t){if(t=t[Kt]||t[Ce]){var l=t.tag;if(l===5||l===6||l===13||l===26||l===27||l===3)return t}return null}function _a(t){var l=t.tag;if(l===5||l===26||l===27||l===6)return t.stateNode;throw Error(h(33))}function Ge(t){var l=t[Ec];return l||(l=t[Ec]={hoistableStyles:new Map,hoistableScripts:new Map}),l}function Xt(t){t[za]=!0}var zc=new Set,_c={};function be(t,l){Qe(t,l),Qe(t+"Capture",l)}function Qe(t,l){for(_c[t]=l,t=0;t<l.length;t++)zc.add(l[t])}var $d=RegExp("^[:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD][:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD\\-.0-9\\u00B7\\u0300-\\u036F\\u203F-\\u2040]*$"),Mc={},Ac={};function kd(t){return Wn.call(Ac,t)?!0:Wn.call(Mc,t)?!1:$d.test(t)?Ac[t]=!0:(Mc[t]=!0,!1)}function Hu(t,l,e){if(kd(l))if(e===null)t.removeAttribute(l);else{switch(typeof e){case"undefined":case"function":case"symbol":t.removeAttribute(l);return;case"boolean":var a=l.toLowerCase().slice(0,5);if(a!=="data-"&&a!=="aria-"){t.removeAttribute(l);return}}t.setAttribute(l,""+e)}}function xu(t,l,e){if(e===null)t.removeAttribute(l);else{switch(typeof e){case"undefined":case"function":case"symbol":case"boolean":t.removeAttribute(l);return}t.setAttribute(l,""+e)}}function Ul(t,l,e,a){if(a===null)t.removeAttribute(e);else{switch(typeof a){case"undefined":case"function":case"symbol":case"boolean":t.removeAttribute(e);return}t.setAttributeNS(l,e,""+a)}}var ei,Rc;function Ze(t){if(ei===void 0)try{throw Error()}catch(e){var l=e.stack.trim().match(/\n( *(at )?)/);ei=l&&l[1]||"",Rc=-1<e.stack.indexOf(`
    at`)?" (<anonymous>)":-1<e.stack.indexOf("@")?"@unknown:0:0":""}return`
`+ei+t+Rc}var ai=!1;function ui(t,l){if(!t||ai)return"";ai=!0;var e=Error.prepareStackTrace;Error.prepareStackTrace=void 0;try{var a={DetermineComponentFrameRoot:function(){try{if(l){var R=function(){throw Error()};if(Object.defineProperty(R.prototype,"props",{set:function(){throw Error()}}),typeof Reflect=="object"&&Reflect.construct){try{Reflect.construct(R,[])}catch(O){var b=O}Reflect.construct(t,[],R)}else{try{R.call()}catch(O){b=O}t.call(R.prototype)}}else{try{throw Error()}catch(O){b=O}(R=t())&&typeof R.catch=="function"&&R.catch(function(){})}}catch(O){if(O&&b&&typeof O.stack=="string")return[O.stack,b.stack]}return[null,null]}};a.DetermineComponentFrameRoot.displayName="DetermineComponentFrameRoot";var u=Object.getOwnPropertyDescriptor(a.DetermineComponentFrameRoot,"name");u&&u.configurable&&Object.defineProperty(a.DetermineComponentFrameRoot,"name",{value:"DetermineComponentFrameRoot"});var n=a.DetermineComponentFrameRoot(),i=n[0],f=n[1];if(i&&f){var c=i.split(`
`),m=f.split(`
`);for(u=a=0;a<c.length&&!c[a].includes("DetermineComponentFrameRoot");)a++;for(;u<m.length&&!m[u].includes("DetermineComponentFrameRoot");)u++;if(a===c.length||u===m.length)for(a=c.length-1,u=m.length-1;1<=a&&0<=u&&c[a]!==m[u];)u--;for(;1<=a&&0<=u;a--,u--)if(c[a]!==m[u]){if(a!==1||u!==1)do if(a--,u--,0>u||c[a]!==m[u]){var M=`
`+c[a].replace(" at new "," at ");return t.displayName&&M.includes("<anonymous>")&&(M=M.replace("<anonymous>",t.displayName)),M}while(1<=a&&0<=u);break}}}finally{ai=!1,Error.prepareStackTrace=e}return(e=t?t.displayName||t.name:"")?Ze(e):""}function Fd(t){switch(t.tag){case 26:case 27:case 5:return Ze(t.type);case 16:return Ze("Lazy");case 13:return Ze("Suspense");case 19:return Ze("SuspenseList");case 0:case 15:return ui(t.type,!1);case 11:return ui(t.type.render,!1);case 1:return ui(t.type,!0);case 31:return Ze("Activity");default:return""}}function Uc(t){try{var l="";do l+=Fd(t),t=t.return;while(t);return l}catch(e){return`
Error generating stack: `+e.message+`
`+e.stack}}function sl(t){switch(typeof t){case"bigint":case"boolean":case"number":case"string":case"undefined":return t;case"object":return t;default:return""}}function Nc(t){var l=t.type;return(t=t.nodeName)&&t.toLowerCase()==="input"&&(l==="checkbox"||l==="radio")}function Pd(t){var l=Nc(t)?"checked":"value",e=Object.getOwnPropertyDescriptor(t.constructor.prototype,l),a=""+t[l];if(!t.hasOwnProperty(l)&&typeof e<"u"&&typeof e.get=="function"&&typeof e.set=="function"){var u=e.get,n=e.set;return Object.defineProperty(t,l,{configurable:!0,get:function(){return u.call(this)},set:function(i){a=""+i,n.call(this,i)}}),Object.defineProperty(t,l,{enumerable:e.enumerable}),{getValue:function(){return a},setValue:function(i){a=""+i},stopTracking:function(){t._valueTracker=null,delete t[l]}}}}function qu(t){t._valueTracker||(t._valueTracker=Pd(t))}function Hc(t){if(!t)return!1;var l=t._valueTracker;if(!l)return!0;var e=l.getValue(),a="";return t&&(a=Nc(t)?t.checked?"true":"false":t.value),t=a,t!==e?(l.setValue(t),!0):!1}function Yu(t){if(t=t||(typeof document<"u"?document:void 0),typeof t>"u")return null;try{return t.activeElement||t.body}catch{return t.body}}var Id=/[\n"\\]/g;function ol(t){return t.replace(Id,function(l){return"\\"+l.charCodeAt(0).toString(16)+" "})}function ni(t,l,e,a,u,n,i,f){t.name="",i!=null&&typeof i!="function"&&typeof i!="symbol"&&typeof i!="boolean"?t.type=i:t.removeAttribute("type"),l!=null?i==="number"?(l===0&&t.value===""||t.value!=l)&&(t.value=""+sl(l)):t.value!==""+sl(l)&&(t.value=""+sl(l)):i!=="submit"&&i!=="reset"||t.removeAttribute("value"),l!=null?ii(t,i,sl(l)):e!=null?ii(t,i,sl(e)):a!=null&&t.removeAttribute("value"),u==null&&n!=null&&(t.defaultChecked=!!n),u!=null&&(t.checked=u&&typeof u!="function"&&typeof u!="symbol"),f!=null&&typeof f!="function"&&typeof f!="symbol"&&typeof f!="boolean"?t.name=""+sl(f):t.removeAttribute("name")}function xc(t,l,e,a,u,n,i,f){if(n!=null&&typeof n!="function"&&typeof n!="symbol"&&typeof n!="boolean"&&(t.type=n),l!=null||e!=null){if(!(n!=="submit"&&n!=="reset"||l!=null))return;e=e!=null?""+sl(e):"",l=l!=null?""+sl(l):e,f||l===t.value||(t.value=l),t.defaultValue=l}a=a??u,a=typeof a!="function"&&typeof a!="symbol"&&!!a,t.checked=f?t.checked:!!a,t.defaultChecked=!!a,i!=null&&typeof i!="function"&&typeof i!="symbol"&&typeof i!="boolean"&&(t.name=i)}function ii(t,l,e){l==="number"&&Yu(t.ownerDocument)===t||t.defaultValue===""+e||(t.defaultValue=""+e)}function Ve(t,l,e,a){if(t=t.options,l){l={};for(var u=0;u<e.length;u++)l["$"+e[u]]=!0;for(e=0;e<t.length;e++)u=l.hasOwnProperty("$"+t[e].value),t[e].selected!==u&&(t[e].selected=u),u&&a&&(t[e].defaultSelected=!0)}else{for(e=""+sl(e),l=null,u=0;u<t.length;u++){if(t[u].value===e){t[u].selected=!0,a&&(t[u].defaultSelected=!0);return}l!==null||t[u].disabled||(l=t[u])}l!==null&&(l.selected=!0)}}function qc(t,l,e){if(l!=null&&(l=""+sl(l),l!==t.value&&(t.value=l),e==null)){t.defaultValue!==l&&(t.defaultValue=l);return}t.defaultValue=e!=null?""+sl(e):""}function Yc(t,l,e,a){if(l==null){if(a!=null){if(e!=null)throw Error(h(92));if(Tt(a)){if(1<a.length)throw Error(h(93));a=a[0]}e=a}e==null&&(e=""),l=e}e=sl(l),t.defaultValue=e,a=t.textContent,a===e&&a!==""&&a!==null&&(t.value=a)}function Le(t,l){if(l){var e=t.firstChild;if(e&&e===t.lastChild&&e.nodeType===3){e.nodeValue=l;return}}t.textContent=l}var th=new Set("animationIterationCount aspectRatio borderImageOutset borderImageSlice borderImageWidth boxFlex boxFlexGroup boxOrdinalGroup columnCount columns flex flexGrow flexPositive flexShrink flexNegative flexOrder gridArea gridRow gridRowEnd gridRowSpan gridRowStart gridColumn gridColumnEnd gridColumnSpan gridColumnStart fontWeight lineClamp lineHeight opacity order orphans scale tabSize widows zIndex zoom fillOpacity floodOpacity stopOpacity strokeDasharray strokeDashoffset strokeMiterlimit strokeOpacity strokeWidth MozAnimationIterationCount MozBoxFlex MozBoxFlexGroup MozLineClamp msAnimationIterationCount msFlex msZoom msFlexGrow msFlexNegative msFlexOrder msFlexPositive msFlexShrink msGridColumn msGridColumnSpan msGridRow msGridRowSpan WebkitAnimationIterationCount WebkitBoxFlex WebKitBoxFlexGroup WebkitBoxOrdinalGroup WebkitColumnCount WebkitColumns WebkitFlex WebkitFlexGrow WebkitFlexPositive WebkitFlexShrink WebkitLineClamp".split(" "));function Bc(t,l,e){var a=l.indexOf("--")===0;e==null||typeof e=="boolean"||e===""?a?t.setProperty(l,""):l==="float"?t.cssFloat="":t[l]="":a?t.setProperty(l,e):typeof e!="number"||e===0||th.has(l)?l==="float"?t.cssFloat=e:t[l]=(""+e).trim():t[l]=e+"px"}function Cc(t,l,e){if(l!=null&&typeof l!="object")throw Error(h(62));if(t=t.style,e!=null){for(var a in e)!e.hasOwnProperty(a)||l!=null&&l.hasOwnProperty(a)||(a.indexOf("--")===0?t.setProperty(a,""):a==="float"?t.cssFloat="":t[a]="");for(var u in l)a=l[u],l.hasOwnProperty(u)&&e[u]!==a&&Bc(t,u,a)}else for(var n in l)l.hasOwnProperty(n)&&Bc(t,n,l[n])}function fi(t){if(t.indexOf("-")===-1)return!1;switch(t){case"annotation-xml":case"color-profile":case"font-face":case"font-face-src":case"font-face-uri":case"font-face-format":case"font-face-name":case"missing-glyph":return!1;default:return!0}}var lh=new Map([["acceptCharset","accept-charset"],["htmlFor","for"],["httpEquiv","http-equiv"],["crossOrigin","crossorigin"],["accentHeight","accent-height"],["alignmentBaseline","alignment-baseline"],["arabicForm","arabic-form"],["baselineShift","baseline-shift"],["capHeight","cap-height"],["clipPath","clip-path"],["clipRule","clip-rule"],["colorInterpolation","color-interpolation"],["colorInterpolationFilters","color-interpolation-filters"],["colorProfile","color-profile"],["colorRendering","color-rendering"],["dominantBaseline","dominant-baseline"],["enableBackground","enable-background"],["fillOpacity","fill-opacity"],["fillRule","fill-rule"],["floodColor","flood-color"],["floodOpacity","flood-opacity"],["fontFamily","font-family"],["fontSize","font-size"],["fontSizeAdjust","font-size-adjust"],["fontStretch","font-stretch"],["fontStyle","font-style"],["fontVariant","font-variant"],["fontWeight","font-weight"],["glyphName","glyph-name"],["glyphOrientationHorizontal","glyph-orientation-horizontal"],["glyphOrientationVertical","glyph-orientation-vertical"],["horizAdvX","horiz-adv-x"],["horizOriginX","horiz-origin-x"],["imageRendering","image-rendering"],["letterSpacing","letter-spacing"],["lightingColor","lighting-color"],["markerEnd","marker-end"],["markerMid","marker-mid"],["markerStart","marker-start"],["overlinePosition","overline-position"],["overlineThickness","overline-thickness"],["paintOrder","paint-order"],["panose-1","panose-1"],["pointerEvents","pointer-events"],["renderingIntent","rendering-intent"],["shapeRendering","shape-rendering"],["stopColor","stop-color"],["stopOpacity","stop-opacity"],["strikethroughPosition","strikethrough-position"],["strikethroughThickness","strikethrough-thickness"],["strokeDasharray","stroke-dasharray"],["strokeDashoffset","stroke-dashoffset"],["strokeLinecap","stroke-linecap"],["strokeLinejoin","stroke-linejoin"],["strokeMiterlimit","stroke-miterlimit"],["strokeOpacity","stroke-opacity"],["strokeWidth","stroke-width"],["textAnchor","text-anchor"],["textDecoration","text-decoration"],["textRendering","text-rendering"],["transformOrigin","transform-origin"],["underlinePosition","underline-position"],["underlineThickness","underline-thickness"],["unicodeBidi","unicode-bidi"],["unicodeRange","unicode-range"],["unitsPerEm","units-per-em"],["vAlphabetic","v-alphabetic"],["vHanging","v-hanging"],["vIdeographic","v-ideographic"],["vMathematical","v-mathematical"],["vectorEffect","vector-effect"],["vertAdvY","vert-adv-y"],["vertOriginX","vert-origin-x"],["vertOriginY","vert-origin-y"],["wordSpacing","word-spacing"],["writingMode","writing-mode"],["xmlnsXlink","xmlns:xlink"],["xHeight","x-height"]]),eh=/^[\u0000-\u001F ]*j[\r\n\t]*a[\r\n\t]*v[\r\n\t]*a[\r\n\t]*s[\r\n\t]*c[\r\n\t]*r[\r\n\t]*i[\r\n\t]*p[\r\n\t]*t[\r\n\t]*:/i;function Bu(t){return eh.test(""+t)?"javascript:throw new Error('React has blocked a javascript: URL as a security precaution.')":t}var ci=null;function ri(t){return t=t.target||t.srcElement||window,t.correspondingUseElement&&(t=t.correspondingUseElement),t.nodeType===3?t.parentNode:t}var Ke=null,we=null;function Xc(t){var l=je(t);if(l&&(t=l.stateNode)){var e=t[$t]||null;t:switch(t=l.stateNode,l.type){case"input":if(ni(t,e.value,e.defaultValue,e.defaultValue,e.checked,e.defaultChecked,e.type,e.name),l=e.name,e.type==="radio"&&l!=null){for(e=t;e.parentNode;)e=e.parentNode;for(e=e.querySelectorAll('input[name="'+ol(""+l)+'"][type="radio"]'),l=0;l<e.length;l++){var a=e[l];if(a!==t&&a.form===t.form){var u=a[$t]||null;if(!u)throw Error(h(90));ni(a,u.value,u.defaultValue,u.defaultValue,u.checked,u.defaultChecked,u.type,u.name)}}for(l=0;l<e.length;l++)a=e[l],a.form===t.form&&Hc(a)}break t;case"textarea":qc(t,e.value,e.defaultValue);break t;case"select":l=e.value,l!=null&&Ve(t,!!e.multiple,l,!1)}}}var si=!1;function jc(t,l,e){if(si)return t(l,e);si=!0;try{var a=t(l);return a}finally{if(si=!1,(Ke!==null||we!==null)&&(Tn(),Ke&&(l=Ke,t=we,we=Ke=null,Xc(l),t)))for(l=0;l<t.length;l++)Xc(t[l])}}function Ma(t,l){var e=t.stateNode;if(e===null)return null;var a=e[$t]||null;if(a===null)return null;e=a[l];t:switch(l){case"onClick":case"onClickCapture":case"onDoubleClick":case"onDoubleClickCapture":case"onMouseDown":case"onMouseDownCapture":case"onMouseMove":case"onMouseMoveCapture":case"onMouseUp":case"onMouseUpCapture":case"onMouseEnter":(a=!a.disabled)||(t=t.type,a=!(t==="button"||t==="input"||t==="select"||t==="textarea")),t=!a;break t;default:t=!1}if(t)return null;if(e&&typeof e!="function")throw Error(h(231,l,typeof e));return e}var Nl=!(typeof window>"u"||typeof window.document>"u"||typeof window.document.createElement>"u"),oi=!1;if(Nl)try{var Aa={};Object.defineProperty(Aa,"passive",{get:function(){oi=!0}}),window.addEventListener("test",Aa,Aa),window.removeEventListener("test",Aa,Aa)}catch{oi=!1}var Wl=null,di=null,Cu=null;function Gc(){if(Cu)return Cu;var t,l=di,e=l.length,a,u="value"in Wl?Wl.value:Wl.textContent,n=u.length;for(t=0;t<e&&l[t]===u[t];t++);var i=e-t;for(a=1;a<=i&&l[e-a]===u[n-a];a++);return Cu=u.slice(t,1<a?1-a:void 0)}function Xu(t){var l=t.keyCode;return"charCode"in t?(t=t.charCode,t===0&&l===13&&(t=13)):t=l,t===10&&(t=13),32<=t||t===13?t:0}function ju(){return!0}function Qc(){return!1}function kt(t){function l(e,a,u,n,i){this._reactName=e,this._targetInst=u,this.type=a,this.nativeEvent=n,this.target=i,this.currentTarget=null;for(var f in t)t.hasOwnProperty(f)&&(e=t[f],this[f]=e?e(n):n[f]);return this.isDefaultPrevented=(n.defaultPrevented!=null?n.defaultPrevented:n.returnValue===!1)?ju:Qc,this.isPropagationStopped=Qc,this}return H(l.prototype,{preventDefault:function(){this.defaultPrevented=!0;var e=this.nativeEvent;e&&(e.preventDefault?e.preventDefault():typeof e.returnValue!="unknown"&&(e.returnValue=!1),this.isDefaultPrevented=ju)},stopPropagation:function(){var e=this.nativeEvent;e&&(e.stopPropagation?e.stopPropagation():typeof e.cancelBubble!="unknown"&&(e.cancelBubble=!0),this.isPropagationStopped=ju)},persist:function(){},isPersistent:ju}),l}var Oe={eventPhase:0,bubbles:0,cancelable:0,timeStamp:function(t){return t.timeStamp||Date.now()},defaultPrevented:0,isTrusted:0},Gu=kt(Oe),Ra=H({},Oe,{view:0,detail:0}),ah=kt(Ra),hi,vi,Ua,Qu=H({},Ra,{screenX:0,screenY:0,clientX:0,clientY:0,pageX:0,pageY:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,getModifierState:gi,button:0,buttons:0,relatedTarget:function(t){return t.relatedTarget===void 0?t.fromElement===t.srcElement?t.toElement:t.fromElement:t.relatedTarget},movementX:function(t){return"movementX"in t?t.movementX:(t!==Ua&&(Ua&&t.type==="mousemove"?(hi=t.screenX-Ua.screenX,vi=t.screenY-Ua.screenY):vi=hi=0,Ua=t),hi)},movementY:function(t){return"movementY"in t?t.movementY:vi}}),Zc=kt(Qu),uh=H({},Qu,{dataTransfer:0}),nh=kt(uh),ih=H({},Ra,{relatedTarget:0}),yi=kt(ih),fh=H({},Oe,{animationName:0,elapsedTime:0,pseudoElement:0}),ch=kt(fh),rh=H({},Oe,{clipboardData:function(t){return"clipboardData"in t?t.clipboardData:window.clipboardData}}),sh=kt(rh),oh=H({},Oe,{data:0}),Vc=kt(oh),dh={Esc:"Escape",Spacebar:" ",Left:"ArrowLeft",Up:"ArrowUp",Right:"ArrowRight",Down:"ArrowDown",Del:"Delete",Win:"OS",Menu:"ContextMenu",Apps:"ContextMenu",Scroll:"ScrollLock",MozPrintableKey:"Unidentified"},hh={8:"Backspace",9:"Tab",12:"Clear",13:"Enter",16:"Shift",17:"Control",18:"Alt",19:"Pause",20:"CapsLock",27:"Escape",32:" ",33:"PageUp",34:"PageDown",35:"End",36:"Home",37:"ArrowLeft",38:"ArrowUp",39:"ArrowRight",40:"ArrowDown",45:"Insert",46:"Delete",112:"F1",113:"F2",114:"F3",115:"F4",116:"F5",117:"F6",118:"F7",119:"F8",120:"F9",121:"F10",122:"F11",123:"F12",144:"NumLock",145:"ScrollLock",224:"Meta"},vh={Alt:"altKey",Control:"ctrlKey",Meta:"metaKey",Shift:"shiftKey"};function yh(t){var l=this.nativeEvent;return l.getModifierState?l.getModifierState(t):(t=vh[t])?!!l[t]:!1}function gi(){return yh}var gh=H({},Ra,{key:function(t){if(t.key){var l=dh[t.key]||t.key;if(l!=="Unidentified")return l}return t.type==="keypress"?(t=Xu(t),t===13?"Enter":String.fromCharCode(t)):t.type==="keydown"||t.type==="keyup"?hh[t.keyCode]||"Unidentified":""},code:0,location:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,repeat:0,locale:0,getModifierState:gi,charCode:function(t){return t.type==="keypress"?Xu(t):0},keyCode:function(t){return t.type==="keydown"||t.type==="keyup"?t.keyCode:0},which:function(t){return t.type==="keypress"?Xu(t):t.type==="keydown"||t.type==="keyup"?t.keyCode:0}}),mh=kt(gh),ph=H({},Qu,{pointerId:0,width:0,height:0,pressure:0,tangentialPressure:0,tiltX:0,tiltY:0,twist:0,pointerType:0,isPrimary:0}),Lc=kt(ph),Sh=H({},Ra,{touches:0,targetTouches:0,changedTouches:0,altKey:0,metaKey:0,ctrlKey:0,shiftKey:0,getModifierState:gi}),bh=kt(Sh),Oh=H({},Oe,{propertyName:0,elapsedTime:0,pseudoElement:0}),Th=kt(Oh),Dh=H({},Qu,{deltaX:function(t){return"deltaX"in t?t.deltaX:"wheelDeltaX"in t?-t.wheelDeltaX:0},deltaY:function(t){return"deltaY"in t?t.deltaY:"wheelDeltaY"in t?-t.wheelDeltaY:"wheelDelta"in t?-t.wheelDelta:0},deltaZ:0,deltaMode:0}),Eh=kt(Dh),zh=H({},Oe,{newState:0,oldState:0}),_h=kt(zh),Mh=[9,13,27,32],mi=Nl&&"CompositionEvent"in window,Na=null;Nl&&"documentMode"in document&&(Na=document.documentMode);var Ah=Nl&&"TextEvent"in window&&!Na,Kc=Nl&&(!mi||Na&&8<Na&&11>=Na),wc=" ",Jc=!1;function Wc(t,l){switch(t){case"keyup":return Mh.indexOf(l.keyCode)!==-1;case"keydown":return l.keyCode!==229;case"keypress":case"mousedown":case"focusout":return!0;default:return!1}}function $c(t){return t=t.detail,typeof t=="object"&&"data"in t?t.data:null}var Je=!1;function Rh(t,l){switch(t){case"compositionend":return $c(l);case"keypress":return l.which!==32?null:(Jc=!0,wc);case"textInput":return t=l.data,t===wc&&Jc?null:t;default:return null}}function Uh(t,l){if(Je)return t==="compositionend"||!mi&&Wc(t,l)?(t=Gc(),Cu=di=Wl=null,Je=!1,t):null;switch(t){case"paste":return null;case"keypress":if(!(l.ctrlKey||l.altKey||l.metaKey)||l.ctrlKey&&l.altKey){if(l.char&&1<l.char.length)return l.char;if(l.which)return String.fromCharCode(l.which)}return null;case"compositionend":return Kc&&l.locale!=="ko"?null:l.data;default:return null}}var Nh={color:!0,date:!0,datetime:!0,"datetime-local":!0,email:!0,month:!0,number:!0,password:!0,range:!0,search:!0,tel:!0,text:!0,time:!0,url:!0,week:!0};function kc(t){var l=t&&t.nodeName&&t.nodeName.toLowerCase();return l==="input"?!!Nh[t.type]:l==="textarea"}function Fc(t,l,e,a){Ke?we?we.push(a):we=[a]:Ke=a,l=An(l,"onChange"),0<l.length&&(e=new Gu("onChange","change",null,e,a),t.push({event:e,listeners:l}))}var Ha=null,xa=null;function Hh(t){Ho(t,0)}function Zu(t){var l=_a(t);if(Hc(l))return t}function Pc(t,l){if(t==="change")return l}var Ic=!1;if(Nl){var pi;if(Nl){var Si="oninput"in document;if(!Si){var tr=document.createElement("div");tr.setAttribute("oninput","return;"),Si=typeof tr.oninput=="function"}pi=Si}else pi=!1;Ic=pi&&(!document.documentMode||9<document.documentMode)}function lr(){Ha&&(Ha.detachEvent("onpropertychange",er),xa=Ha=null)}function er(t){if(t.propertyName==="value"&&Zu(xa)){var l=[];Fc(l,xa,t,ri(t)),jc(Hh,l)}}function xh(t,l,e){t==="focusin"?(lr(),Ha=l,xa=e,Ha.attachEvent("onpropertychange",er)):t==="focusout"&&lr()}function qh(t){if(t==="selectionchange"||t==="keyup"||t==="keydown")return Zu(xa)}function Yh(t,l){if(t==="click")return Zu(l)}function Bh(t,l){if(t==="input"||t==="change")return Zu(l)}function Ch(t,l){return t===l&&(t!==0||1/t===1/l)||t!==t&&l!==l}var al=typeof Object.is=="function"?Object.is:Ch;function qa(t,l){if(al(t,l))return!0;if(typeof t!="object"||t===null||typeof l!="object"||l===null)return!1;var e=Object.keys(t),a=Object.keys(l);if(e.length!==a.length)return!1;for(a=0;a<e.length;a++){var u=e[a];if(!Wn.call(l,u)||!al(t[u],l[u]))return!1}return!0}function ar(t){for(;t&&t.firstChild;)t=t.firstChild;return t}function ur(t,l){var e=ar(t);t=0;for(var a;e;){if(e.nodeType===3){if(a=t+e.textContent.length,t<=l&&a>=l)return{node:e,offset:l-t};t=a}t:{for(;e;){if(e.nextSibling){e=e.nextSibling;break t}e=e.parentNode}e=void 0}e=ar(e)}}function nr(t,l){return t&&l?t===l?!0:t&&t.nodeType===3?!1:l&&l.nodeType===3?nr(t,l.parentNode):"contains"in t?t.contains(l):t.compareDocumentPosition?!!(t.compareDocumentPosition(l)&16):!1:!1}function ir(t){t=t!=null&&t.ownerDocument!=null&&t.ownerDocument.defaultView!=null?t.ownerDocument.defaultView:window;for(var l=Yu(t.document);l instanceof t.HTMLIFrameElement;){try{var e=typeof l.contentWindow.location.href=="string"}catch{e=!1}if(e)t=l.contentWindow;else break;l=Yu(t.document)}return l}function bi(t){var l=t&&t.nodeName&&t.nodeName.toLowerCase();return l&&(l==="input"&&(t.type==="text"||t.type==="search"||t.type==="tel"||t.type==="url"||t.type==="password")||l==="textarea"||t.contentEditable==="true")}var Xh=Nl&&"documentMode"in document&&11>=document.documentMode,We=null,Oi=null,Ya=null,Ti=!1;function fr(t,l,e){var a=e.window===e?e.document:e.nodeType===9?e:e.ownerDocument;Ti||We==null||We!==Yu(a)||(a=We,"selectionStart"in a&&bi(a)?a={start:a.selectionStart,end:a.selectionEnd}:(a=(a.ownerDocument&&a.ownerDocument.defaultView||window).getSelection(),a={anchorNode:a.anchorNode,anchorOffset:a.anchorOffset,focusNode:a.focusNode,focusOffset:a.focusOffset}),Ya&&qa(Ya,a)||(Ya=a,a=An(Oi,"onSelect"),0<a.length&&(l=new Gu("onSelect","select",null,l,e),t.push({event:l,listeners:a}),l.target=We)))}function Te(t,l){var e={};return e[t.toLowerCase()]=l.toLowerCase(),e["Webkit"+t]="webkit"+l,e["Moz"+t]="moz"+l,e}var $e={animationend:Te("Animation","AnimationEnd"),animationiteration:Te("Animation","AnimationIteration"),animationstart:Te("Animation","AnimationStart"),transitionrun:Te("Transition","TransitionRun"),transitionstart:Te("Transition","TransitionStart"),transitioncancel:Te("Transition","TransitionCancel"),transitionend:Te("Transition","TransitionEnd")},Di={},cr={};Nl&&(cr=document.createElement("div").style,"AnimationEvent"in window||(delete $e.animationend.animation,delete $e.animationiteration.animation,delete $e.animationstart.animation),"TransitionEvent"in window||delete $e.transitionend.transition);function De(t){if(Di[t])return Di[t];if(!$e[t])return t;var l=$e[t],e;for(e in l)if(l.hasOwnProperty(e)&&e in cr)return Di[t]=l[e];return t}var rr=De("animationend"),sr=De("animationiteration"),or=De("animationstart"),jh=De("transitionrun"),Gh=De("transitionstart"),Qh=De("transitioncancel"),dr=De("transitionend"),hr=new Map,Ei="abort auxClick beforeToggle cancel canPlay canPlayThrough click close contextMenu copy cut drag dragEnd dragEnter dragExit dragLeave dragOver dragStart drop durationChange emptied encrypted ended error gotPointerCapture input invalid keyDown keyPress keyUp load loadedData loadedMetadata loadStart lostPointerCapture mouseDown mouseMove mouseOut mouseOver mouseUp paste pause play playing pointerCancel pointerDown pointerMove pointerOut pointerOver pointerUp progress rateChange reset resize seeked seeking stalled submit suspend timeUpdate touchCancel touchEnd touchStart volumeChange scroll toggle touchMove waiting wheel".split(" ");Ei.push("scrollEnd");function bl(t,l){hr.set(t,l),be(l,[t])}var vr=new WeakMap;function dl(t,l){if(typeof t=="object"&&t!==null){var e=vr.get(t);return e!==void 0?e:(l={value:t,source:l,stack:Uc(l)},vr.set(t,l),l)}return{value:t,source:l,stack:Uc(l)}}var hl=[],ke=0,zi=0;function Vu(){for(var t=ke,l=zi=ke=0;l<t;){var e=hl[l];hl[l++]=null;var a=hl[l];hl[l++]=null;var u=hl[l];hl[l++]=null;var n=hl[l];if(hl[l++]=null,a!==null&&u!==null){var i=a.pending;i===null?u.next=u:(u.next=i.next,i.next=u),a.pending=u}n!==0&&yr(e,u,n)}}function Lu(t,l,e,a){hl[ke++]=t,hl[ke++]=l,hl[ke++]=e,hl[ke++]=a,zi|=a,t.lanes|=a,t=t.alternate,t!==null&&(t.lanes|=a)}function _i(t,l,e,a){return Lu(t,l,e,a),Ku(t)}function Fe(t,l){return Lu(t,null,null,l),Ku(t)}function yr(t,l,e){t.lanes|=e;var a=t.alternate;a!==null&&(a.lanes|=e);for(var u=!1,n=t.return;n!==null;)n.childLanes|=e,a=n.alternate,a!==null&&(a.childLanes|=e),n.tag===22&&(t=n.stateNode,t===null||t._visibility&1||(u=!0)),t=n,n=n.return;return t.tag===3?(n=t.stateNode,u&&l!==null&&(u=31-el(e),t=n.hiddenUpdates,a=t[u],a===null?t[u]=[l]:a.push(l),l.lane=e|536870912),n):null}function Ku(t){if(50<iu)throw iu=0,xf=null,Error(h(185));for(var l=t.return;l!==null;)t=l,l=t.return;return t.tag===3?t.stateNode:null}var Pe={};function Zh(t,l,e,a){this.tag=t,this.key=e,this.sibling=this.child=this.return=this.stateNode=this.type=this.elementType=null,this.index=0,this.refCleanup=this.ref=null,this.pendingProps=l,this.dependencies=this.memoizedState=this.updateQueue=this.memoizedProps=null,this.mode=a,this.subtreeFlags=this.flags=0,this.deletions=null,this.childLanes=this.lanes=0,this.alternate=null}function ul(t,l,e,a){return new Zh(t,l,e,a)}function Mi(t){return t=t.prototype,!(!t||!t.isReactComponent)}function Hl(t,l){var e=t.alternate;return e===null?(e=ul(t.tag,l,t.key,t.mode),e.elementType=t.elementType,e.type=t.type,e.stateNode=t.stateNode,e.alternate=t,t.alternate=e):(e.pendingProps=l,e.type=t.type,e.flags=0,e.subtreeFlags=0,e.deletions=null),e.flags=t.flags&65011712,e.childLanes=t.childLanes,e.lanes=t.lanes,e.child=t.child,e.memoizedProps=t.memoizedProps,e.memoizedState=t.memoizedState,e.updateQueue=t.updateQueue,l=t.dependencies,e.dependencies=l===null?null:{lanes:l.lanes,firstContext:l.firstContext},e.sibling=t.sibling,e.index=t.index,e.ref=t.ref,e.refCleanup=t.refCleanup,e}function gr(t,l){t.flags&=65011714;var e=t.alternate;return e===null?(t.childLanes=0,t.lanes=l,t.child=null,t.subtreeFlags=0,t.memoizedProps=null,t.memoizedState=null,t.updateQueue=null,t.dependencies=null,t.stateNode=null):(t.childLanes=e.childLanes,t.lanes=e.lanes,t.child=e.child,t.subtreeFlags=0,t.deletions=null,t.memoizedProps=e.memoizedProps,t.memoizedState=e.memoizedState,t.updateQueue=e.updateQueue,t.type=e.type,l=e.dependencies,t.dependencies=l===null?null:{lanes:l.lanes,firstContext:l.firstContext}),t}function wu(t,l,e,a,u,n){var i=0;if(a=t,typeof t=="function")Mi(t)&&(i=1);else if(typeof t=="string")i=Lv(t,e,lt.current)?26:t==="html"||t==="head"||t==="body"?27:5;else t:switch(t){case q:return t=ul(31,e,l,u),t.elementType=q,t.lanes=n,t;case tt:return Ee(e.children,u,n,l);case V:i=8,u|=24;break;case x:return t=ul(12,e,l,u|2),t.elementType=x,t.lanes=n,t;case v:return t=ul(13,e,l,u),t.elementType=v,t.lanes=n,t;case p:return t=ul(19,e,l,u),t.elementType=p,t.lanes=n,t;default:if(typeof t=="object"&&t!==null)switch(t.$$typeof){case _:case T:i=10;break t;case y:i=9;break t;case E:i=11;break t;case s:i=14;break t;case z:i=16,a=null;break t}i=29,e=Error(h(130,t===null?"null":typeof t,"")),a=null}return l=ul(i,e,l,u),l.elementType=t,l.type=a,l.lanes=n,l}function Ee(t,l,e,a){return t=ul(7,t,a,l),t.lanes=e,t}function Ai(t,l,e){return t=ul(6,t,null,l),t.lanes=e,t}function Ri(t,l,e){return l=ul(4,t.children!==null?t.children:[],t.key,l),l.lanes=e,l.stateNode={containerInfo:t.containerInfo,pendingChildren:null,implementation:t.implementation},l}var Ie=[],ta=0,Ju=null,Wu=0,vl=[],yl=0,ze=null,xl=1,ql="";function _e(t,l){Ie[ta++]=Wu,Ie[ta++]=Ju,Ju=t,Wu=l}function mr(t,l,e){vl[yl++]=xl,vl[yl++]=ql,vl[yl++]=ze,ze=t;var a=xl;t=ql;var u=32-el(a)-1;a&=~(1<<u),e+=1;var n=32-el(l)+u;if(30<n){var i=u-u%5;n=(a&(1<<i)-1).toString(32),a>>=i,u-=i,xl=1<<32-el(l)+u|e<<u|a,ql=n+t}else xl=1<<n|e<<u|a,ql=t}function Ui(t){t.return!==null&&(_e(t,1),mr(t,1,0))}function Ni(t){for(;t===Ju;)Ju=Ie[--ta],Ie[ta]=null,Wu=Ie[--ta],Ie[ta]=null;for(;t===ze;)ze=vl[--yl],vl[yl]=null,ql=vl[--yl],vl[yl]=null,xl=vl[--yl],vl[yl]=null}var Wt=null,At=null,ht=!1,Me=null,El=!1,Hi=Error(h(519));function Ae(t){var l=Error(h(418,""));throw Xa(dl(l,t)),Hi}function pr(t){var l=t.stateNode,e=t.type,a=t.memoizedProps;switch(l[Kt]=t,l[$t]=a,e){case"dialog":st("cancel",l),st("close",l);break;case"iframe":case"object":case"embed":st("load",l);break;case"video":case"audio":for(e=0;e<cu.length;e++)st(cu[e],l);break;case"source":st("error",l);break;case"img":case"image":case"link":st("error",l),st("load",l);break;case"details":st("toggle",l);break;case"input":st("invalid",l),xc(l,a.value,a.defaultValue,a.checked,a.defaultChecked,a.type,a.name,!0),qu(l);break;case"select":st("invalid",l);break;case"textarea":st("invalid",l),Yc(l,a.value,a.defaultValue,a.children),qu(l)}e=a.children,typeof e!="string"&&typeof e!="number"&&typeof e!="bigint"||l.textContent===""+e||a.suppressHydrationWarning===!0||Bo(l.textContent,e)?(a.popover!=null&&(st("beforetoggle",l),st("toggle",l)),a.onScroll!=null&&st("scroll",l),a.onScrollEnd!=null&&st("scrollend",l),a.onClick!=null&&(l.onclick=Rn),l=!0):l=!1,l||Ae(t)}function Sr(t){for(Wt=t.return;Wt;)switch(Wt.tag){case 5:case 13:El=!1;return;case 27:case 3:El=!0;return;default:Wt=Wt.return}}function Ba(t){if(t!==Wt)return!1;if(!ht)return Sr(t),ht=!0,!1;var l=t.tag,e;if((e=l!==3&&l!==27)&&((e=l===5)&&(e=t.type,e=!(e!=="form"&&e!=="button")||$f(t.type,t.memoizedProps)),e=!e),e&&At&&Ae(t),Sr(t),l===13){if(t=t.memoizedState,t=t!==null?t.dehydrated:null,!t)throw Error(h(317));t:{for(t=t.nextSibling,l=0;t;){if(t.nodeType===8)if(e=t.data,e==="/$"){if(l===0){At=Tl(t.nextSibling);break t}l--}else e!=="$"&&e!=="$!"&&e!=="$?"||l++;t=t.nextSibling}At=null}}else l===27?(l=At,se(t.type)?(t=If,If=null,At=t):At=l):At=Wt?Tl(t.stateNode.nextSibling):null;return!0}function Ca(){At=Wt=null,ht=!1}function br(){var t=Me;return t!==null&&(It===null?It=t:It.push.apply(It,t),Me=null),t}function Xa(t){Me===null?Me=[t]:Me.push(t)}var xi=N(null),Re=null,Yl=null;function $l(t,l,e){X(xi,l._currentValue),l._currentValue=e}function Bl(t){t._currentValue=xi.current,G(xi)}function qi(t,l,e){for(;t!==null;){var a=t.alternate;if((t.childLanes&l)!==l?(t.childLanes|=l,a!==null&&(a.childLanes|=l)):a!==null&&(a.childLanes&l)!==l&&(a.childLanes|=l),t===e)break;t=t.return}}function Yi(t,l,e,a){var u=t.child;for(u!==null&&(u.return=t);u!==null;){var n=u.dependencies;if(n!==null){var i=u.child;n=n.firstContext;t:for(;n!==null;){var f=n;n=u;for(var c=0;c<l.length;c++)if(f.context===l[c]){n.lanes|=e,f=n.alternate,f!==null&&(f.lanes|=e),qi(n.return,e,t),a||(i=null);break t}n=f.next}}else if(u.tag===18){if(i=u.return,i===null)throw Error(h(341));i.lanes|=e,n=i.alternate,n!==null&&(n.lanes|=e),qi(i,e,t),i=null}else i=u.child;if(i!==null)i.return=u;else for(i=u;i!==null;){if(i===t){i=null;break}if(u=i.sibling,u!==null){u.return=i.return,i=u;break}i=i.return}u=i}}function ja(t,l,e,a){t=null;for(var u=l,n=!1;u!==null;){if(!n){if((u.flags&524288)!==0)n=!0;else if((u.flags&262144)!==0)break}if(u.tag===10){var i=u.alternate;if(i===null)throw Error(h(387));if(i=i.memoizedProps,i!==null){var f=u.type;al(u.pendingProps.value,i.value)||(t!==null?t.push(f):t=[f])}}else if(u===tl.current){if(i=u.alternate,i===null)throw Error(h(387));i.memoizedState.memoizedState!==u.memoizedState.memoizedState&&(t!==null?t.push(vu):t=[vu])}u=u.return}t!==null&&Yi(l,t,e,a),l.flags|=262144}function $u(t){for(t=t.firstContext;t!==null;){if(!al(t.context._currentValue,t.memoizedValue))return!0;t=t.next}return!1}function Ue(t){Re=t,Yl=null,t=t.dependencies,t!==null&&(t.firstContext=null)}function wt(t){return Or(Re,t)}function ku(t,l){return Re===null&&Ue(t),Or(t,l)}function Or(t,l){var e=l._currentValue;if(l={context:l,memoizedValue:e,next:null},Yl===null){if(t===null)throw Error(h(308));Yl=l,t.dependencies={lanes:0,firstContext:l},t.flags|=524288}else Yl=Yl.next=l;return e}var Vh=typeof AbortController<"u"?AbortController:function(){var t=[],l=this.signal={aborted:!1,addEventListener:function(e,a){t.push(a)}};this.abort=function(){l.aborted=!0,t.forEach(function(e){return e()})}},Lh=D.unstable_scheduleCallback,Kh=D.unstable_NormalPriority,Bt={$$typeof:T,Consumer:null,Provider:null,_currentValue:null,_currentValue2:null,_threadCount:0};function Bi(){return{controller:new Vh,data:new Map,refCount:0}}function Ga(t){t.refCount--,t.refCount===0&&Lh(Kh,function(){t.controller.abort()})}var Qa=null,Ci=0,la=0,ea=null;function wh(t,l){if(Qa===null){var e=Qa=[];Ci=0,la=Gf(),ea={status:"pending",value:void 0,then:function(a){e.push(a)}}}return Ci++,l.then(Tr,Tr),l}function Tr(){if(--Ci===0&&Qa!==null){ea!==null&&(ea.status="fulfilled");var t=Qa;Qa=null,la=0,ea=null;for(var l=0;l<t.length;l++)(0,t[l])()}}function Jh(t,l){var e=[],a={status:"pending",value:null,reason:null,then:function(u){e.push(u)}};return t.then(function(){a.status="fulfilled",a.value=l;for(var u=0;u<e.length;u++)(0,e[u])(l)},function(u){for(a.status="rejected",a.reason=u,u=0;u<e.length;u++)(0,e[u])(void 0)}),a}var Dr=C.S;C.S=function(t,l){typeof l=="object"&&l!==null&&typeof l.then=="function"&&wh(t,l),Dr!==null&&Dr(t,l)};var Ne=N(null);function Xi(){var t=Ne.current;return t!==null?t:Dt.pooledCache}function Fu(t,l){l===null?X(Ne,Ne.current):X(Ne,l.pool)}function Er(){var t=Xi();return t===null?null:{parent:Bt._currentValue,pool:t}}var Za=Error(h(460)),zr=Error(h(474)),Pu=Error(h(542)),ji={then:function(){}};function _r(t){return t=t.status,t==="fulfilled"||t==="rejected"}function Iu(){}function Mr(t,l,e){switch(e=t[e],e===void 0?t.push(l):e!==l&&(l.then(Iu,Iu),l=e),l.status){case"fulfilled":return l.value;case"rejected":throw t=l.reason,Rr(t),t;default:if(typeof l.status=="string")l.then(Iu,Iu);else{if(t=Dt,t!==null&&100<t.shellSuspendCounter)throw Error(h(482));t=l,t.status="pending",t.then(function(a){if(l.status==="pending"){var u=l;u.status="fulfilled",u.value=a}},function(a){if(l.status==="pending"){var u=l;u.status="rejected",u.reason=a}})}switch(l.status){case"fulfilled":return l.value;case"rejected":throw t=l.reason,Rr(t),t}throw Va=l,Za}}var Va=null;function Ar(){if(Va===null)throw Error(h(459));var t=Va;return Va=null,t}function Rr(t){if(t===Za||t===Pu)throw Error(h(483))}var kl=!1;function Gi(t){t.updateQueue={baseState:t.memoizedState,firstBaseUpdate:null,lastBaseUpdate:null,shared:{pending:null,lanes:0,hiddenCallbacks:null},callbacks:null}}function Qi(t,l){t=t.updateQueue,l.updateQueue===t&&(l.updateQueue={baseState:t.baseState,firstBaseUpdate:t.firstBaseUpdate,lastBaseUpdate:t.lastBaseUpdate,shared:t.shared,callbacks:null})}function Fl(t){return{lane:t,tag:0,payload:null,callback:null,next:null}}function Pl(t,l,e){var a=t.updateQueue;if(a===null)return null;if(a=a.shared,(yt&2)!==0){var u=a.pending;return u===null?l.next=l:(l.next=u.next,u.next=l),a.pending=l,l=Ku(t),yr(t,null,e),l}return Lu(t,a,l,e),Ku(t)}function La(t,l,e){if(l=l.updateQueue,l!==null&&(l=l.shared,(e&4194048)!==0)){var a=l.lanes;a&=t.pendingLanes,e|=a,l.lanes=e,Tc(t,e)}}function Zi(t,l){var e=t.updateQueue,a=t.alternate;if(a!==null&&(a=a.updateQueue,e===a)){var u=null,n=null;if(e=e.firstBaseUpdate,e!==null){do{var i={lane:e.lane,tag:e.tag,payload:e.payload,callback:null,next:null};n===null?u=n=i:n=n.next=i,e=e.next}while(e!==null);n===null?u=n=l:n=n.next=l}else u=n=l;e={baseState:a.baseState,firstBaseUpdate:u,lastBaseUpdate:n,shared:a.shared,callbacks:a.callbacks},t.updateQueue=e;return}t=e.lastBaseUpdate,t===null?e.firstBaseUpdate=l:t.next=l,e.lastBaseUpdate=l}var Vi=!1;function Ka(){if(Vi){var t=ea;if(t!==null)throw t}}function wa(t,l,e,a){Vi=!1;var u=t.updateQueue;kl=!1;var n=u.firstBaseUpdate,i=u.lastBaseUpdate,f=u.shared.pending;if(f!==null){u.shared.pending=null;var c=f,m=c.next;c.next=null,i===null?n=m:i.next=m,i=c;var M=t.alternate;M!==null&&(M=M.updateQueue,f=M.lastBaseUpdate,f!==i&&(f===null?M.firstBaseUpdate=m:f.next=m,M.lastBaseUpdate=c))}if(n!==null){var R=u.baseState;i=0,M=m=c=null,f=n;do{var b=f.lane&-536870913,O=b!==f.lane;if(O?(ot&b)===b:(a&b)===b){b!==0&&b===la&&(Vi=!0),M!==null&&(M=M.next={lane:0,tag:f.tag,payload:f.payload,callback:null,next:null});t:{var I=t,$=f;b=l;var bt=e;switch($.tag){case 1:if(I=$.payload,typeof I=="function"){R=I.call(bt,R,b);break t}R=I;break t;case 3:I.flags=I.flags&-65537|128;case 0:if(I=$.payload,b=typeof I=="function"?I.call(bt,R,b):I,b==null)break t;R=H({},R,b);break t;case 2:kl=!0}}b=f.callback,b!==null&&(t.flags|=64,O&&(t.flags|=8192),O=u.callbacks,O===null?u.callbacks=[b]:O.push(b))}else O={lane:b,tag:f.tag,payload:f.payload,callback:f.callback,next:null},M===null?(m=M=O,c=R):M=M.next=O,i|=b;if(f=f.next,f===null){if(f=u.shared.pending,f===null)break;O=f,f=O.next,O.next=null,u.lastBaseUpdate=O,u.shared.pending=null}}while(!0);M===null&&(c=R),u.baseState=c,u.firstBaseUpdate=m,u.lastBaseUpdate=M,n===null&&(u.shared.lanes=0),ie|=i,t.lanes=i,t.memoizedState=R}}function Ur(t,l){if(typeof t!="function")throw Error(h(191,t));t.call(l)}function Nr(t,l){var e=t.callbacks;if(e!==null)for(t.callbacks=null,t=0;t<e.length;t++)Ur(e[t],l)}var aa=N(null),tn=N(0);function Hr(t,l){t=Vl,X(tn,t),X(aa,l),Vl=t|l.baseLanes}function Li(){X(tn,Vl),X(aa,aa.current)}function Ki(){Vl=tn.current,G(aa),G(tn)}var Il=0,it=null,pt=null,qt=null,ln=!1,ua=!1,He=!1,en=0,Ja=0,na=null,Wh=0;function Ut(){throw Error(h(321))}function wi(t,l){if(l===null)return!1;for(var e=0;e<l.length&&e<t.length;e++)if(!al(t[e],l[e]))return!1;return!0}function Ji(t,l,e,a,u,n){return Il=n,it=l,l.memoizedState=null,l.updateQueue=null,l.lanes=0,C.H=t===null||t.memoizedState===null?ys:gs,He=!1,n=e(a,u),He=!1,ua&&(n=qr(l,e,a,u)),xr(t),n}function xr(t){C.H=rn;var l=pt!==null&&pt.next!==null;if(Il=0,qt=pt=it=null,ln=!1,Ja=0,na=null,l)throw Error(h(300));t===null||jt||(t=t.dependencies,t!==null&&$u(t)&&(jt=!0))}function qr(t,l,e,a){it=t;var u=0;do{if(ua&&(na=null),Ja=0,ua=!1,25<=u)throw Error(h(301));if(u+=1,qt=pt=null,t.updateQueue!=null){var n=t.updateQueue;n.lastEffect=null,n.events=null,n.stores=null,n.memoCache!=null&&(n.memoCache.index=0)}C.H=lv,n=l(e,a)}while(ua);return n}function $h(){var t=C.H,l=t.useState()[0];return l=typeof l.then=="function"?Wa(l):l,t=t.useState()[0],(pt!==null?pt.memoizedState:null)!==t&&(it.flags|=1024),l}function Wi(){var t=en!==0;return en=0,t}function $i(t,l,e){l.updateQueue=t.updateQueue,l.flags&=-2053,t.lanes&=~e}function ki(t){if(ln){for(t=t.memoizedState;t!==null;){var l=t.queue;l!==null&&(l.pending=null),t=t.next}ln=!1}Il=0,qt=pt=it=null,ua=!1,Ja=en=0,na=null}function Ft(){var t={memoizedState:null,baseState:null,baseQueue:null,queue:null,next:null};return qt===null?it.memoizedState=qt=t:qt=qt.next=t,qt}function Yt(){if(pt===null){var t=it.alternate;t=t!==null?t.memoizedState:null}else t=pt.next;var l=qt===null?it.memoizedState:qt.next;if(l!==null)qt=l,pt=t;else{if(t===null)throw it.alternate===null?Error(h(467)):Error(h(310));pt=t,t={memoizedState:pt.memoizedState,baseState:pt.baseState,baseQueue:pt.baseQueue,queue:pt.queue,next:null},qt===null?it.memoizedState=qt=t:qt=qt.next=t}return qt}function Fi(){return{lastEffect:null,events:null,stores:null,memoCache:null}}function Wa(t){var l=Ja;return Ja+=1,na===null&&(na=[]),t=Mr(na,t,l),l=it,(qt===null?l.memoizedState:qt.next)===null&&(l=l.alternate,C.H=l===null||l.memoizedState===null?ys:gs),t}function an(t){if(t!==null&&typeof t=="object"){if(typeof t.then=="function")return Wa(t);if(t.$$typeof===T)return wt(t)}throw Error(h(438,String(t)))}function Pi(t){var l=null,e=it.updateQueue;if(e!==null&&(l=e.memoCache),l==null){var a=it.alternate;a!==null&&(a=a.updateQueue,a!==null&&(a=a.memoCache,a!=null&&(l={data:a.data.map(function(u){return u.slice()}),index:0})))}if(l==null&&(l={data:[],index:0}),e===null&&(e=Fi(),it.updateQueue=e),e.memoCache=l,e=l.data[l.index],e===void 0)for(e=l.data[l.index]=Array(t),a=0;a<t;a++)e[a]=ut;return l.index++,e}function Cl(t,l){return typeof l=="function"?l(t):l}function un(t){var l=Yt();return Ii(l,pt,t)}function Ii(t,l,e){var a=t.queue;if(a===null)throw Error(h(311));a.lastRenderedReducer=e;var u=t.baseQueue,n=a.pending;if(n!==null){if(u!==null){var i=u.next;u.next=n.next,n.next=i}l.baseQueue=u=n,a.pending=null}if(n=t.baseState,u===null)t.memoizedState=n;else{l=u.next;var f=i=null,c=null,m=l,M=!1;do{var R=m.lane&-536870913;if(R!==m.lane?(ot&R)===R:(Il&R)===R){var b=m.revertLane;if(b===0)c!==null&&(c=c.next={lane:0,revertLane:0,action:m.action,hasEagerState:m.hasEagerState,eagerState:m.eagerState,next:null}),R===la&&(M=!0);else if((Il&b)===b){m=m.next,b===la&&(M=!0);continue}else R={lane:0,revertLane:m.revertLane,action:m.action,hasEagerState:m.hasEagerState,eagerState:m.eagerState,next:null},c===null?(f=c=R,i=n):c=c.next=R,it.lanes|=b,ie|=b;R=m.action,He&&e(n,R),n=m.hasEagerState?m.eagerState:e(n,R)}else b={lane:R,revertLane:m.revertLane,action:m.action,hasEagerState:m.hasEagerState,eagerState:m.eagerState,next:null},c===null?(f=c=b,i=n):c=c.next=b,it.lanes|=R,ie|=R;m=m.next}while(m!==null&&m!==l);if(c===null?i=n:c.next=f,!al(n,t.memoizedState)&&(jt=!0,M&&(e=ea,e!==null)))throw e;t.memoizedState=n,t.baseState=i,t.baseQueue=c,a.lastRenderedState=n}return u===null&&(a.lanes=0),[t.memoizedState,a.dispatch]}function tf(t){var l=Yt(),e=l.queue;if(e===null)throw Error(h(311));e.lastRenderedReducer=t;var a=e.dispatch,u=e.pending,n=l.memoizedState;if(u!==null){e.pending=null;var i=u=u.next;do n=t(n,i.action),i=i.next;while(i!==u);al(n,l.memoizedState)||(jt=!0),l.memoizedState=n,l.baseQueue===null&&(l.baseState=n),e.lastRenderedState=n}return[n,a]}function Yr(t,l,e){var a=it,u=Yt(),n=ht;if(n){if(e===void 0)throw Error(h(407));e=e()}else e=l();var i=!al((pt||u).memoizedState,e);i&&(u.memoizedState=e,jt=!0),u=u.queue;var f=Xr.bind(null,a,u,t);if($a(2048,8,f,[t]),u.getSnapshot!==l||i||qt!==null&&qt.memoizedState.tag&1){if(a.flags|=2048,ia(9,nn(),Cr.bind(null,a,u,e,l),null),Dt===null)throw Error(h(349));n||(Il&124)!==0||Br(a,l,e)}return e}function Br(t,l,e){t.flags|=16384,t={getSnapshot:l,value:e},l=it.updateQueue,l===null?(l=Fi(),it.updateQueue=l,l.stores=[t]):(e=l.stores,e===null?l.stores=[t]:e.push(t))}function Cr(t,l,e,a){l.value=e,l.getSnapshot=a,jr(l)&&Gr(t)}function Xr(t,l,e){return e(function(){jr(l)&&Gr(t)})}function jr(t){var l=t.getSnapshot;t=t.value;try{var e=l();return!al(t,e)}catch{return!0}}function Gr(t){var l=Fe(t,2);l!==null&&rl(l,t,2)}function lf(t){var l=Ft();if(typeof t=="function"){var e=t;if(t=e(),He){wl(!0);try{e()}finally{wl(!1)}}}return l.memoizedState=l.baseState=t,l.queue={pending:null,lanes:0,dispatch:null,lastRenderedReducer:Cl,lastRenderedState:t},l}function Qr(t,l,e,a){return t.baseState=e,Ii(t,pt,typeof a=="function"?a:Cl)}function kh(t,l,e,a,u){if(cn(t))throw Error(h(485));if(t=l.action,t!==null){var n={payload:u,action:t,next:null,isTransition:!0,status:"pending",value:null,reason:null,listeners:[],then:function(i){n.listeners.push(i)}};C.T!==null?e(!0):n.isTransition=!1,a(n),e=l.pending,e===null?(n.next=l.pending=n,Zr(l,n)):(n.next=e.next,l.pending=e.next=n)}}function Zr(t,l){var e=l.action,a=l.payload,u=t.state;if(l.isTransition){var n=C.T,i={};C.T=i;try{var f=e(u,a),c=C.S;c!==null&&c(i,f),Vr(t,l,f)}catch(m){ef(t,l,m)}finally{C.T=n}}else try{n=e(u,a),Vr(t,l,n)}catch(m){ef(t,l,m)}}function Vr(t,l,e){e!==null&&typeof e=="object"&&typeof e.then=="function"?e.then(function(a){Lr(t,l,a)},function(a){return ef(t,l,a)}):Lr(t,l,e)}function Lr(t,l,e){l.status="fulfilled",l.value=e,Kr(l),t.state=e,l=t.pending,l!==null&&(e=l.next,e===l?t.pending=null:(e=e.next,l.next=e,Zr(t,e)))}function ef(t,l,e){var a=t.pending;if(t.pending=null,a!==null){a=a.next;do l.status="rejected",l.reason=e,Kr(l),l=l.next;while(l!==a)}t.action=null}function Kr(t){t=t.listeners;for(var l=0;l<t.length;l++)(0,t[l])()}function wr(t,l){return l}function Jr(t,l){if(ht){var e=Dt.formState;if(e!==null){t:{var a=it;if(ht){if(At){l:{for(var u=At,n=El;u.nodeType!==8;){if(!n){u=null;break l}if(u=Tl(u.nextSibling),u===null){u=null;break l}}n=u.data,u=n==="F!"||n==="F"?u:null}if(u){At=Tl(u.nextSibling),a=u.data==="F!";break t}}Ae(a)}a=!1}a&&(l=e[0])}}return e=Ft(),e.memoizedState=e.baseState=l,a={pending:null,lanes:0,dispatch:null,lastRenderedReducer:wr,lastRenderedState:l},e.queue=a,e=ds.bind(null,it,a),a.dispatch=e,a=lf(!1),n=cf.bind(null,it,!1,a.queue),a=Ft(),u={state:l,dispatch:null,action:t,pending:null},a.queue=u,e=kh.bind(null,it,u,n,e),u.dispatch=e,a.memoizedState=t,[l,e,!1]}function Wr(t){var l=Yt();return $r(l,pt,t)}function $r(t,l,e){if(l=Ii(t,l,wr)[0],t=un(Cl)[0],typeof l=="object"&&l!==null&&typeof l.then=="function")try{var a=Wa(l)}catch(i){throw i===Za?Pu:i}else a=l;l=Yt();var u=l.queue,n=u.dispatch;return e!==l.memoizedState&&(it.flags|=2048,ia(9,nn(),Fh.bind(null,u,e),null)),[a,n,t]}function Fh(t,l){t.action=l}function kr(t){var l=Yt(),e=pt;if(e!==null)return $r(l,e,t);Yt(),l=l.memoizedState,e=Yt();var a=e.queue.dispatch;return e.memoizedState=t,[l,a,!1]}function ia(t,l,e,a){return t={tag:t,create:e,deps:a,inst:l,next:null},l=it.updateQueue,l===null&&(l=Fi(),it.updateQueue=l),e=l.lastEffect,e===null?l.lastEffect=t.next=t:(a=e.next,e.next=t,t.next=a,l.lastEffect=t),t}function nn(){return{destroy:void 0,resource:void 0}}function Fr(){return Yt().memoizedState}function fn(t,l,e,a){var u=Ft();a=a===void 0?null:a,it.flags|=t,u.memoizedState=ia(1|l,nn(),e,a)}function $a(t,l,e,a){var u=Yt();a=a===void 0?null:a;var n=u.memoizedState.inst;pt!==null&&a!==null&&wi(a,pt.memoizedState.deps)?u.memoizedState=ia(l,n,e,a):(it.flags|=t,u.memoizedState=ia(1|l,n,e,a))}function Pr(t,l){fn(8390656,8,t,l)}function Ir(t,l){$a(2048,8,t,l)}function ts(t,l){return $a(4,2,t,l)}function ls(t,l){return $a(4,4,t,l)}function es(t,l){if(typeof l=="function"){t=t();var e=l(t);return function(){typeof e=="function"?e():l(null)}}if(l!=null)return t=t(),l.current=t,function(){l.current=null}}function as(t,l,e){e=e!=null?e.concat([t]):null,$a(4,4,es.bind(null,l,t),e)}function af(){}function us(t,l){var e=Yt();l=l===void 0?null:l;var a=e.memoizedState;return l!==null&&wi(l,a[1])?a[0]:(e.memoizedState=[t,l],t)}function ns(t,l){var e=Yt();l=l===void 0?null:l;var a=e.memoizedState;if(l!==null&&wi(l,a[1]))return a[0];if(a=t(),He){wl(!0);try{t()}finally{wl(!1)}}return e.memoizedState=[a,l],a}function uf(t,l,e){return e===void 0||(Il&1073741824)!==0?t.memoizedState=l:(t.memoizedState=e,t=co(),it.lanes|=t,ie|=t,e)}function is(t,l,e,a){return al(e,l)?e:aa.current!==null?(t=uf(t,e,a),al(t,l)||(jt=!0),t):(Il&42)===0?(jt=!0,t.memoizedState=e):(t=co(),it.lanes|=t,ie|=t,l)}function fs(t,l,e,a,u){var n=et.p;et.p=n!==0&&8>n?n:8;var i=C.T,f={};C.T=f,cf(t,!1,l,e);try{var c=u(),m=C.S;if(m!==null&&m(f,c),c!==null&&typeof c=="object"&&typeof c.then=="function"){var M=Jh(c,a);ka(t,l,M,cl(t))}else ka(t,l,a,cl(t))}catch(R){ka(t,l,{then:function(){},status:"rejected",reason:R},cl())}finally{et.p=n,C.T=i}}function Ph(){}function nf(t,l,e,a){if(t.tag!==5)throw Error(h(476));var u=cs(t).queue;fs(t,u,l,xt,e===null?Ph:function(){return rs(t),e(a)})}function cs(t){var l=t.memoizedState;if(l!==null)return l;l={memoizedState:xt,baseState:xt,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:Cl,lastRenderedState:xt},next:null};var e={};return l.next={memoizedState:e,baseState:e,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:Cl,lastRenderedState:e},next:null},t.memoizedState=l,t=t.alternate,t!==null&&(t.memoizedState=l),l}function rs(t){var l=cs(t).next.queue;ka(t,l,{},cl())}function ff(){return wt(vu)}function ss(){return Yt().memoizedState}function os(){return Yt().memoizedState}function Ih(t){for(var l=t.return;l!==null;){switch(l.tag){case 24:case 3:var e=cl();t=Fl(e);var a=Pl(l,t,e);a!==null&&(rl(a,l,e),La(a,l,e)),l={cache:Bi()},t.payload=l;return}l=l.return}}function tv(t,l,e){var a=cl();e={lane:a,revertLane:0,action:e,hasEagerState:!1,eagerState:null,next:null},cn(t)?hs(l,e):(e=_i(t,l,e,a),e!==null&&(rl(e,t,a),vs(e,l,a)))}function ds(t,l,e){var a=cl();ka(t,l,e,a)}function ka(t,l,e,a){var u={lane:a,revertLane:0,action:e,hasEagerState:!1,eagerState:null,next:null};if(cn(t))hs(l,u);else{var n=t.alternate;if(t.lanes===0&&(n===null||n.lanes===0)&&(n=l.lastRenderedReducer,n!==null))try{var i=l.lastRenderedState,f=n(i,e);if(u.hasEagerState=!0,u.eagerState=f,al(f,i))return Lu(t,l,u,0),Dt===null&&Vu(),!1}catch{}finally{}if(e=_i(t,l,u,a),e!==null)return rl(e,t,a),vs(e,l,a),!0}return!1}function cf(t,l,e,a){if(a={lane:2,revertLane:Gf(),action:a,hasEagerState:!1,eagerState:null,next:null},cn(t)){if(l)throw Error(h(479))}else l=_i(t,e,a,2),l!==null&&rl(l,t,2)}function cn(t){var l=t.alternate;return t===it||l!==null&&l===it}function hs(t,l){ua=ln=!0;var e=t.pending;e===null?l.next=l:(l.next=e.next,e.next=l),t.pending=l}function vs(t,l,e){if((e&4194048)!==0){var a=l.lanes;a&=t.pendingLanes,e|=a,l.lanes=e,Tc(t,e)}}var rn={readContext:wt,use:an,useCallback:Ut,useContext:Ut,useEffect:Ut,useImperativeHandle:Ut,useLayoutEffect:Ut,useInsertionEffect:Ut,useMemo:Ut,useReducer:Ut,useRef:Ut,useState:Ut,useDebugValue:Ut,useDeferredValue:Ut,useTransition:Ut,useSyncExternalStore:Ut,useId:Ut,useHostTransitionStatus:Ut,useFormState:Ut,useActionState:Ut,useOptimistic:Ut,useMemoCache:Ut,useCacheRefresh:Ut},ys={readContext:wt,use:an,useCallback:function(t,l){return Ft().memoizedState=[t,l===void 0?null:l],t},useContext:wt,useEffect:Pr,useImperativeHandle:function(t,l,e){e=e!=null?e.concat([t]):null,fn(4194308,4,es.bind(null,l,t),e)},useLayoutEffect:function(t,l){return fn(4194308,4,t,l)},useInsertionEffect:function(t,l){fn(4,2,t,l)},useMemo:function(t,l){var e=Ft();l=l===void 0?null:l;var a=t();if(He){wl(!0);try{t()}finally{wl(!1)}}return e.memoizedState=[a,l],a},useReducer:function(t,l,e){var a=Ft();if(e!==void 0){var u=e(l);if(He){wl(!0);try{e(l)}finally{wl(!1)}}}else u=l;return a.memoizedState=a.baseState=u,t={pending:null,lanes:0,dispatch:null,lastRenderedReducer:t,lastRenderedState:u},a.queue=t,t=t.dispatch=tv.bind(null,it,t),[a.memoizedState,t]},useRef:function(t){var l=Ft();return t={current:t},l.memoizedState=t},useState:function(t){t=lf(t);var l=t.queue,e=ds.bind(null,it,l);return l.dispatch=e,[t.memoizedState,e]},useDebugValue:af,useDeferredValue:function(t,l){var e=Ft();return uf(e,t,l)},useTransition:function(){var t=lf(!1);return t=fs.bind(null,it,t.queue,!0,!1),Ft().memoizedState=t,[!1,t]},useSyncExternalStore:function(t,l,e){var a=it,u=Ft();if(ht){if(e===void 0)throw Error(h(407));e=e()}else{if(e=l(),Dt===null)throw Error(h(349));(ot&124)!==0||Br(a,l,e)}u.memoizedState=e;var n={value:e,getSnapshot:l};return u.queue=n,Pr(Xr.bind(null,a,n,t),[t]),a.flags|=2048,ia(9,nn(),Cr.bind(null,a,n,e,l),null),e},useId:function(){var t=Ft(),l=Dt.identifierPrefix;if(ht){var e=ql,a=xl;e=(a&~(1<<32-el(a)-1)).toString(32)+e,l="«"+l+"R"+e,e=en++,0<e&&(l+="H"+e.toString(32)),l+="»"}else e=Wh++,l="«"+l+"r"+e.toString(32)+"»";return t.memoizedState=l},useHostTransitionStatus:ff,useFormState:Jr,useActionState:Jr,useOptimistic:function(t){var l=Ft();l.memoizedState=l.baseState=t;var e={pending:null,lanes:0,dispatch:null,lastRenderedReducer:null,lastRenderedState:null};return l.queue=e,l=cf.bind(null,it,!0,e),e.dispatch=l,[t,l]},useMemoCache:Pi,useCacheRefresh:function(){return Ft().memoizedState=Ih.bind(null,it)}},gs={readContext:wt,use:an,useCallback:us,useContext:wt,useEffect:Ir,useImperativeHandle:as,useInsertionEffect:ts,useLayoutEffect:ls,useMemo:ns,useReducer:un,useRef:Fr,useState:function(){return un(Cl)},useDebugValue:af,useDeferredValue:function(t,l){var e=Yt();return is(e,pt.memoizedState,t,l)},useTransition:function(){var t=un(Cl)[0],l=Yt().memoizedState;return[typeof t=="boolean"?t:Wa(t),l]},useSyncExternalStore:Yr,useId:ss,useHostTransitionStatus:ff,useFormState:Wr,useActionState:Wr,useOptimistic:function(t,l){var e=Yt();return Qr(e,pt,t,l)},useMemoCache:Pi,useCacheRefresh:os},lv={readContext:wt,use:an,useCallback:us,useContext:wt,useEffect:Ir,useImperativeHandle:as,useInsertionEffect:ts,useLayoutEffect:ls,useMemo:ns,useReducer:tf,useRef:Fr,useState:function(){return tf(Cl)},useDebugValue:af,useDeferredValue:function(t,l){var e=Yt();return pt===null?uf(e,t,l):is(e,pt.memoizedState,t,l)},useTransition:function(){var t=tf(Cl)[0],l=Yt().memoizedState;return[typeof t=="boolean"?t:Wa(t),l]},useSyncExternalStore:Yr,useId:ss,useHostTransitionStatus:ff,useFormState:kr,useActionState:kr,useOptimistic:function(t,l){var e=Yt();return pt!==null?Qr(e,pt,t,l):(e.baseState=t,[t,e.queue.dispatch])},useMemoCache:Pi,useCacheRefresh:os},fa=null,Fa=0;function sn(t){var l=Fa;return Fa+=1,fa===null&&(fa=[]),Mr(fa,t,l)}function Pa(t,l){l=l.props.ref,t.ref=l!==void 0?l:null}function on(t,l){throw l.$$typeof===B?Error(h(525)):(t=Object.prototype.toString.call(l),Error(h(31,t==="[object Object]"?"object with keys {"+Object.keys(l).join(", ")+"}":t)))}function ms(t){var l=t._init;return l(t._payload)}function ps(t){function l(d,r){if(t){var g=d.deletions;g===null?(d.deletions=[r],d.flags|=16):g.push(r)}}function e(d,r){if(!t)return null;for(;r!==null;)l(d,r),r=r.sibling;return null}function a(d){for(var r=new Map;d!==null;)d.key!==null?r.set(d.key,d):r.set(d.index,d),d=d.sibling;return r}function u(d,r){return d=Hl(d,r),d.index=0,d.sibling=null,d}function n(d,r,g){return d.index=g,t?(g=d.alternate,g!==null?(g=g.index,g<r?(d.flags|=67108866,r):g):(d.flags|=67108866,r)):(d.flags|=1048576,r)}function i(d){return t&&d.alternate===null&&(d.flags|=67108866),d}function f(d,r,g,A){return r===null||r.tag!==6?(r=Ai(g,d.mode,A),r.return=d,r):(r=u(r,g),r.return=d,r)}function c(d,r,g,A){var Q=g.type;return Q===tt?M(d,r,g.props.children,A,g.key):r!==null&&(r.elementType===Q||typeof Q=="object"&&Q!==null&&Q.$$typeof===z&&ms(Q)===r.type)?(r=u(r,g.props),Pa(r,g),r.return=d,r):(r=wu(g.type,g.key,g.props,null,d.mode,A),Pa(r,g),r.return=d,r)}function m(d,r,g,A){return r===null||r.tag!==4||r.stateNode.containerInfo!==g.containerInfo||r.stateNode.implementation!==g.implementation?(r=Ri(g,d.mode,A),r.return=d,r):(r=u(r,g.children||[]),r.return=d,r)}function M(d,r,g,A,Q){return r===null||r.tag!==7?(r=Ee(g,d.mode,A,Q),r.return=d,r):(r=u(r,g),r.return=d,r)}function R(d,r,g){if(typeof r=="string"&&r!==""||typeof r=="number"||typeof r=="bigint")return r=Ai(""+r,d.mode,g),r.return=d,r;if(typeof r=="object"&&r!==null){switch(r.$$typeof){case L:return g=wu(r.type,r.key,r.props,null,d.mode,g),Pa(g,r),g.return=d,g;case W:return r=Ri(r,d.mode,g),r.return=d,r;case z:var A=r._init;return r=A(r._payload),R(d,r,g)}if(Tt(r)||ct(r))return r=Ee(r,d.mode,g,null),r.return=d,r;if(typeof r.then=="function")return R(d,sn(r),g);if(r.$$typeof===T)return R(d,ku(d,r),g);on(d,r)}return null}function b(d,r,g,A){var Q=r!==null?r.key:null;if(typeof g=="string"&&g!==""||typeof g=="number"||typeof g=="bigint")return Q!==null?null:f(d,r,""+g,A);if(typeof g=="object"&&g!==null){switch(g.$$typeof){case L:return g.key===Q?c(d,r,g,A):null;case W:return g.key===Q?m(d,r,g,A):null;case z:return Q=g._init,g=Q(g._payload),b(d,r,g,A)}if(Tt(g)||ct(g))return Q!==null?null:M(d,r,g,A,null);if(typeof g.then=="function")return b(d,r,sn(g),A);if(g.$$typeof===T)return b(d,r,ku(d,g),A);on(d,g)}return null}function O(d,r,g,A,Q){if(typeof A=="string"&&A!==""||typeof A=="number"||typeof A=="bigint")return d=d.get(g)||null,f(r,d,""+A,Q);if(typeof A=="object"&&A!==null){switch(A.$$typeof){case L:return d=d.get(A.key===null?g:A.key)||null,c(r,d,A,Q);case W:return d=d.get(A.key===null?g:A.key)||null,m(r,d,A,Q);case z:var ft=A._init;return A=ft(A._payload),O(d,r,g,A,Q)}if(Tt(A)||ct(A))return d=d.get(g)||null,M(r,d,A,Q,null);if(typeof A.then=="function")return O(d,r,g,sn(A),Q);if(A.$$typeof===T)return O(d,r,g,ku(r,A),Q);on(r,A)}return null}function I(d,r,g,A){for(var Q=null,ft=null,w=r,k=r=0,Qt=null;w!==null&&k<g.length;k++){w.index>k?(Qt=w,w=null):Qt=w.sibling;var dt=b(d,w,g[k],A);if(dt===null){w===null&&(w=Qt);break}t&&w&&dt.alternate===null&&l(d,w),r=n(dt,r,k),ft===null?Q=dt:ft.sibling=dt,ft=dt,w=Qt}if(k===g.length)return e(d,w),ht&&_e(d,k),Q;if(w===null){for(;k<g.length;k++)w=R(d,g[k],A),w!==null&&(r=n(w,r,k),ft===null?Q=w:ft.sibling=w,ft=w);return ht&&_e(d,k),Q}for(w=a(w);k<g.length;k++)Qt=O(w,d,k,g[k],A),Qt!==null&&(t&&Qt.alternate!==null&&w.delete(Qt.key===null?k:Qt.key),r=n(Qt,r,k),ft===null?Q=Qt:ft.sibling=Qt,ft=Qt);return t&&w.forEach(function(ye){return l(d,ye)}),ht&&_e(d,k),Q}function $(d,r,g,A){if(g==null)throw Error(h(151));for(var Q=null,ft=null,w=r,k=r=0,Qt=null,dt=g.next();w!==null&&!dt.done;k++,dt=g.next()){w.index>k?(Qt=w,w=null):Qt=w.sibling;var ye=b(d,w,dt.value,A);if(ye===null){w===null&&(w=Qt);break}t&&w&&ye.alternate===null&&l(d,w),r=n(ye,r,k),ft===null?Q=ye:ft.sibling=ye,ft=ye,w=Qt}if(dt.done)return e(d,w),ht&&_e(d,k),Q;if(w===null){for(;!dt.done;k++,dt=g.next())dt=R(d,dt.value,A),dt!==null&&(r=n(dt,r,k),ft===null?Q=dt:ft.sibling=dt,ft=dt);return ht&&_e(d,k),Q}for(w=a(w);!dt.done;k++,dt=g.next())dt=O(w,d,k,dt.value,A),dt!==null&&(t&&dt.alternate!==null&&w.delete(dt.key===null?k:dt.key),r=n(dt,r,k),ft===null?Q=dt:ft.sibling=dt,ft=dt);return t&&w.forEach(function(e0){return l(d,e0)}),ht&&_e(d,k),Q}function bt(d,r,g,A){if(typeof g=="object"&&g!==null&&g.type===tt&&g.key===null&&(g=g.props.children),typeof g=="object"&&g!==null){switch(g.$$typeof){case L:t:{for(var Q=g.key;r!==null;){if(r.key===Q){if(Q=g.type,Q===tt){if(r.tag===7){e(d,r.sibling),A=u(r,g.props.children),A.return=d,d=A;break t}}else if(r.elementType===Q||typeof Q=="object"&&Q!==null&&Q.$$typeof===z&&ms(Q)===r.type){e(d,r.sibling),A=u(r,g.props),Pa(A,g),A.return=d,d=A;break t}e(d,r);break}else l(d,r);r=r.sibling}g.type===tt?(A=Ee(g.props.children,d.mode,A,g.key),A.return=d,d=A):(A=wu(g.type,g.key,g.props,null,d.mode,A),Pa(A,g),A.return=d,d=A)}return i(d);case W:t:{for(Q=g.key;r!==null;){if(r.key===Q)if(r.tag===4&&r.stateNode.containerInfo===g.containerInfo&&r.stateNode.implementation===g.implementation){e(d,r.sibling),A=u(r,g.children||[]),A.return=d,d=A;break t}else{e(d,r);break}else l(d,r);r=r.sibling}A=Ri(g,d.mode,A),A.return=d,d=A}return i(d);case z:return Q=g._init,g=Q(g._payload),bt(d,r,g,A)}if(Tt(g))return I(d,r,g,A);if(ct(g)){if(Q=ct(g),typeof Q!="function")throw Error(h(150));return g=Q.call(g),$(d,r,g,A)}if(typeof g.then=="function")return bt(d,r,sn(g),A);if(g.$$typeof===T)return bt(d,r,ku(d,g),A);on(d,g)}return typeof g=="string"&&g!==""||typeof g=="number"||typeof g=="bigint"?(g=""+g,r!==null&&r.tag===6?(e(d,r.sibling),A=u(r,g),A.return=d,d=A):(e(d,r),A=Ai(g,d.mode,A),A.return=d,d=A),i(d)):e(d,r)}return function(d,r,g,A){try{Fa=0;var Q=bt(d,r,g,A);return fa=null,Q}catch(w){if(w===Za||w===Pu)throw w;var ft=ul(29,w,null,d.mode);return ft.lanes=A,ft.return=d,ft}finally{}}}var ca=ps(!0),Ss=ps(!1),gl=N(null),zl=null;function te(t){var l=t.alternate;X(Ct,Ct.current&1),X(gl,t),zl===null&&(l===null||aa.current!==null||l.memoizedState!==null)&&(zl=t)}function bs(t){if(t.tag===22){if(X(Ct,Ct.current),X(gl,t),zl===null){var l=t.alternate;l!==null&&l.memoizedState!==null&&(zl=t)}}else le()}function le(){X(Ct,Ct.current),X(gl,gl.current)}function Xl(t){G(gl),zl===t&&(zl=null),G(Ct)}var Ct=N(0);function dn(t){for(var l=t;l!==null;){if(l.tag===13){var e=l.memoizedState;if(e!==null&&(e=e.dehydrated,e===null||e.data==="$?"||Pf(e)))return l}else if(l.tag===19&&l.memoizedProps.revealOrder!==void 0){if((l.flags&128)!==0)return l}else if(l.child!==null){l.child.return=l,l=l.child;continue}if(l===t)break;for(;l.sibling===null;){if(l.return===null||l.return===t)return null;l=l.return}l.sibling.return=l.return,l=l.sibling}return null}function rf(t,l,e,a){l=t.memoizedState,e=e(a,l),e=e==null?l:H({},l,e),t.memoizedState=e,t.lanes===0&&(t.updateQueue.baseState=e)}var sf={enqueueSetState:function(t,l,e){t=t._reactInternals;var a=cl(),u=Fl(a);u.payload=l,e!=null&&(u.callback=e),l=Pl(t,u,a),l!==null&&(rl(l,t,a),La(l,t,a))},enqueueReplaceState:function(t,l,e){t=t._reactInternals;var a=cl(),u=Fl(a);u.tag=1,u.payload=l,e!=null&&(u.callback=e),l=Pl(t,u,a),l!==null&&(rl(l,t,a),La(l,t,a))},enqueueForceUpdate:function(t,l){t=t._reactInternals;var e=cl(),a=Fl(e);a.tag=2,l!=null&&(a.callback=l),l=Pl(t,a,e),l!==null&&(rl(l,t,e),La(l,t,e))}};function Os(t,l,e,a,u,n,i){return t=t.stateNode,typeof t.shouldComponentUpdate=="function"?t.shouldComponentUpdate(a,n,i):l.prototype&&l.prototype.isPureReactComponent?!qa(e,a)||!qa(u,n):!0}function Ts(t,l,e,a){t=l.state,typeof l.componentWillReceiveProps=="function"&&l.componentWillReceiveProps(e,a),typeof l.UNSAFE_componentWillReceiveProps=="function"&&l.UNSAFE_componentWillReceiveProps(e,a),l.state!==t&&sf.enqueueReplaceState(l,l.state,null)}function xe(t,l){var e=l;if("ref"in l){e={};for(var a in l)a!=="ref"&&(e[a]=l[a])}if(t=t.defaultProps){e===l&&(e=H({},e));for(var u in t)e[u]===void 0&&(e[u]=t[u])}return e}var hn=typeof reportError=="function"?reportError:function(t){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var l=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof t=="object"&&t!==null&&typeof t.message=="string"?String(t.message):String(t),error:t});if(!window.dispatchEvent(l))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",t);return}console.error(t)};function Ds(t){hn(t)}function Es(t){console.error(t)}function zs(t){hn(t)}function vn(t,l){try{var e=t.onUncaughtError;e(l.value,{componentStack:l.stack})}catch(a){setTimeout(function(){throw a})}}function _s(t,l,e){try{var a=t.onCaughtError;a(e.value,{componentStack:e.stack,errorBoundary:l.tag===1?l.stateNode:null})}catch(u){setTimeout(function(){throw u})}}function of(t,l,e){return e=Fl(e),e.tag=3,e.payload={element:null},e.callback=function(){vn(t,l)},e}function Ms(t){return t=Fl(t),t.tag=3,t}function As(t,l,e,a){var u=e.type.getDerivedStateFromError;if(typeof u=="function"){var n=a.value;t.payload=function(){return u(n)},t.callback=function(){_s(l,e,a)}}var i=e.stateNode;i!==null&&typeof i.componentDidCatch=="function"&&(t.callback=function(){_s(l,e,a),typeof u!="function"&&(fe===null?fe=new Set([this]):fe.add(this));var f=a.stack;this.componentDidCatch(a.value,{componentStack:f!==null?f:""})})}function ev(t,l,e,a,u){if(e.flags|=32768,a!==null&&typeof a=="object"&&typeof a.then=="function"){if(l=e.alternate,l!==null&&ja(l,e,u,!0),e=gl.current,e!==null){switch(e.tag){case 13:return zl===null?Yf():e.alternate===null&&Rt===0&&(Rt=3),e.flags&=-257,e.flags|=65536,e.lanes=u,a===ji?e.flags|=16384:(l=e.updateQueue,l===null?e.updateQueue=new Set([a]):l.add(a),Cf(t,a,u)),!1;case 22:return e.flags|=65536,a===ji?e.flags|=16384:(l=e.updateQueue,l===null?(l={transitions:null,markerInstances:null,retryQueue:new Set([a])},e.updateQueue=l):(e=l.retryQueue,e===null?l.retryQueue=new Set([a]):e.add(a)),Cf(t,a,u)),!1}throw Error(h(435,e.tag))}return Cf(t,a,u),Yf(),!1}if(ht)return l=gl.current,l!==null?((l.flags&65536)===0&&(l.flags|=256),l.flags|=65536,l.lanes=u,a!==Hi&&(t=Error(h(422),{cause:a}),Xa(dl(t,e)))):(a!==Hi&&(l=Error(h(423),{cause:a}),Xa(dl(l,e))),t=t.current.alternate,t.flags|=65536,u&=-u,t.lanes|=u,a=dl(a,e),u=of(t.stateNode,a,u),Zi(t,u),Rt!==4&&(Rt=2)),!1;var n=Error(h(520),{cause:a});if(n=dl(n,e),nu===null?nu=[n]:nu.push(n),Rt!==4&&(Rt=2),l===null)return!0;a=dl(a,e),e=l;do{switch(e.tag){case 3:return e.flags|=65536,t=u&-u,e.lanes|=t,t=of(e.stateNode,a,t),Zi(e,t),!1;case 1:if(l=e.type,n=e.stateNode,(e.flags&128)===0&&(typeof l.getDerivedStateFromError=="function"||n!==null&&typeof n.componentDidCatch=="function"&&(fe===null||!fe.has(n))))return e.flags|=65536,u&=-u,e.lanes|=u,u=Ms(u),As(u,t,e,a),Zi(e,u),!1}e=e.return}while(e!==null);return!1}var Rs=Error(h(461)),jt=!1;function Zt(t,l,e,a){l.child=t===null?Ss(l,null,e,a):ca(l,t.child,e,a)}function Us(t,l,e,a,u){e=e.render;var n=l.ref;if("ref"in a){var i={};for(var f in a)f!=="ref"&&(i[f]=a[f])}else i=a;return Ue(l),a=Ji(t,l,e,i,n,u),f=Wi(),t!==null&&!jt?($i(t,l,u),jl(t,l,u)):(ht&&f&&Ui(l),l.flags|=1,Zt(t,l,a,u),l.child)}function Ns(t,l,e,a,u){if(t===null){var n=e.type;return typeof n=="function"&&!Mi(n)&&n.defaultProps===void 0&&e.compare===null?(l.tag=15,l.type=n,Hs(t,l,n,a,u)):(t=wu(e.type,null,a,l,l.mode,u),t.ref=l.ref,t.return=l,l.child=t)}if(n=t.child,!Sf(t,u)){var i=n.memoizedProps;if(e=e.compare,e=e!==null?e:qa,e(i,a)&&t.ref===l.ref)return jl(t,l,u)}return l.flags|=1,t=Hl(n,a),t.ref=l.ref,t.return=l,l.child=t}function Hs(t,l,e,a,u){if(t!==null){var n=t.memoizedProps;if(qa(n,a)&&t.ref===l.ref)if(jt=!1,l.pendingProps=a=n,Sf(t,u))(t.flags&131072)!==0&&(jt=!0);else return l.lanes=t.lanes,jl(t,l,u)}return df(t,l,e,a,u)}function xs(t,l,e){var a=l.pendingProps,u=a.children,n=t!==null?t.memoizedState:null;if(a.mode==="hidden"){if((l.flags&128)!==0){if(a=n!==null?n.baseLanes|e:e,t!==null){for(u=l.child=t.child,n=0;u!==null;)n=n|u.lanes|u.childLanes,u=u.sibling;l.childLanes=n&~a}else l.childLanes=0,l.child=null;return qs(t,l,a,e)}if((e&536870912)!==0)l.memoizedState={baseLanes:0,cachePool:null},t!==null&&Fu(l,n!==null?n.cachePool:null),n!==null?Hr(l,n):Li(),bs(l);else return l.lanes=l.childLanes=536870912,qs(t,l,n!==null?n.baseLanes|e:e,e)}else n!==null?(Fu(l,n.cachePool),Hr(l,n),le(),l.memoizedState=null):(t!==null&&Fu(l,null),Li(),le());return Zt(t,l,u,e),l.child}function qs(t,l,e,a){var u=Xi();return u=u===null?null:{parent:Bt._currentValue,pool:u},l.memoizedState={baseLanes:e,cachePool:u},t!==null&&Fu(l,null),Li(),bs(l),t!==null&&ja(t,l,a,!0),null}function yn(t,l){var e=l.ref;if(e===null)t!==null&&t.ref!==null&&(l.flags|=4194816);else{if(typeof e!="function"&&typeof e!="object")throw Error(h(284));(t===null||t.ref!==e)&&(l.flags|=4194816)}}function df(t,l,e,a,u){return Ue(l),e=Ji(t,l,e,a,void 0,u),a=Wi(),t!==null&&!jt?($i(t,l,u),jl(t,l,u)):(ht&&a&&Ui(l),l.flags|=1,Zt(t,l,e,u),l.child)}function Ys(t,l,e,a,u,n){return Ue(l),l.updateQueue=null,e=qr(l,a,e,u),xr(t),a=Wi(),t!==null&&!jt?($i(t,l,n),jl(t,l,n)):(ht&&a&&Ui(l),l.flags|=1,Zt(t,l,e,n),l.child)}function Bs(t,l,e,a,u){if(Ue(l),l.stateNode===null){var n=Pe,i=e.contextType;typeof i=="object"&&i!==null&&(n=wt(i)),n=new e(a,n),l.memoizedState=n.state!==null&&n.state!==void 0?n.state:null,n.updater=sf,l.stateNode=n,n._reactInternals=l,n=l.stateNode,n.props=a,n.state=l.memoizedState,n.refs={},Gi(l),i=e.contextType,n.context=typeof i=="object"&&i!==null?wt(i):Pe,n.state=l.memoizedState,i=e.getDerivedStateFromProps,typeof i=="function"&&(rf(l,e,i,a),n.state=l.memoizedState),typeof e.getDerivedStateFromProps=="function"||typeof n.getSnapshotBeforeUpdate=="function"||typeof n.UNSAFE_componentWillMount!="function"&&typeof n.componentWillMount!="function"||(i=n.state,typeof n.componentWillMount=="function"&&n.componentWillMount(),typeof n.UNSAFE_componentWillMount=="function"&&n.UNSAFE_componentWillMount(),i!==n.state&&sf.enqueueReplaceState(n,n.state,null),wa(l,a,n,u),Ka(),n.state=l.memoizedState),typeof n.componentDidMount=="function"&&(l.flags|=4194308),a=!0}else if(t===null){n=l.stateNode;var f=l.memoizedProps,c=xe(e,f);n.props=c;var m=n.context,M=e.contextType;i=Pe,typeof M=="object"&&M!==null&&(i=wt(M));var R=e.getDerivedStateFromProps;M=typeof R=="function"||typeof n.getSnapshotBeforeUpdate=="function",f=l.pendingProps!==f,M||typeof n.UNSAFE_componentWillReceiveProps!="function"&&typeof n.componentWillReceiveProps!="function"||(f||m!==i)&&Ts(l,n,a,i),kl=!1;var b=l.memoizedState;n.state=b,wa(l,a,n,u),Ka(),m=l.memoizedState,f||b!==m||kl?(typeof R=="function"&&(rf(l,e,R,a),m=l.memoizedState),(c=kl||Os(l,e,c,a,b,m,i))?(M||typeof n.UNSAFE_componentWillMount!="function"&&typeof n.componentWillMount!="function"||(typeof n.componentWillMount=="function"&&n.componentWillMount(),typeof n.UNSAFE_componentWillMount=="function"&&n.UNSAFE_componentWillMount()),typeof n.componentDidMount=="function"&&(l.flags|=4194308)):(typeof n.componentDidMount=="function"&&(l.flags|=4194308),l.memoizedProps=a,l.memoizedState=m),n.props=a,n.state=m,n.context=i,a=c):(typeof n.componentDidMount=="function"&&(l.flags|=4194308),a=!1)}else{n=l.stateNode,Qi(t,l),i=l.memoizedProps,M=xe(e,i),n.props=M,R=l.pendingProps,b=n.context,m=e.contextType,c=Pe,typeof m=="object"&&m!==null&&(c=wt(m)),f=e.getDerivedStateFromProps,(m=typeof f=="function"||typeof n.getSnapshotBeforeUpdate=="function")||typeof n.UNSAFE_componentWillReceiveProps!="function"&&typeof n.componentWillReceiveProps!="function"||(i!==R||b!==c)&&Ts(l,n,a,c),kl=!1,b=l.memoizedState,n.state=b,wa(l,a,n,u),Ka();var O=l.memoizedState;i!==R||b!==O||kl||t!==null&&t.dependencies!==null&&$u(t.dependencies)?(typeof f=="function"&&(rf(l,e,f,a),O=l.memoizedState),(M=kl||Os(l,e,M,a,b,O,c)||t!==null&&t.dependencies!==null&&$u(t.dependencies))?(m||typeof n.UNSAFE_componentWillUpdate!="function"&&typeof n.componentWillUpdate!="function"||(typeof n.componentWillUpdate=="function"&&n.componentWillUpdate(a,O,c),typeof n.UNSAFE_componentWillUpdate=="function"&&n.UNSAFE_componentWillUpdate(a,O,c)),typeof n.componentDidUpdate=="function"&&(l.flags|=4),typeof n.getSnapshotBeforeUpdate=="function"&&(l.flags|=1024)):(typeof n.componentDidUpdate!="function"||i===t.memoizedProps&&b===t.memoizedState||(l.flags|=4),typeof n.getSnapshotBeforeUpdate!="function"||i===t.memoizedProps&&b===t.memoizedState||(l.flags|=1024),l.memoizedProps=a,l.memoizedState=O),n.props=a,n.state=O,n.context=c,a=M):(typeof n.componentDidUpdate!="function"||i===t.memoizedProps&&b===t.memoizedState||(l.flags|=4),typeof n.getSnapshotBeforeUpdate!="function"||i===t.memoizedProps&&b===t.memoizedState||(l.flags|=1024),a=!1)}return n=a,yn(t,l),a=(l.flags&128)!==0,n||a?(n=l.stateNode,e=a&&typeof e.getDerivedStateFromError!="function"?null:n.render(),l.flags|=1,t!==null&&a?(l.child=ca(l,t.child,null,u),l.child=ca(l,null,e,u)):Zt(t,l,e,u),l.memoizedState=n.state,t=l.child):t=jl(t,l,u),t}function Cs(t,l,e,a){return Ca(),l.flags|=256,Zt(t,l,e,a),l.child}var hf={dehydrated:null,treeContext:null,retryLane:0,hydrationErrors:null};function vf(t){return{baseLanes:t,cachePool:Er()}}function yf(t,l,e){return t=t!==null?t.childLanes&~e:0,l&&(t|=ml),t}function Xs(t,l,e){var a=l.pendingProps,u=!1,n=(l.flags&128)!==0,i;if((i=n)||(i=t!==null&&t.memoizedState===null?!1:(Ct.current&2)!==0),i&&(u=!0,l.flags&=-129),i=(l.flags&32)!==0,l.flags&=-33,t===null){if(ht){if(u?te(l):le(),ht){var f=At,c;if(c=f){t:{for(c=f,f=El;c.nodeType!==8;){if(!f){f=null;break t}if(c=Tl(c.nextSibling),c===null){f=null;break t}}f=c}f!==null?(l.memoizedState={dehydrated:f,treeContext:ze!==null?{id:xl,overflow:ql}:null,retryLane:536870912,hydrationErrors:null},c=ul(18,null,null,0),c.stateNode=f,c.return=l,l.child=c,Wt=l,At=null,c=!0):c=!1}c||Ae(l)}if(f=l.memoizedState,f!==null&&(f=f.dehydrated,f!==null))return Pf(f)?l.lanes=32:l.lanes=536870912,null;Xl(l)}return f=a.children,a=a.fallback,u?(le(),u=l.mode,f=gn({mode:"hidden",children:f},u),a=Ee(a,u,e,null),f.return=l,a.return=l,f.sibling=a,l.child=f,u=l.child,u.memoizedState=vf(e),u.childLanes=yf(t,i,e),l.memoizedState=hf,a):(te(l),gf(l,f))}if(c=t.memoizedState,c!==null&&(f=c.dehydrated,f!==null)){if(n)l.flags&256?(te(l),l.flags&=-257,l=mf(t,l,e)):l.memoizedState!==null?(le(),l.child=t.child,l.flags|=128,l=null):(le(),u=a.fallback,f=l.mode,a=gn({mode:"visible",children:a.children},f),u=Ee(u,f,e,null),u.flags|=2,a.return=l,u.return=l,a.sibling=u,l.child=a,ca(l,t.child,null,e),a=l.child,a.memoizedState=vf(e),a.childLanes=yf(t,i,e),l.memoizedState=hf,l=u);else if(te(l),Pf(f)){if(i=f.nextSibling&&f.nextSibling.dataset,i)var m=i.dgst;i=m,a=Error(h(419)),a.stack="",a.digest=i,Xa({value:a,source:null,stack:null}),l=mf(t,l,e)}else if(jt||ja(t,l,e,!1),i=(e&t.childLanes)!==0,jt||i){if(i=Dt,i!==null&&(a=e&-e,a=(a&42)!==0?1:Pn(a),a=(a&(i.suspendedLanes|e))!==0?0:a,a!==0&&a!==c.retryLane))throw c.retryLane=a,Fe(t,a),rl(i,t,a),Rs;f.data==="$?"||Yf(),l=mf(t,l,e)}else f.data==="$?"?(l.flags|=192,l.child=t.child,l=null):(t=c.treeContext,At=Tl(f.nextSibling),Wt=l,ht=!0,Me=null,El=!1,t!==null&&(vl[yl++]=xl,vl[yl++]=ql,vl[yl++]=ze,xl=t.id,ql=t.overflow,ze=l),l=gf(l,a.children),l.flags|=4096);return l}return u?(le(),u=a.fallback,f=l.mode,c=t.child,m=c.sibling,a=Hl(c,{mode:"hidden",children:a.children}),a.subtreeFlags=c.subtreeFlags&65011712,m!==null?u=Hl(m,u):(u=Ee(u,f,e,null),u.flags|=2),u.return=l,a.return=l,a.sibling=u,l.child=a,a=u,u=l.child,f=t.child.memoizedState,f===null?f=vf(e):(c=f.cachePool,c!==null?(m=Bt._currentValue,c=c.parent!==m?{parent:m,pool:m}:c):c=Er(),f={baseLanes:f.baseLanes|e,cachePool:c}),u.memoizedState=f,u.childLanes=yf(t,i,e),l.memoizedState=hf,a):(te(l),e=t.child,t=e.sibling,e=Hl(e,{mode:"visible",children:a.children}),e.return=l,e.sibling=null,t!==null&&(i=l.deletions,i===null?(l.deletions=[t],l.flags|=16):i.push(t)),l.child=e,l.memoizedState=null,e)}function gf(t,l){return l=gn({mode:"visible",children:l},t.mode),l.return=t,t.child=l}function gn(t,l){return t=ul(22,t,null,l),t.lanes=0,t.stateNode={_visibility:1,_pendingMarkers:null,_retryCache:null,_transitions:null},t}function mf(t,l,e){return ca(l,t.child,null,e),t=gf(l,l.pendingProps.children),t.flags|=2,l.memoizedState=null,t}function js(t,l,e){t.lanes|=l;var a=t.alternate;a!==null&&(a.lanes|=l),qi(t.return,l,e)}function pf(t,l,e,a,u){var n=t.memoizedState;n===null?t.memoizedState={isBackwards:l,rendering:null,renderingStartTime:0,last:a,tail:e,tailMode:u}:(n.isBackwards=l,n.rendering=null,n.renderingStartTime=0,n.last=a,n.tail=e,n.tailMode=u)}function Gs(t,l,e){var a=l.pendingProps,u=a.revealOrder,n=a.tail;if(Zt(t,l,a.children,e),a=Ct.current,(a&2)!==0)a=a&1|2,l.flags|=128;else{if(t!==null&&(t.flags&128)!==0)t:for(t=l.child;t!==null;){if(t.tag===13)t.memoizedState!==null&&js(t,e,l);else if(t.tag===19)js(t,e,l);else if(t.child!==null){t.child.return=t,t=t.child;continue}if(t===l)break t;for(;t.sibling===null;){if(t.return===null||t.return===l)break t;t=t.return}t.sibling.return=t.return,t=t.sibling}a&=1}switch(X(Ct,a),u){case"forwards":for(e=l.child,u=null;e!==null;)t=e.alternate,t!==null&&dn(t)===null&&(u=e),e=e.sibling;e=u,e===null?(u=l.child,l.child=null):(u=e.sibling,e.sibling=null),pf(l,!1,u,e,n);break;case"backwards":for(e=null,u=l.child,l.child=null;u!==null;){if(t=u.alternate,t!==null&&dn(t)===null){l.child=u;break}t=u.sibling,u.sibling=e,e=u,u=t}pf(l,!0,e,null,n);break;case"together":pf(l,!1,null,null,void 0);break;default:l.memoizedState=null}return l.child}function jl(t,l,e){if(t!==null&&(l.dependencies=t.dependencies),ie|=l.lanes,(e&l.childLanes)===0)if(t!==null){if(ja(t,l,e,!1),(e&l.childLanes)===0)return null}else return null;if(t!==null&&l.child!==t.child)throw Error(h(153));if(l.child!==null){for(t=l.child,e=Hl(t,t.pendingProps),l.child=e,e.return=l;t.sibling!==null;)t=t.sibling,e=e.sibling=Hl(t,t.pendingProps),e.return=l;e.sibling=null}return l.child}function Sf(t,l){return(t.lanes&l)!==0?!0:(t=t.dependencies,!!(t!==null&&$u(t)))}function av(t,l,e){switch(l.tag){case 3:zt(l,l.stateNode.containerInfo),$l(l,Bt,t.memoizedState.cache),Ca();break;case 27:case 5:Jn(l);break;case 4:zt(l,l.stateNode.containerInfo);break;case 10:$l(l,l.type,l.memoizedProps.value);break;case 13:var a=l.memoizedState;if(a!==null)return a.dehydrated!==null?(te(l),l.flags|=128,null):(e&l.child.childLanes)!==0?Xs(t,l,e):(te(l),t=jl(t,l,e),t!==null?t.sibling:null);te(l);break;case 19:var u=(t.flags&128)!==0;if(a=(e&l.childLanes)!==0,a||(ja(t,l,e,!1),a=(e&l.childLanes)!==0),u){if(a)return Gs(t,l,e);l.flags|=128}if(u=l.memoizedState,u!==null&&(u.rendering=null,u.tail=null,u.lastEffect=null),X(Ct,Ct.current),a)break;return null;case 22:case 23:return l.lanes=0,xs(t,l,e);case 24:$l(l,Bt,t.memoizedState.cache)}return jl(t,l,e)}function Qs(t,l,e){if(t!==null)if(t.memoizedProps!==l.pendingProps)jt=!0;else{if(!Sf(t,e)&&(l.flags&128)===0)return jt=!1,av(t,l,e);jt=(t.flags&131072)!==0}else jt=!1,ht&&(l.flags&1048576)!==0&&mr(l,Wu,l.index);switch(l.lanes=0,l.tag){case 16:t:{t=l.pendingProps;var a=l.elementType,u=a._init;if(a=u(a._payload),l.type=a,typeof a=="function")Mi(a)?(t=xe(a,t),l.tag=1,l=Bs(null,l,a,t,e)):(l.tag=0,l=df(null,l,a,t,e));else{if(a!=null){if(u=a.$$typeof,u===E){l.tag=11,l=Us(null,l,a,t,e);break t}else if(u===s){l.tag=14,l=Ns(null,l,a,t,e);break t}}throw l=Et(a)||a,Error(h(306,l,""))}}return l;case 0:return df(t,l,l.type,l.pendingProps,e);case 1:return a=l.type,u=xe(a,l.pendingProps),Bs(t,l,a,u,e);case 3:t:{if(zt(l,l.stateNode.containerInfo),t===null)throw Error(h(387));a=l.pendingProps;var n=l.memoizedState;u=n.element,Qi(t,l),wa(l,a,null,e);var i=l.memoizedState;if(a=i.cache,$l(l,Bt,a),a!==n.cache&&Yi(l,[Bt],e,!0),Ka(),a=i.element,n.isDehydrated)if(n={element:a,isDehydrated:!1,cache:i.cache},l.updateQueue.baseState=n,l.memoizedState=n,l.flags&256){l=Cs(t,l,a,e);break t}else if(a!==u){u=dl(Error(h(424)),l),Xa(u),l=Cs(t,l,a,e);break t}else{switch(t=l.stateNode.containerInfo,t.nodeType){case 9:t=t.body;break;default:t=t.nodeName==="HTML"?t.ownerDocument.body:t}for(At=Tl(t.firstChild),Wt=l,ht=!0,Me=null,El=!0,e=Ss(l,null,a,e),l.child=e;e;)e.flags=e.flags&-3|4096,e=e.sibling}else{if(Ca(),a===u){l=jl(t,l,e);break t}Zt(t,l,a,e)}l=l.child}return l;case 26:return yn(t,l),t===null?(e=wo(l.type,null,l.pendingProps,null))?l.memoizedState=e:ht||(e=l.type,t=l.pendingProps,a=Un(at.current).createElement(e),a[Kt]=l,a[$t]=t,Lt(a,e,t),Xt(a),l.stateNode=a):l.memoizedState=wo(l.type,t.memoizedProps,l.pendingProps,t.memoizedState),null;case 27:return Jn(l),t===null&&ht&&(a=l.stateNode=Vo(l.type,l.pendingProps,at.current),Wt=l,El=!0,u=At,se(l.type)?(If=u,At=Tl(a.firstChild)):At=u),Zt(t,l,l.pendingProps.children,e),yn(t,l),t===null&&(l.flags|=4194304),l.child;case 5:return t===null&&ht&&((u=a=At)&&(a=Nv(a,l.type,l.pendingProps,El),a!==null?(l.stateNode=a,Wt=l,At=Tl(a.firstChild),El=!1,u=!0):u=!1),u||Ae(l)),Jn(l),u=l.type,n=l.pendingProps,i=t!==null?t.memoizedProps:null,a=n.children,$f(u,n)?a=null:i!==null&&$f(u,i)&&(l.flags|=32),l.memoizedState!==null&&(u=Ji(t,l,$h,null,null,e),vu._currentValue=u),yn(t,l),Zt(t,l,a,e),l.child;case 6:return t===null&&ht&&((t=e=At)&&(e=Hv(e,l.pendingProps,El),e!==null?(l.stateNode=e,Wt=l,At=null,t=!0):t=!1),t||Ae(l)),null;case 13:return Xs(t,l,e);case 4:return zt(l,l.stateNode.containerInfo),a=l.pendingProps,t===null?l.child=ca(l,null,a,e):Zt(t,l,a,e),l.child;case 11:return Us(t,l,l.type,l.pendingProps,e);case 7:return Zt(t,l,l.pendingProps,e),l.child;case 8:return Zt(t,l,l.pendingProps.children,e),l.child;case 12:return Zt(t,l,l.pendingProps.children,e),l.child;case 10:return a=l.pendingProps,$l(l,l.type,a.value),Zt(t,l,a.children,e),l.child;case 9:return u=l.type._context,a=l.pendingProps.children,Ue(l),u=wt(u),a=a(u),l.flags|=1,Zt(t,l,a,e),l.child;case 14:return Ns(t,l,l.type,l.pendingProps,e);case 15:return Hs(t,l,l.type,l.pendingProps,e);case 19:return Gs(t,l,e);case 31:return a=l.pendingProps,e=l.mode,a={mode:a.mode,children:a.children},t===null?(e=gn(a,e),e.ref=l.ref,l.child=e,e.return=l,l=e):(e=Hl(t.child,a),e.ref=l.ref,l.child=e,e.return=l,l=e),l;case 22:return xs(t,l,e);case 24:return Ue(l),a=wt(Bt),t===null?(u=Xi(),u===null&&(u=Dt,n=Bi(),u.pooledCache=n,n.refCount++,n!==null&&(u.pooledCacheLanes|=e),u=n),l.memoizedState={parent:a,cache:u},Gi(l),$l(l,Bt,u)):((t.lanes&e)!==0&&(Qi(t,l),wa(l,null,null,e),Ka()),u=t.memoizedState,n=l.memoizedState,u.parent!==a?(u={parent:a,cache:a},l.memoizedState=u,l.lanes===0&&(l.memoizedState=l.updateQueue.baseState=u),$l(l,Bt,a)):(a=n.cache,$l(l,Bt,a),a!==u.cache&&Yi(l,[Bt],e,!0))),Zt(t,l,l.pendingProps.children,e),l.child;case 29:throw l.pendingProps}throw Error(h(156,l.tag))}function Gl(t){t.flags|=4}function Zs(t,l){if(l.type!=="stylesheet"||(l.state.loading&4)!==0)t.flags&=-16777217;else if(t.flags|=16777216,!Fo(l)){if(l=gl.current,l!==null&&((ot&4194048)===ot?zl!==null:(ot&62914560)!==ot&&(ot&536870912)===0||l!==zl))throw Va=ji,zr;t.flags|=8192}}function mn(t,l){l!==null&&(t.flags|=4),t.flags&16384&&(l=t.tag!==22?bc():536870912,t.lanes|=l,da|=l)}function Ia(t,l){if(!ht)switch(t.tailMode){case"hidden":l=t.tail;for(var e=null;l!==null;)l.alternate!==null&&(e=l),l=l.sibling;e===null?t.tail=null:e.sibling=null;break;case"collapsed":e=t.tail;for(var a=null;e!==null;)e.alternate!==null&&(a=e),e=e.sibling;a===null?l||t.tail===null?t.tail=null:t.tail.sibling=null:a.sibling=null}}function Mt(t){var l=t.alternate!==null&&t.alternate.child===t.child,e=0,a=0;if(l)for(var u=t.child;u!==null;)e|=u.lanes|u.childLanes,a|=u.subtreeFlags&65011712,a|=u.flags&65011712,u.return=t,u=u.sibling;else for(u=t.child;u!==null;)e|=u.lanes|u.childLanes,a|=u.subtreeFlags,a|=u.flags,u.return=t,u=u.sibling;return t.subtreeFlags|=a,t.childLanes=e,l}function uv(t,l,e){var a=l.pendingProps;switch(Ni(l),l.tag){case 31:case 16:case 15:case 0:case 11:case 7:case 8:case 12:case 9:case 14:return Mt(l),null;case 1:return Mt(l),null;case 3:return e=l.stateNode,a=null,t!==null&&(a=t.memoizedState.cache),l.memoizedState.cache!==a&&(l.flags|=2048),Bl(Bt),Kl(),e.pendingContext&&(e.context=e.pendingContext,e.pendingContext=null),(t===null||t.child===null)&&(Ba(l)?Gl(l):t===null||t.memoizedState.isDehydrated&&(l.flags&256)===0||(l.flags|=1024,br())),Mt(l),null;case 26:return e=l.memoizedState,t===null?(Gl(l),e!==null?(Mt(l),Zs(l,e)):(Mt(l),l.flags&=-16777217)):e?e!==t.memoizedState?(Gl(l),Mt(l),Zs(l,e)):(Mt(l),l.flags&=-16777217):(t.memoizedProps!==a&&Gl(l),Mt(l),l.flags&=-16777217),null;case 27:Mu(l),e=at.current;var u=l.type;if(t!==null&&l.stateNode!=null)t.memoizedProps!==a&&Gl(l);else{if(!a){if(l.stateNode===null)throw Error(h(166));return Mt(l),null}t=lt.current,Ba(l)?pr(l):(t=Vo(u,a,e),l.stateNode=t,Gl(l))}return Mt(l),null;case 5:if(Mu(l),e=l.type,t!==null&&l.stateNode!=null)t.memoizedProps!==a&&Gl(l);else{if(!a){if(l.stateNode===null)throw Error(h(166));return Mt(l),null}if(t=lt.current,Ba(l))pr(l);else{switch(u=Un(at.current),t){case 1:t=u.createElementNS("http://www.w3.org/2000/svg",e);break;case 2:t=u.createElementNS("http://www.w3.org/1998/Math/MathML",e);break;default:switch(e){case"svg":t=u.createElementNS("http://www.w3.org/2000/svg",e);break;case"math":t=u.createElementNS("http://www.w3.org/1998/Math/MathML",e);break;case"script":t=u.createElement("div"),t.innerHTML="<script><\/script>",t=t.removeChild(t.firstChild);break;case"select":t=typeof a.is=="string"?u.createElement("select",{is:a.is}):u.createElement("select"),a.multiple?t.multiple=!0:a.size&&(t.size=a.size);break;default:t=typeof a.is=="string"?u.createElement(e,{is:a.is}):u.createElement(e)}}t[Kt]=l,t[$t]=a;t:for(u=l.child;u!==null;){if(u.tag===5||u.tag===6)t.appendChild(u.stateNode);else if(u.tag!==4&&u.tag!==27&&u.child!==null){u.child.return=u,u=u.child;continue}if(u===l)break t;for(;u.sibling===null;){if(u.return===null||u.return===l)break t;u=u.return}u.sibling.return=u.return,u=u.sibling}l.stateNode=t;t:switch(Lt(t,e,a),e){case"button":case"input":case"select":case"textarea":t=!!a.autoFocus;break t;case"img":t=!0;break t;default:t=!1}t&&Gl(l)}}return Mt(l),l.flags&=-16777217,null;case 6:if(t&&l.stateNode!=null)t.memoizedProps!==a&&Gl(l);else{if(typeof a!="string"&&l.stateNode===null)throw Error(h(166));if(t=at.current,Ba(l)){if(t=l.stateNode,e=l.memoizedProps,a=null,u=Wt,u!==null)switch(u.tag){case 27:case 5:a=u.memoizedProps}t[Kt]=l,t=!!(t.nodeValue===e||a!==null&&a.suppressHydrationWarning===!0||Bo(t.nodeValue,e)),t||Ae(l)}else t=Un(t).createTextNode(a),t[Kt]=l,l.stateNode=t}return Mt(l),null;case 13:if(a=l.memoizedState,t===null||t.memoizedState!==null&&t.memoizedState.dehydrated!==null){if(u=Ba(l),a!==null&&a.dehydrated!==null){if(t===null){if(!u)throw Error(h(318));if(u=l.memoizedState,u=u!==null?u.dehydrated:null,!u)throw Error(h(317));u[Kt]=l}else Ca(),(l.flags&128)===0&&(l.memoizedState=null),l.flags|=4;Mt(l),u=!1}else u=br(),t!==null&&t.memoizedState!==null&&(t.memoizedState.hydrationErrors=u),u=!0;if(!u)return l.flags&256?(Xl(l),l):(Xl(l),null)}if(Xl(l),(l.flags&128)!==0)return l.lanes=e,l;if(e=a!==null,t=t!==null&&t.memoizedState!==null,e){a=l.child,u=null,a.alternate!==null&&a.alternate.memoizedState!==null&&a.alternate.memoizedState.cachePool!==null&&(u=a.alternate.memoizedState.cachePool.pool);var n=null;a.memoizedState!==null&&a.memoizedState.cachePool!==null&&(n=a.memoizedState.cachePool.pool),n!==u&&(a.flags|=2048)}return e!==t&&e&&(l.child.flags|=8192),mn(l,l.updateQueue),Mt(l),null;case 4:return Kl(),t===null&&Lf(l.stateNode.containerInfo),Mt(l),null;case 10:return Bl(l.type),Mt(l),null;case 19:if(G(Ct),u=l.memoizedState,u===null)return Mt(l),null;if(a=(l.flags&128)!==0,n=u.rendering,n===null)if(a)Ia(u,!1);else{if(Rt!==0||t!==null&&(t.flags&128)!==0)for(t=l.child;t!==null;){if(n=dn(t),n!==null){for(l.flags|=128,Ia(u,!1),t=n.updateQueue,l.updateQueue=t,mn(l,t),l.subtreeFlags=0,t=e,e=l.child;e!==null;)gr(e,t),e=e.sibling;return X(Ct,Ct.current&1|2),l.child}t=t.sibling}u.tail!==null&&Dl()>bn&&(l.flags|=128,a=!0,Ia(u,!1),l.lanes=4194304)}else{if(!a)if(t=dn(n),t!==null){if(l.flags|=128,a=!0,t=t.updateQueue,l.updateQueue=t,mn(l,t),Ia(u,!0),u.tail===null&&u.tailMode==="hidden"&&!n.alternate&&!ht)return Mt(l),null}else 2*Dl()-u.renderingStartTime>bn&&e!==536870912&&(l.flags|=128,a=!0,Ia(u,!1),l.lanes=4194304);u.isBackwards?(n.sibling=l.child,l.child=n):(t=u.last,t!==null?t.sibling=n:l.child=n,u.last=n)}return u.tail!==null?(l=u.tail,u.rendering=l,u.tail=l.sibling,u.renderingStartTime=Dl(),l.sibling=null,t=Ct.current,X(Ct,a?t&1|2:t&1),l):(Mt(l),null);case 22:case 23:return Xl(l),Ki(),a=l.memoizedState!==null,t!==null?t.memoizedState!==null!==a&&(l.flags|=8192):a&&(l.flags|=8192),a?(e&536870912)!==0&&(l.flags&128)===0&&(Mt(l),l.subtreeFlags&6&&(l.flags|=8192)):Mt(l),e=l.updateQueue,e!==null&&mn(l,e.retryQueue),e=null,t!==null&&t.memoizedState!==null&&t.memoizedState.cachePool!==null&&(e=t.memoizedState.cachePool.pool),a=null,l.memoizedState!==null&&l.memoizedState.cachePool!==null&&(a=l.memoizedState.cachePool.pool),a!==e&&(l.flags|=2048),t!==null&&G(Ne),null;case 24:return e=null,t!==null&&(e=t.memoizedState.cache),l.memoizedState.cache!==e&&(l.flags|=2048),Bl(Bt),Mt(l),null;case 25:return null;case 30:return null}throw Error(h(156,l.tag))}function nv(t,l){switch(Ni(l),l.tag){case 1:return t=l.flags,t&65536?(l.flags=t&-65537|128,l):null;case 3:return Bl(Bt),Kl(),t=l.flags,(t&65536)!==0&&(t&128)===0?(l.flags=t&-65537|128,l):null;case 26:case 27:case 5:return Mu(l),null;case 13:if(Xl(l),t=l.memoizedState,t!==null&&t.dehydrated!==null){if(l.alternate===null)throw Error(h(340));Ca()}return t=l.flags,t&65536?(l.flags=t&-65537|128,l):null;case 19:return G(Ct),null;case 4:return Kl(),null;case 10:return Bl(l.type),null;case 22:case 23:return Xl(l),Ki(),t!==null&&G(Ne),t=l.flags,t&65536?(l.flags=t&-65537|128,l):null;case 24:return Bl(Bt),null;case 25:return null;default:return null}}function Vs(t,l){switch(Ni(l),l.tag){case 3:Bl(Bt),Kl();break;case 26:case 27:case 5:Mu(l);break;case 4:Kl();break;case 13:Xl(l);break;case 19:G(Ct);break;case 10:Bl(l.type);break;case 22:case 23:Xl(l),Ki(),t!==null&&G(Ne);break;case 24:Bl(Bt)}}function tu(t,l){try{var e=l.updateQueue,a=e!==null?e.lastEffect:null;if(a!==null){var u=a.next;e=u;do{if((e.tag&t)===t){a=void 0;var n=e.create,i=e.inst;a=n(),i.destroy=a}e=e.next}while(e!==u)}}catch(f){Ot(l,l.return,f)}}function ee(t,l,e){try{var a=l.updateQueue,u=a!==null?a.lastEffect:null;if(u!==null){var n=u.next;a=n;do{if((a.tag&t)===t){var i=a.inst,f=i.destroy;if(f!==void 0){i.destroy=void 0,u=l;var c=e,m=f;try{m()}catch(M){Ot(u,c,M)}}}a=a.next}while(a!==n)}}catch(M){Ot(l,l.return,M)}}function Ls(t){var l=t.updateQueue;if(l!==null){var e=t.stateNode;try{Nr(l,e)}catch(a){Ot(t,t.return,a)}}}function Ks(t,l,e){e.props=xe(t.type,t.memoizedProps),e.state=t.memoizedState;try{e.componentWillUnmount()}catch(a){Ot(t,l,a)}}function lu(t,l){try{var e=t.ref;if(e!==null){switch(t.tag){case 26:case 27:case 5:var a=t.stateNode;break;case 30:a=t.stateNode;break;default:a=t.stateNode}typeof e=="function"?t.refCleanup=e(a):e.current=a}}catch(u){Ot(t,l,u)}}function _l(t,l){var e=t.ref,a=t.refCleanup;if(e!==null)if(typeof a=="function")try{a()}catch(u){Ot(t,l,u)}finally{t.refCleanup=null,t=t.alternate,t!=null&&(t.refCleanup=null)}else if(typeof e=="function")try{e(null)}catch(u){Ot(t,l,u)}else e.current=null}function ws(t){var l=t.type,e=t.memoizedProps,a=t.stateNode;try{t:switch(l){case"button":case"input":case"select":case"textarea":e.autoFocus&&a.focus();break t;case"img":e.src?a.src=e.src:e.srcSet&&(a.srcset=e.srcSet)}}catch(u){Ot(t,t.return,u)}}function bf(t,l,e){try{var a=t.stateNode;_v(a,t.type,e,l),a[$t]=l}catch(u){Ot(t,t.return,u)}}function Js(t){return t.tag===5||t.tag===3||t.tag===26||t.tag===27&&se(t.type)||t.tag===4}function Of(t){t:for(;;){for(;t.sibling===null;){if(t.return===null||Js(t.return))return null;t=t.return}for(t.sibling.return=t.return,t=t.sibling;t.tag!==5&&t.tag!==6&&t.tag!==18;){if(t.tag===27&&se(t.type)||t.flags&2||t.child===null||t.tag===4)continue t;t.child.return=t,t=t.child}if(!(t.flags&2))return t.stateNode}}function Tf(t,l,e){var a=t.tag;if(a===5||a===6)t=t.stateNode,l?(e.nodeType===9?e.body:e.nodeName==="HTML"?e.ownerDocument.body:e).insertBefore(t,l):(l=e.nodeType===9?e.body:e.nodeName==="HTML"?e.ownerDocument.body:e,l.appendChild(t),e=e._reactRootContainer,e!=null||l.onclick!==null||(l.onclick=Rn));else if(a!==4&&(a===27&&se(t.type)&&(e=t.stateNode,l=null),t=t.child,t!==null))for(Tf(t,l,e),t=t.sibling;t!==null;)Tf(t,l,e),t=t.sibling}function pn(t,l,e){var a=t.tag;if(a===5||a===6)t=t.stateNode,l?e.insertBefore(t,l):e.appendChild(t);else if(a!==4&&(a===27&&se(t.type)&&(e=t.stateNode),t=t.child,t!==null))for(pn(t,l,e),t=t.sibling;t!==null;)pn(t,l,e),t=t.sibling}function Ws(t){var l=t.stateNode,e=t.memoizedProps;try{for(var a=t.type,u=l.attributes;u.length;)l.removeAttributeNode(u[0]);Lt(l,a,e),l[Kt]=t,l[$t]=e}catch(n){Ot(t,t.return,n)}}var Ql=!1,Nt=!1,Df=!1,$s=typeof WeakSet=="function"?WeakSet:Set,Gt=null;function iv(t,l){if(t=t.containerInfo,Jf=Bn,t=ir(t),bi(t)){if("selectionStart"in t)var e={start:t.selectionStart,end:t.selectionEnd};else t:{e=(e=t.ownerDocument)&&e.defaultView||window;var a=e.getSelection&&e.getSelection();if(a&&a.rangeCount!==0){e=a.anchorNode;var u=a.anchorOffset,n=a.focusNode;a=a.focusOffset;try{e.nodeType,n.nodeType}catch{e=null;break t}var i=0,f=-1,c=-1,m=0,M=0,R=t,b=null;l:for(;;){for(var O;R!==e||u!==0&&R.nodeType!==3||(f=i+u),R!==n||a!==0&&R.nodeType!==3||(c=i+a),R.nodeType===3&&(i+=R.nodeValue.length),(O=R.firstChild)!==null;)b=R,R=O;for(;;){if(R===t)break l;if(b===e&&++m===u&&(f=i),b===n&&++M===a&&(c=i),(O=R.nextSibling)!==null)break;R=b,b=R.parentNode}R=O}e=f===-1||c===-1?null:{start:f,end:c}}else e=null}e=e||{start:0,end:0}}else e=null;for(Wf={focusedElem:t,selectionRange:e},Bn=!1,Gt=l;Gt!==null;)if(l=Gt,t=l.child,(l.subtreeFlags&1024)!==0&&t!==null)t.return=l,Gt=t;else for(;Gt!==null;){switch(l=Gt,n=l.alternate,t=l.flags,l.tag){case 0:break;case 11:case 15:break;case 1:if((t&1024)!==0&&n!==null){t=void 0,e=l,u=n.memoizedProps,n=n.memoizedState,a=e.stateNode;try{var I=xe(e.type,u,e.elementType===e.type);t=a.getSnapshotBeforeUpdate(I,n),a.__reactInternalSnapshotBeforeUpdate=t}catch($){Ot(e,e.return,$)}}break;case 3:if((t&1024)!==0){if(t=l.stateNode.containerInfo,e=t.nodeType,e===9)Ff(t);else if(e===1)switch(t.nodeName){case"HEAD":case"HTML":case"BODY":Ff(t);break;default:t.textContent=""}}break;case 5:case 26:case 27:case 6:case 4:case 17:break;default:if((t&1024)!==0)throw Error(h(163))}if(t=l.sibling,t!==null){t.return=l.return,Gt=t;break}Gt=l.return}}function ks(t,l,e){var a=e.flags;switch(e.tag){case 0:case 11:case 15:ae(t,e),a&4&&tu(5,e);break;case 1:if(ae(t,e),a&4)if(t=e.stateNode,l===null)try{t.componentDidMount()}catch(i){Ot(e,e.return,i)}else{var u=xe(e.type,l.memoizedProps);l=l.memoizedState;try{t.componentDidUpdate(u,l,t.__reactInternalSnapshotBeforeUpdate)}catch(i){Ot(e,e.return,i)}}a&64&&Ls(e),a&512&&lu(e,e.return);break;case 3:if(ae(t,e),a&64&&(t=e.updateQueue,t!==null)){if(l=null,e.child!==null)switch(e.child.tag){case 27:case 5:l=e.child.stateNode;break;case 1:l=e.child.stateNode}try{Nr(t,l)}catch(i){Ot(e,e.return,i)}}break;case 27:l===null&&a&4&&Ws(e);case 26:case 5:ae(t,e),l===null&&a&4&&ws(e),a&512&&lu(e,e.return);break;case 12:ae(t,e);break;case 13:ae(t,e),a&4&&Is(t,e),a&64&&(t=e.memoizedState,t!==null&&(t=t.dehydrated,t!==null&&(e=yv.bind(null,e),xv(t,e))));break;case 22:if(a=e.memoizedState!==null||Ql,!a){l=l!==null&&l.memoizedState!==null||Nt,u=Ql;var n=Nt;Ql=a,(Nt=l)&&!n?ue(t,e,(e.subtreeFlags&8772)!==0):ae(t,e),Ql=u,Nt=n}break;case 30:break;default:ae(t,e)}}function Fs(t){var l=t.alternate;l!==null&&(t.alternate=null,Fs(l)),t.child=null,t.deletions=null,t.sibling=null,t.tag===5&&(l=t.stateNode,l!==null&&li(l)),t.stateNode=null,t.return=null,t.dependencies=null,t.memoizedProps=null,t.memoizedState=null,t.pendingProps=null,t.stateNode=null,t.updateQueue=null}var _t=null,Pt=!1;function Zl(t,l,e){for(e=e.child;e!==null;)Ps(t,l,e),e=e.sibling}function Ps(t,l,e){if(ll&&typeof ll.onCommitFiberUnmount=="function")try{ll.onCommitFiberUnmount(Ta,e)}catch{}switch(e.tag){case 26:Nt||_l(e,l),Zl(t,l,e),e.memoizedState?e.memoizedState.count--:e.stateNode&&(e=e.stateNode,e.parentNode.removeChild(e));break;case 27:Nt||_l(e,l);var a=_t,u=Pt;se(e.type)&&(_t=e.stateNode,Pt=!1),Zl(t,l,e),su(e.stateNode),_t=a,Pt=u;break;case 5:Nt||_l(e,l);case 6:if(a=_t,u=Pt,_t=null,Zl(t,l,e),_t=a,Pt=u,_t!==null)if(Pt)try{(_t.nodeType===9?_t.body:_t.nodeName==="HTML"?_t.ownerDocument.body:_t).removeChild(e.stateNode)}catch(n){Ot(e,l,n)}else try{_t.removeChild(e.stateNode)}catch(n){Ot(e,l,n)}break;case 18:_t!==null&&(Pt?(t=_t,Qo(t.nodeType===9?t.body:t.nodeName==="HTML"?t.ownerDocument.body:t,e.stateNode),pu(t)):Qo(_t,e.stateNode));break;case 4:a=_t,u=Pt,_t=e.stateNode.containerInfo,Pt=!0,Zl(t,l,e),_t=a,Pt=u;break;case 0:case 11:case 14:case 15:Nt||ee(2,e,l),Nt||ee(4,e,l),Zl(t,l,e);break;case 1:Nt||(_l(e,l),a=e.stateNode,typeof a.componentWillUnmount=="function"&&Ks(e,l,a)),Zl(t,l,e);break;case 21:Zl(t,l,e);break;case 22:Nt=(a=Nt)||e.memoizedState!==null,Zl(t,l,e),Nt=a;break;default:Zl(t,l,e)}}function Is(t,l){if(l.memoizedState===null&&(t=l.alternate,t!==null&&(t=t.memoizedState,t!==null&&(t=t.dehydrated,t!==null))))try{pu(t)}catch(e){Ot(l,l.return,e)}}function fv(t){switch(t.tag){case 13:case 19:var l=t.stateNode;return l===null&&(l=t.stateNode=new $s),l;case 22:return t=t.stateNode,l=t._retryCache,l===null&&(l=t._retryCache=new $s),l;default:throw Error(h(435,t.tag))}}function Ef(t,l){var e=fv(t);l.forEach(function(a){var u=gv.bind(null,t,a);e.has(a)||(e.add(a),a.then(u,u))})}function nl(t,l){var e=l.deletions;if(e!==null)for(var a=0;a<e.length;a++){var u=e[a],n=t,i=l,f=i;t:for(;f!==null;){switch(f.tag){case 27:if(se(f.type)){_t=f.stateNode,Pt=!1;break t}break;case 5:_t=f.stateNode,Pt=!1;break t;case 3:case 4:_t=f.stateNode.containerInfo,Pt=!0;break t}f=f.return}if(_t===null)throw Error(h(160));Ps(n,i,u),_t=null,Pt=!1,n=u.alternate,n!==null&&(n.return=null),u.return=null}if(l.subtreeFlags&13878)for(l=l.child;l!==null;)to(l,t),l=l.sibling}var Ol=null;function to(t,l){var e=t.alternate,a=t.flags;switch(t.tag){case 0:case 11:case 14:case 15:nl(l,t),il(t),a&4&&(ee(3,t,t.return),tu(3,t),ee(5,t,t.return));break;case 1:nl(l,t),il(t),a&512&&(Nt||e===null||_l(e,e.return)),a&64&&Ql&&(t=t.updateQueue,t!==null&&(a=t.callbacks,a!==null&&(e=t.shared.hiddenCallbacks,t.shared.hiddenCallbacks=e===null?a:e.concat(a))));break;case 26:var u=Ol;if(nl(l,t),il(t),a&512&&(Nt||e===null||_l(e,e.return)),a&4){var n=e!==null?e.memoizedState:null;if(a=t.memoizedState,e===null)if(a===null)if(t.stateNode===null){t:{a=t.type,e=t.memoizedProps,u=u.ownerDocument||u;l:switch(a){case"title":n=u.getElementsByTagName("title")[0],(!n||n[za]||n[Kt]||n.namespaceURI==="http://www.w3.org/2000/svg"||n.hasAttribute("itemprop"))&&(n=u.createElement(a),u.head.insertBefore(n,u.querySelector("head > title"))),Lt(n,a,e),n[Kt]=t,Xt(n),a=n;break t;case"link":var i=$o("link","href",u).get(a+(e.href||""));if(i){for(var f=0;f<i.length;f++)if(n=i[f],n.getAttribute("href")===(e.href==null||e.href===""?null:e.href)&&n.getAttribute("rel")===(e.rel==null?null:e.rel)&&n.getAttribute("title")===(e.title==null?null:e.title)&&n.getAttribute("crossorigin")===(e.crossOrigin==null?null:e.crossOrigin)){i.splice(f,1);break l}}n=u.createElement(a),Lt(n,a,e),u.head.appendChild(n);break;case"meta":if(i=$o("meta","content",u).get(a+(e.content||""))){for(f=0;f<i.length;f++)if(n=i[f],n.getAttribute("content")===(e.content==null?null:""+e.content)&&n.getAttribute("name")===(e.name==null?null:e.name)&&n.getAttribute("property")===(e.property==null?null:e.property)&&n.getAttribute("http-equiv")===(e.httpEquiv==null?null:e.httpEquiv)&&n.getAttribute("charset")===(e.charSet==null?null:e.charSet)){i.splice(f,1);break l}}n=u.createElement(a),Lt(n,a,e),u.head.appendChild(n);break;default:throw Error(h(468,a))}n[Kt]=t,Xt(n),a=n}t.stateNode=a}else ko(u,t.type,t.stateNode);else t.stateNode=Wo(u,a,t.memoizedProps);else n!==a?(n===null?e.stateNode!==null&&(e=e.stateNode,e.parentNode.removeChild(e)):n.count--,a===null?ko(u,t.type,t.stateNode):Wo(u,a,t.memoizedProps)):a===null&&t.stateNode!==null&&bf(t,t.memoizedProps,e.memoizedProps)}break;case 27:nl(l,t),il(t),a&512&&(Nt||e===null||_l(e,e.return)),e!==null&&a&4&&bf(t,t.memoizedProps,e.memoizedProps);break;case 5:if(nl(l,t),il(t),a&512&&(Nt||e===null||_l(e,e.return)),t.flags&32){u=t.stateNode;try{Le(u,"")}catch(O){Ot(t,t.return,O)}}a&4&&t.stateNode!=null&&(u=t.memoizedProps,bf(t,u,e!==null?e.memoizedProps:u)),a&1024&&(Df=!0);break;case 6:if(nl(l,t),il(t),a&4){if(t.stateNode===null)throw Error(h(162));a=t.memoizedProps,e=t.stateNode;try{e.nodeValue=a}catch(O){Ot(t,t.return,O)}}break;case 3:if(xn=null,u=Ol,Ol=Nn(l.containerInfo),nl(l,t),Ol=u,il(t),a&4&&e!==null&&e.memoizedState.isDehydrated)try{pu(l.containerInfo)}catch(O){Ot(t,t.return,O)}Df&&(Df=!1,lo(t));break;case 4:a=Ol,Ol=Nn(t.stateNode.containerInfo),nl(l,t),il(t),Ol=a;break;case 12:nl(l,t),il(t);break;case 13:nl(l,t),il(t),t.child.flags&8192&&t.memoizedState!==null!=(e!==null&&e.memoizedState!==null)&&(Uf=Dl()),a&4&&(a=t.updateQueue,a!==null&&(t.updateQueue=null,Ef(t,a)));break;case 22:u=t.memoizedState!==null;var c=e!==null&&e.memoizedState!==null,m=Ql,M=Nt;if(Ql=m||u,Nt=M||c,nl(l,t),Nt=M,Ql=m,il(t),a&8192)t:for(l=t.stateNode,l._visibility=u?l._visibility&-2:l._visibility|1,u&&(e===null||c||Ql||Nt||qe(t)),e=null,l=t;;){if(l.tag===5||l.tag===26){if(e===null){c=e=l;try{if(n=c.stateNode,u)i=n.style,typeof i.setProperty=="function"?i.setProperty("display","none","important"):i.display="none";else{f=c.stateNode;var R=c.memoizedProps.style,b=R!=null&&R.hasOwnProperty("display")?R.display:null;f.style.display=b==null||typeof b=="boolean"?"":(""+b).trim()}}catch(O){Ot(c,c.return,O)}}}else if(l.tag===6){if(e===null){c=l;try{c.stateNode.nodeValue=u?"":c.memoizedProps}catch(O){Ot(c,c.return,O)}}}else if((l.tag!==22&&l.tag!==23||l.memoizedState===null||l===t)&&l.child!==null){l.child.return=l,l=l.child;continue}if(l===t)break t;for(;l.sibling===null;){if(l.return===null||l.return===t)break t;e===l&&(e=null),l=l.return}e===l&&(e=null),l.sibling.return=l.return,l=l.sibling}a&4&&(a=t.updateQueue,a!==null&&(e=a.retryQueue,e!==null&&(a.retryQueue=null,Ef(t,e))));break;case 19:nl(l,t),il(t),a&4&&(a=t.updateQueue,a!==null&&(t.updateQueue=null,Ef(t,a)));break;case 30:break;case 21:break;default:nl(l,t),il(t)}}function il(t){var l=t.flags;if(l&2){try{for(var e,a=t.return;a!==null;){if(Js(a)){e=a;break}a=a.return}if(e==null)throw Error(h(160));switch(e.tag){case 27:var u=e.stateNode,n=Of(t);pn(t,n,u);break;case 5:var i=e.stateNode;e.flags&32&&(Le(i,""),e.flags&=-33);var f=Of(t);pn(t,f,i);break;case 3:case 4:var c=e.stateNode.containerInfo,m=Of(t);Tf(t,m,c);break;default:throw Error(h(161))}}catch(M){Ot(t,t.return,M)}t.flags&=-3}l&4096&&(t.flags&=-4097)}function lo(t){if(t.subtreeFlags&1024)for(t=t.child;t!==null;){var l=t;lo(l),l.tag===5&&l.flags&1024&&l.stateNode.reset(),t=t.sibling}}function ae(t,l){if(l.subtreeFlags&8772)for(l=l.child;l!==null;)ks(t,l.alternate,l),l=l.sibling}function qe(t){for(t=t.child;t!==null;){var l=t;switch(l.tag){case 0:case 11:case 14:case 15:ee(4,l,l.return),qe(l);break;case 1:_l(l,l.return);var e=l.stateNode;typeof e.componentWillUnmount=="function"&&Ks(l,l.return,e),qe(l);break;case 27:su(l.stateNode);case 26:case 5:_l(l,l.return),qe(l);break;case 22:l.memoizedState===null&&qe(l);break;case 30:qe(l);break;default:qe(l)}t=t.sibling}}function ue(t,l,e){for(e=e&&(l.subtreeFlags&8772)!==0,l=l.child;l!==null;){var a=l.alternate,u=t,n=l,i=n.flags;switch(n.tag){case 0:case 11:case 15:ue(u,n,e),tu(4,n);break;case 1:if(ue(u,n,e),a=n,u=a.stateNode,typeof u.componentDidMount=="function")try{u.componentDidMount()}catch(m){Ot(a,a.return,m)}if(a=n,u=a.updateQueue,u!==null){var f=a.stateNode;try{var c=u.shared.hiddenCallbacks;if(c!==null)for(u.shared.hiddenCallbacks=null,u=0;u<c.length;u++)Ur(c[u],f)}catch(m){Ot(a,a.return,m)}}e&&i&64&&Ls(n),lu(n,n.return);break;case 27:Ws(n);case 26:case 5:ue(u,n,e),e&&a===null&&i&4&&ws(n),lu(n,n.return);break;case 12:ue(u,n,e);break;case 13:ue(u,n,e),e&&i&4&&Is(u,n);break;case 22:n.memoizedState===null&&ue(u,n,e),lu(n,n.return);break;case 30:break;default:ue(u,n,e)}l=l.sibling}}function zf(t,l){var e=null;t!==null&&t.memoizedState!==null&&t.memoizedState.cachePool!==null&&(e=t.memoizedState.cachePool.pool),t=null,l.memoizedState!==null&&l.memoizedState.cachePool!==null&&(t=l.memoizedState.cachePool.pool),t!==e&&(t!=null&&t.refCount++,e!=null&&Ga(e))}function _f(t,l){t=null,l.alternate!==null&&(t=l.alternate.memoizedState.cache),l=l.memoizedState.cache,l!==t&&(l.refCount++,t!=null&&Ga(t))}function Ml(t,l,e,a){if(l.subtreeFlags&10256)for(l=l.child;l!==null;)eo(t,l,e,a),l=l.sibling}function eo(t,l,e,a){var u=l.flags;switch(l.tag){case 0:case 11:case 15:Ml(t,l,e,a),u&2048&&tu(9,l);break;case 1:Ml(t,l,e,a);break;case 3:Ml(t,l,e,a),u&2048&&(t=null,l.alternate!==null&&(t=l.alternate.memoizedState.cache),l=l.memoizedState.cache,l!==t&&(l.refCount++,t!=null&&Ga(t)));break;case 12:if(u&2048){Ml(t,l,e,a),t=l.stateNode;try{var n=l.memoizedProps,i=n.id,f=n.onPostCommit;typeof f=="function"&&f(i,l.alternate===null?"mount":"update",t.passiveEffectDuration,-0)}catch(c){Ot(l,l.return,c)}}else Ml(t,l,e,a);break;case 13:Ml(t,l,e,a);break;case 23:break;case 22:n=l.stateNode,i=l.alternate,l.memoizedState!==null?n._visibility&2?Ml(t,l,e,a):eu(t,l):n._visibility&2?Ml(t,l,e,a):(n._visibility|=2,ra(t,l,e,a,(l.subtreeFlags&10256)!==0)),u&2048&&zf(i,l);break;case 24:Ml(t,l,e,a),u&2048&&_f(l.alternate,l);break;default:Ml(t,l,e,a)}}function ra(t,l,e,a,u){for(u=u&&(l.subtreeFlags&10256)!==0,l=l.child;l!==null;){var n=t,i=l,f=e,c=a,m=i.flags;switch(i.tag){case 0:case 11:case 15:ra(n,i,f,c,u),tu(8,i);break;case 23:break;case 22:var M=i.stateNode;i.memoizedState!==null?M._visibility&2?ra(n,i,f,c,u):eu(n,i):(M._visibility|=2,ra(n,i,f,c,u)),u&&m&2048&&zf(i.alternate,i);break;case 24:ra(n,i,f,c,u),u&&m&2048&&_f(i.alternate,i);break;default:ra(n,i,f,c,u)}l=l.sibling}}function eu(t,l){if(l.subtreeFlags&10256)for(l=l.child;l!==null;){var e=t,a=l,u=a.flags;switch(a.tag){case 22:eu(e,a),u&2048&&zf(a.alternate,a);break;case 24:eu(e,a),u&2048&&_f(a.alternate,a);break;default:eu(e,a)}l=l.sibling}}var au=8192;function sa(t){if(t.subtreeFlags&au)for(t=t.child;t!==null;)ao(t),t=t.sibling}function ao(t){switch(t.tag){case 26:sa(t),t.flags&au&&t.memoizedState!==null&&wv(Ol,t.memoizedState,t.memoizedProps);break;case 5:sa(t);break;case 3:case 4:var l=Ol;Ol=Nn(t.stateNode.containerInfo),sa(t),Ol=l;break;case 22:t.memoizedState===null&&(l=t.alternate,l!==null&&l.memoizedState!==null?(l=au,au=16777216,sa(t),au=l):sa(t));break;default:sa(t)}}function uo(t){var l=t.alternate;if(l!==null&&(t=l.child,t!==null)){l.child=null;do l=t.sibling,t.sibling=null,t=l;while(t!==null)}}function uu(t){var l=t.deletions;if((t.flags&16)!==0){if(l!==null)for(var e=0;e<l.length;e++){var a=l[e];Gt=a,io(a,t)}uo(t)}if(t.subtreeFlags&10256)for(t=t.child;t!==null;)no(t),t=t.sibling}function no(t){switch(t.tag){case 0:case 11:case 15:uu(t),t.flags&2048&&ee(9,t,t.return);break;case 3:uu(t);break;case 12:uu(t);break;case 22:var l=t.stateNode;t.memoizedState!==null&&l._visibility&2&&(t.return===null||t.return.tag!==13)?(l._visibility&=-3,Sn(t)):uu(t);break;default:uu(t)}}function Sn(t){var l=t.deletions;if((t.flags&16)!==0){if(l!==null)for(var e=0;e<l.length;e++){var a=l[e];Gt=a,io(a,t)}uo(t)}for(t=t.child;t!==null;){switch(l=t,l.tag){case 0:case 11:case 15:ee(8,l,l.return),Sn(l);break;case 22:e=l.stateNode,e._visibility&2&&(e._visibility&=-3,Sn(l));break;default:Sn(l)}t=t.sibling}}function io(t,l){for(;Gt!==null;){var e=Gt;switch(e.tag){case 0:case 11:case 15:ee(8,e,l);break;case 23:case 22:if(e.memoizedState!==null&&e.memoizedState.cachePool!==null){var a=e.memoizedState.cachePool.pool;a!=null&&a.refCount++}break;case 24:Ga(e.memoizedState.cache)}if(a=e.child,a!==null)a.return=e,Gt=a;else t:for(e=t;Gt!==null;){a=Gt;var u=a.sibling,n=a.return;if(Fs(a),a===e){Gt=null;break t}if(u!==null){u.return=n,Gt=u;break t}Gt=n}}}var cv={getCacheForType:function(t){var l=wt(Bt),e=l.data.get(t);return e===void 0&&(e=t(),l.data.set(t,e)),e}},rv=typeof WeakMap=="function"?WeakMap:Map,yt=0,Dt=null,rt=null,ot=0,gt=0,fl=null,ne=!1,oa=!1,Mf=!1,Vl=0,Rt=0,ie=0,Ye=0,Af=0,ml=0,da=0,nu=null,It=null,Rf=!1,Uf=0,bn=1/0,On=null,fe=null,Vt=0,ce=null,ha=null,va=0,Nf=0,Hf=null,fo=null,iu=0,xf=null;function cl(){if((yt&2)!==0&&ot!==0)return ot&-ot;if(C.T!==null){var t=la;return t!==0?t:Gf()}return Dc()}function co(){ml===0&&(ml=(ot&536870912)===0||ht?Sc():536870912);var t=gl.current;return t!==null&&(t.flags|=32),ml}function rl(t,l,e){(t===Dt&&(gt===2||gt===9)||t.cancelPendingCommit!==null)&&(ya(t,0),re(t,ot,ml,!1)),Ea(t,e),((yt&2)===0||t!==Dt)&&(t===Dt&&((yt&2)===0&&(Ye|=e),Rt===4&&re(t,ot,ml,!1)),Al(t))}function ro(t,l,e){if((yt&6)!==0)throw Error(h(327));var a=!e&&(l&124)===0&&(l&t.expiredLanes)===0||Da(t,l),u=a?dv(t,l):Bf(t,l,!0),n=a;do{if(u===0){oa&&!a&&re(t,l,0,!1);break}else{if(e=t.current.alternate,n&&!sv(e)){u=Bf(t,l,!1),n=!1;continue}if(u===2){if(n=l,t.errorRecoveryDisabledLanes&n)var i=0;else i=t.pendingLanes&-536870913,i=i!==0?i:i&536870912?536870912:0;if(i!==0){l=i;t:{var f=t;u=nu;var c=f.current.memoizedState.isDehydrated;if(c&&(ya(f,i).flags|=256),i=Bf(f,i,!1),i!==2){if(Mf&&!c){f.errorRecoveryDisabledLanes|=n,Ye|=n,u=4;break t}n=It,It=u,n!==null&&(It===null?It=n:It.push.apply(It,n))}u=i}if(n=!1,u!==2)continue}}if(u===1){ya(t,0),re(t,l,0,!0);break}t:{switch(a=t,n=u,n){case 0:case 1:throw Error(h(345));case 4:if((l&4194048)!==l)break;case 6:re(a,l,ml,!ne);break t;case 2:It=null;break;case 3:case 5:break;default:throw Error(h(329))}if((l&62914560)===l&&(u=Uf+300-Dl(),10<u)){if(re(a,l,ml,!ne),Nu(a,0,!0)!==0)break t;a.timeoutHandle=jo(so.bind(null,a,e,It,On,Rf,l,ml,Ye,da,ne,n,2,-0,0),u);break t}so(a,e,It,On,Rf,l,ml,Ye,da,ne,n,0,-0,0)}}break}while(!0);Al(t)}function so(t,l,e,a,u,n,i,f,c,m,M,R,b,O){if(t.timeoutHandle=-1,R=l.subtreeFlags,(R&8192||(R&16785408)===16785408)&&(hu={stylesheets:null,count:0,unsuspend:Kv},ao(l),R=Jv(),R!==null)){t.cancelPendingCommit=R(po.bind(null,t,l,n,e,a,u,i,f,c,M,1,b,O)),re(t,n,i,!m);return}po(t,l,n,e,a,u,i,f,c)}function sv(t){for(var l=t;;){var e=l.tag;if((e===0||e===11||e===15)&&l.flags&16384&&(e=l.updateQueue,e!==null&&(e=e.stores,e!==null)))for(var a=0;a<e.length;a++){var u=e[a],n=u.getSnapshot;u=u.value;try{if(!al(n(),u))return!1}catch{return!1}}if(e=l.child,l.subtreeFlags&16384&&e!==null)e.return=l,l=e;else{if(l===t)break;for(;l.sibling===null;){if(l.return===null||l.return===t)return!0;l=l.return}l.sibling.return=l.return,l=l.sibling}}return!0}function re(t,l,e,a){l&=~Af,l&=~Ye,t.suspendedLanes|=l,t.pingedLanes&=~l,a&&(t.warmLanes|=l),a=t.expirationTimes;for(var u=l;0<u;){var n=31-el(u),i=1<<n;a[n]=-1,u&=~i}e!==0&&Oc(t,e,l)}function Tn(){return(yt&6)===0?(fu(0),!1):!0}function qf(){if(rt!==null){if(gt===0)var t=rt.return;else t=rt,Yl=Re=null,ki(t),fa=null,Fa=0,t=rt;for(;t!==null;)Vs(t.alternate,t),t=t.return;rt=null}}function ya(t,l){var e=t.timeoutHandle;e!==-1&&(t.timeoutHandle=-1,Av(e)),e=t.cancelPendingCommit,e!==null&&(t.cancelPendingCommit=null,e()),qf(),Dt=t,rt=e=Hl(t.current,null),ot=l,gt=0,fl=null,ne=!1,oa=Da(t,l),Mf=!1,da=ml=Af=Ye=ie=Rt=0,It=nu=null,Rf=!1,(l&8)!==0&&(l|=l&32);var a=t.entangledLanes;if(a!==0)for(t=t.entanglements,a&=l;0<a;){var u=31-el(a),n=1<<u;l|=t[u],a&=~n}return Vl=l,Vu(),e}function oo(t,l){it=null,C.H=rn,l===Za||l===Pu?(l=Ar(),gt=3):l===zr?(l=Ar(),gt=4):gt=l===Rs?8:l!==null&&typeof l=="object"&&typeof l.then=="function"?6:1,fl=l,rt===null&&(Rt=1,vn(t,dl(l,t.current)))}function ho(){var t=C.H;return C.H=rn,t===null?rn:t}function vo(){var t=C.A;return C.A=cv,t}function Yf(){Rt=4,ne||(ot&4194048)!==ot&&gl.current!==null||(oa=!0),(ie&134217727)===0&&(Ye&134217727)===0||Dt===null||re(Dt,ot,ml,!1)}function Bf(t,l,e){var a=yt;yt|=2;var u=ho(),n=vo();(Dt!==t||ot!==l)&&(On=null,ya(t,l)),l=!1;var i=Rt;t:do try{if(gt!==0&&rt!==null){var f=rt,c=fl;switch(gt){case 8:qf(),i=6;break t;case 3:case 2:case 9:case 6:gl.current===null&&(l=!0);var m=gt;if(gt=0,fl=null,ga(t,f,c,m),e&&oa){i=0;break t}break;default:m=gt,gt=0,fl=null,ga(t,f,c,m)}}ov(),i=Rt;break}catch(M){oo(t,M)}while(!0);return l&&t.shellSuspendCounter++,Yl=Re=null,yt=a,C.H=u,C.A=n,rt===null&&(Dt=null,ot=0,Vu()),i}function ov(){for(;rt!==null;)yo(rt)}function dv(t,l){var e=yt;yt|=2;var a=ho(),u=vo();Dt!==t||ot!==l?(On=null,bn=Dl()+500,ya(t,l)):oa=Da(t,l);t:do try{if(gt!==0&&rt!==null){l=rt;var n=fl;l:switch(gt){case 1:gt=0,fl=null,ga(t,l,n,1);break;case 2:case 9:if(_r(n)){gt=0,fl=null,go(l);break}l=function(){gt!==2&&gt!==9||Dt!==t||(gt=7),Al(t)},n.then(l,l);break t;case 3:gt=7;break t;case 4:gt=5;break t;case 7:_r(n)?(gt=0,fl=null,go(l)):(gt=0,fl=null,ga(t,l,n,7));break;case 5:var i=null;switch(rt.tag){case 26:i=rt.memoizedState;case 5:case 27:var f=rt;if(!i||Fo(i)){gt=0,fl=null;var c=f.sibling;if(c!==null)rt=c;else{var m=f.return;m!==null?(rt=m,Dn(m)):rt=null}break l}}gt=0,fl=null,ga(t,l,n,5);break;case 6:gt=0,fl=null,ga(t,l,n,6);break;case 8:qf(),Rt=6;break t;default:throw Error(h(462))}}hv();break}catch(M){oo(t,M)}while(!0);return Yl=Re=null,C.H=a,C.A=u,yt=e,rt!==null?0:(Dt=null,ot=0,Vu(),Rt)}function hv(){for(;rt!==null&&!Yd();)yo(rt)}function yo(t){var l=Qs(t.alternate,t,Vl);t.memoizedProps=t.pendingProps,l===null?Dn(t):rt=l}function go(t){var l=t,e=l.alternate;switch(l.tag){case 15:case 0:l=Ys(e,l,l.pendingProps,l.type,void 0,ot);break;case 11:l=Ys(e,l,l.pendingProps,l.type.render,l.ref,ot);break;case 5:ki(l);default:Vs(e,l),l=rt=gr(l,Vl),l=Qs(e,l,Vl)}t.memoizedProps=t.pendingProps,l===null?Dn(t):rt=l}function ga(t,l,e,a){Yl=Re=null,ki(l),fa=null,Fa=0;var u=l.return;try{if(ev(t,u,l,e,ot)){Rt=1,vn(t,dl(e,t.current)),rt=null;return}}catch(n){if(u!==null)throw rt=u,n;Rt=1,vn(t,dl(e,t.current)),rt=null;return}l.flags&32768?(ht||a===1?t=!0:oa||(ot&536870912)!==0?t=!1:(ne=t=!0,(a===2||a===9||a===3||a===6)&&(a=gl.current,a!==null&&a.tag===13&&(a.flags|=16384))),mo(l,t)):Dn(l)}function Dn(t){var l=t;do{if((l.flags&32768)!==0){mo(l,ne);return}t=l.return;var e=uv(l.alternate,l,Vl);if(e!==null){rt=e;return}if(l=l.sibling,l!==null){rt=l;return}rt=l=t}while(l!==null);Rt===0&&(Rt=5)}function mo(t,l){do{var e=nv(t.alternate,t);if(e!==null){e.flags&=32767,rt=e;return}if(e=t.return,e!==null&&(e.flags|=32768,e.subtreeFlags=0,e.deletions=null),!l&&(t=t.sibling,t!==null)){rt=t;return}rt=t=e}while(t!==null);Rt=6,rt=null}function po(t,l,e,a,u,n,i,f,c){t.cancelPendingCommit=null;do En();while(Vt!==0);if((yt&6)!==0)throw Error(h(327));if(l!==null){if(l===t.current)throw Error(h(177));if(n=l.lanes|l.childLanes,n|=zi,Kd(t,e,n,i,f,c),t===Dt&&(rt=Dt=null,ot=0),ha=l,ce=t,va=e,Nf=n,Hf=u,fo=a,(l.subtreeFlags&10256)!==0||(l.flags&10256)!==0?(t.callbackNode=null,t.callbackPriority=0,mv(Au,function(){return Do(),null})):(t.callbackNode=null,t.callbackPriority=0),a=(l.flags&13878)!==0,(l.subtreeFlags&13878)!==0||a){a=C.T,C.T=null,u=et.p,et.p=2,i=yt,yt|=4;try{iv(t,l,e)}finally{yt=i,et.p=u,C.T=a}}Vt=1,So(),bo(),Oo()}}function So(){if(Vt===1){Vt=0;var t=ce,l=ha,e=(l.flags&13878)!==0;if((l.subtreeFlags&13878)!==0||e){e=C.T,C.T=null;var a=et.p;et.p=2;var u=yt;yt|=4;try{to(l,t);var n=Wf,i=ir(t.containerInfo),f=n.focusedElem,c=n.selectionRange;if(i!==f&&f&&f.ownerDocument&&nr(f.ownerDocument.documentElement,f)){if(c!==null&&bi(f)){var m=c.start,M=c.end;if(M===void 0&&(M=m),"selectionStart"in f)f.selectionStart=m,f.selectionEnd=Math.min(M,f.value.length);else{var R=f.ownerDocument||document,b=R&&R.defaultView||window;if(b.getSelection){var O=b.getSelection(),I=f.textContent.length,$=Math.min(c.start,I),bt=c.end===void 0?$:Math.min(c.end,I);!O.extend&&$>bt&&(i=bt,bt=$,$=i);var d=ur(f,$),r=ur(f,bt);if(d&&r&&(O.rangeCount!==1||O.anchorNode!==d.node||O.anchorOffset!==d.offset||O.focusNode!==r.node||O.focusOffset!==r.offset)){var g=R.createRange();g.setStart(d.node,d.offset),O.removeAllRanges(),$>bt?(O.addRange(g),O.extend(r.node,r.offset)):(g.setEnd(r.node,r.offset),O.addRange(g))}}}}for(R=[],O=f;O=O.parentNode;)O.nodeType===1&&R.push({element:O,left:O.scrollLeft,top:O.scrollTop});for(typeof f.focus=="function"&&f.focus(),f=0;f<R.length;f++){var A=R[f];A.element.scrollLeft=A.left,A.element.scrollTop=A.top}}Bn=!!Jf,Wf=Jf=null}finally{yt=u,et.p=a,C.T=e}}t.current=l,Vt=2}}function bo(){if(Vt===2){Vt=0;var t=ce,l=ha,e=(l.flags&8772)!==0;if((l.subtreeFlags&8772)!==0||e){e=C.T,C.T=null;var a=et.p;et.p=2;var u=yt;yt|=4;try{ks(t,l.alternate,l)}finally{yt=u,et.p=a,C.T=e}}Vt=3}}function Oo(){if(Vt===4||Vt===3){Vt=0,Bd();var t=ce,l=ha,e=va,a=fo;(l.subtreeFlags&10256)!==0||(l.flags&10256)!==0?Vt=5:(Vt=0,ha=ce=null,To(t,t.pendingLanes));var u=t.pendingLanes;if(u===0&&(fe=null),In(e),l=l.stateNode,ll&&typeof ll.onCommitFiberRoot=="function")try{ll.onCommitFiberRoot(Ta,l,void 0,(l.current.flags&128)===128)}catch{}if(a!==null){l=C.T,u=et.p,et.p=2,C.T=null;try{for(var n=t.onRecoverableError,i=0;i<a.length;i++){var f=a[i];n(f.value,{componentStack:f.stack})}}finally{C.T=l,et.p=u}}(va&3)!==0&&En(),Al(t),u=t.pendingLanes,(e&4194090)!==0&&(u&42)!==0?t===xf?iu++:(iu=0,xf=t):iu=0,fu(0)}}function To(t,l){(t.pooledCacheLanes&=l)===0&&(l=t.pooledCache,l!=null&&(t.pooledCache=null,Ga(l)))}function En(t){return So(),bo(),Oo(),Do()}function Do(){if(Vt!==5)return!1;var t=ce,l=Nf;Nf=0;var e=In(va),a=C.T,u=et.p;try{et.p=32>e?32:e,C.T=null,e=Hf,Hf=null;var n=ce,i=va;if(Vt=0,ha=ce=null,va=0,(yt&6)!==0)throw Error(h(331));var f=yt;if(yt|=4,no(n.current),eo(n,n.current,i,e),yt=f,fu(0,!1),ll&&typeof ll.onPostCommitFiberRoot=="function")try{ll.onPostCommitFiberRoot(Ta,n)}catch{}return!0}finally{et.p=u,C.T=a,To(t,l)}}function Eo(t,l,e){l=dl(e,l),l=of(t.stateNode,l,2),t=Pl(t,l,2),t!==null&&(Ea(t,2),Al(t))}function Ot(t,l,e){if(t.tag===3)Eo(t,t,e);else for(;l!==null;){if(l.tag===3){Eo(l,t,e);break}else if(l.tag===1){var a=l.stateNode;if(typeof l.type.getDerivedStateFromError=="function"||typeof a.componentDidCatch=="function"&&(fe===null||!fe.has(a))){t=dl(e,t),e=Ms(2),a=Pl(l,e,2),a!==null&&(As(e,a,l,t),Ea(a,2),Al(a));break}}l=l.return}}function Cf(t,l,e){var a=t.pingCache;if(a===null){a=t.pingCache=new rv;var u=new Set;a.set(l,u)}else u=a.get(l),u===void 0&&(u=new Set,a.set(l,u));u.has(e)||(Mf=!0,u.add(e),t=vv.bind(null,t,l,e),l.then(t,t))}function vv(t,l,e){var a=t.pingCache;a!==null&&a.delete(l),t.pingedLanes|=t.suspendedLanes&e,t.warmLanes&=~e,Dt===t&&(ot&e)===e&&(Rt===4||Rt===3&&(ot&62914560)===ot&&300>Dl()-Uf?(yt&2)===0&&ya(t,0):Af|=e,da===ot&&(da=0)),Al(t)}function zo(t,l){l===0&&(l=bc()),t=Fe(t,l),t!==null&&(Ea(t,l),Al(t))}function yv(t){var l=t.memoizedState,e=0;l!==null&&(e=l.retryLane),zo(t,e)}function gv(t,l){var e=0;switch(t.tag){case 13:var a=t.stateNode,u=t.memoizedState;u!==null&&(e=u.retryLane);break;case 19:a=t.stateNode;break;case 22:a=t.stateNode._retryCache;break;default:throw Error(h(314))}a!==null&&a.delete(l),zo(t,e)}function mv(t,l){return $n(t,l)}var zn=null,ma=null,Xf=!1,_n=!1,jf=!1,Be=0;function Al(t){t!==ma&&t.next===null&&(ma===null?zn=ma=t:ma=ma.next=t),_n=!0,Xf||(Xf=!0,Sv())}function fu(t,l){if(!jf&&_n){jf=!0;do for(var e=!1,a=zn;a!==null;){if(t!==0){var u=a.pendingLanes;if(u===0)var n=0;else{var i=a.suspendedLanes,f=a.pingedLanes;n=(1<<31-el(42|t)+1)-1,n&=u&~(i&~f),n=n&201326741?n&201326741|1:n?n|2:0}n!==0&&(e=!0,Ro(a,n))}else n=ot,n=Nu(a,a===Dt?n:0,a.cancelPendingCommit!==null||a.timeoutHandle!==-1),(n&3)===0||Da(a,n)||(e=!0,Ro(a,n));a=a.next}while(e);jf=!1}}function pv(){_o()}function _o(){_n=Xf=!1;var t=0;Be!==0&&(Mv()&&(t=Be),Be=0);for(var l=Dl(),e=null,a=zn;a!==null;){var u=a.next,n=Mo(a,l);n===0?(a.next=null,e===null?zn=u:e.next=u,u===null&&(ma=e)):(e=a,(t!==0||(n&3)!==0)&&(_n=!0)),a=u}fu(t)}function Mo(t,l){for(var e=t.suspendedLanes,a=t.pingedLanes,u=t.expirationTimes,n=t.pendingLanes&-62914561;0<n;){var i=31-el(n),f=1<<i,c=u[i];c===-1?((f&e)===0||(f&a)!==0)&&(u[i]=Ld(f,l)):c<=l&&(t.expiredLanes|=f),n&=~f}if(l=Dt,e=ot,e=Nu(t,t===l?e:0,t.cancelPendingCommit!==null||t.timeoutHandle!==-1),a=t.callbackNode,e===0||t===l&&(gt===2||gt===9)||t.cancelPendingCommit!==null)return a!==null&&a!==null&&kn(a),t.callbackNode=null,t.callbackPriority=0;if((e&3)===0||Da(t,e)){if(l=e&-e,l===t.callbackPriority)return l;switch(a!==null&&kn(a),In(e)){case 2:case 8:e=mc;break;case 32:e=Au;break;case 268435456:e=pc;break;default:e=Au}return a=Ao.bind(null,t),e=$n(e,a),t.callbackPriority=l,t.callbackNode=e,l}return a!==null&&a!==null&&kn(a),t.callbackPriority=2,t.callbackNode=null,2}function Ao(t,l){if(Vt!==0&&Vt!==5)return t.callbackNode=null,t.callbackPriority=0,null;var e=t.callbackNode;if(En()&&t.callbackNode!==e)return null;var a=ot;return a=Nu(t,t===Dt?a:0,t.cancelPendingCommit!==null||t.timeoutHandle!==-1),a===0?null:(ro(t,a,l),Mo(t,Dl()),t.callbackNode!=null&&t.callbackNode===e?Ao.bind(null,t):null)}function Ro(t,l){if(En())return null;ro(t,l,!0)}function Sv(){Rv(function(){(yt&6)!==0?$n(gc,pv):_o()})}function Gf(){return Be===0&&(Be=Sc()),Be}function Uo(t){return t==null||typeof t=="symbol"||typeof t=="boolean"?null:typeof t=="function"?t:Bu(""+t)}function No(t,l){var e=l.ownerDocument.createElement("input");return e.name=l.name,e.value=l.value,t.id&&e.setAttribute("form",t.id),l.parentNode.insertBefore(e,l),t=new FormData(t),e.parentNode.removeChild(e),t}function bv(t,l,e,a,u){if(l==="submit"&&e&&e.stateNode===u){var n=Uo((u[$t]||null).action),i=a.submitter;i&&(l=(l=i[$t]||null)?Uo(l.formAction):i.getAttribute("formAction"),l!==null&&(n=l,i=null));var f=new Gu("action","action",null,a,u);t.push({event:f,listeners:[{instance:null,listener:function(){if(a.defaultPrevented){if(Be!==0){var c=i?No(u,i):new FormData(u);nf(e,{pending:!0,data:c,method:u.method,action:n},null,c)}}else typeof n=="function"&&(f.preventDefault(),c=i?No(u,i):new FormData(u),nf(e,{pending:!0,data:c,method:u.method,action:n},n,c))},currentTarget:u}]})}}for(var Qf=0;Qf<Ei.length;Qf++){var Zf=Ei[Qf],Ov=Zf.toLowerCase(),Tv=Zf[0].toUpperCase()+Zf.slice(1);bl(Ov,"on"+Tv)}bl(rr,"onAnimationEnd"),bl(sr,"onAnimationIteration"),bl(or,"onAnimationStart"),bl("dblclick","onDoubleClick"),bl("focusin","onFocus"),bl("focusout","onBlur"),bl(jh,"onTransitionRun"),bl(Gh,"onTransitionStart"),bl(Qh,"onTransitionCancel"),bl(dr,"onTransitionEnd"),Qe("onMouseEnter",["mouseout","mouseover"]),Qe("onMouseLeave",["mouseout","mouseover"]),Qe("onPointerEnter",["pointerout","pointerover"]),Qe("onPointerLeave",["pointerout","pointerover"]),be("onChange","change click focusin focusout input keydown keyup selectionchange".split(" ")),be("onSelect","focusout contextmenu dragend focusin keydown keyup mousedown mouseup selectionchange".split(" ")),be("onBeforeInput",["compositionend","keypress","textInput","paste"]),be("onCompositionEnd","compositionend focusout keydown keypress keyup mousedown".split(" ")),be("onCompositionStart","compositionstart focusout keydown keypress keyup mousedown".split(" ")),be("onCompositionUpdate","compositionupdate focusout keydown keypress keyup mousedown".split(" "));var cu="abort canplay canplaythrough durationchange emptied encrypted ended error loadeddata loadedmetadata loadstart pause play playing progress ratechange resize seeked seeking stalled suspend timeupdate volumechange waiting".split(" "),Dv=new Set("beforetoggle cancel close invalid load scroll scrollend toggle".split(" ").concat(cu));function Ho(t,l){l=(l&4)!==0;for(var e=0;e<t.length;e++){var a=t[e],u=a.event;a=a.listeners;t:{var n=void 0;if(l)for(var i=a.length-1;0<=i;i--){var f=a[i],c=f.instance,m=f.currentTarget;if(f=f.listener,c!==n&&u.isPropagationStopped())break t;n=f,u.currentTarget=m;try{n(u)}catch(M){hn(M)}u.currentTarget=null,n=c}else for(i=0;i<a.length;i++){if(f=a[i],c=f.instance,m=f.currentTarget,f=f.listener,c!==n&&u.isPropagationStopped())break t;n=f,u.currentTarget=m;try{n(u)}catch(M){hn(M)}u.currentTarget=null,n=c}}}}function st(t,l){var e=l[ti];e===void 0&&(e=l[ti]=new Set);var a=t+"__bubble";e.has(a)||(xo(l,t,2,!1),e.add(a))}function Vf(t,l,e){var a=0;l&&(a|=4),xo(e,t,a,l)}var Mn="_reactListening"+Math.random().toString(36).slice(2);function Lf(t){if(!t[Mn]){t[Mn]=!0,zc.forEach(function(e){e!=="selectionchange"&&(Dv.has(e)||Vf(e,!1,t),Vf(e,!0,t))});var l=t.nodeType===9?t:t.ownerDocument;l===null||l[Mn]||(l[Mn]=!0,Vf("selectionchange",!1,l))}}function xo(t,l,e,a){switch(ad(l)){case 2:var u=kv;break;case 8:u=Fv;break;default:u=uc}e=u.bind(null,l,e,t),u=void 0,!oi||l!=="touchstart"&&l!=="touchmove"&&l!=="wheel"||(u=!0),a?u!==void 0?t.addEventListener(l,e,{capture:!0,passive:u}):t.addEventListener(l,e,!0):u!==void 0?t.addEventListener(l,e,{passive:u}):t.addEventListener(l,e,!1)}function Kf(t,l,e,a,u){var n=a;if((l&1)===0&&(l&2)===0&&a!==null)t:for(;;){if(a===null)return;var i=a.tag;if(i===3||i===4){var f=a.stateNode.containerInfo;if(f===u)break;if(i===4)for(i=a.return;i!==null;){var c=i.tag;if((c===3||c===4)&&i.stateNode.containerInfo===u)return;i=i.return}for(;f!==null;){if(i=Xe(f),i===null)return;if(c=i.tag,c===5||c===6||c===26||c===27){a=n=i;continue t}f=f.parentNode}}a=a.return}jc(function(){var m=n,M=ri(e),R=[];t:{var b=hr.get(t);if(b!==void 0){var O=Gu,I=t;switch(t){case"keypress":if(Xu(e)===0)break t;case"keydown":case"keyup":O=mh;break;case"focusin":I="focus",O=yi;break;case"focusout":I="blur",O=yi;break;case"beforeblur":case"afterblur":O=yi;break;case"click":if(e.button===2)break t;case"auxclick":case"dblclick":case"mousedown":case"mousemove":case"mouseup":case"mouseout":case"mouseover":case"contextmenu":O=Zc;break;case"drag":case"dragend":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"dragstart":case"drop":O=nh;break;case"touchcancel":case"touchend":case"touchmove":case"touchstart":O=bh;break;case rr:case sr:case or:O=ch;break;case dr:O=Th;break;case"scroll":case"scrollend":O=ah;break;case"wheel":O=Eh;break;case"copy":case"cut":case"paste":O=sh;break;case"gotpointercapture":case"lostpointercapture":case"pointercancel":case"pointerdown":case"pointermove":case"pointerout":case"pointerover":case"pointerup":O=Lc;break;case"toggle":case"beforetoggle":O=_h}var $=(l&4)!==0,bt=!$&&(t==="scroll"||t==="scrollend"),d=$?b!==null?b+"Capture":null:b;$=[];for(var r=m,g;r!==null;){var A=r;if(g=A.stateNode,A=A.tag,A!==5&&A!==26&&A!==27||g===null||d===null||(A=Ma(r,d),A!=null&&$.push(ru(r,A,g))),bt)break;r=r.return}0<$.length&&(b=new O(b,I,null,e,M),R.push({event:b,listeners:$}))}}if((l&7)===0){t:{if(b=t==="mouseover"||t==="pointerover",O=t==="mouseout"||t==="pointerout",b&&e!==ci&&(I=e.relatedTarget||e.fromElement)&&(Xe(I)||I[Ce]))break t;if((O||b)&&(b=M.window===M?M:(b=M.ownerDocument)?b.defaultView||b.parentWindow:window,O?(I=e.relatedTarget||e.toElement,O=m,I=I?Xe(I):null,I!==null&&(bt=Y(I),$=I.tag,I!==bt||$!==5&&$!==27&&$!==6)&&(I=null)):(O=null,I=m),O!==I)){if($=Zc,A="onMouseLeave",d="onMouseEnter",r="mouse",(t==="pointerout"||t==="pointerover")&&($=Lc,A="onPointerLeave",d="onPointerEnter",r="pointer"),bt=O==null?b:_a(O),g=I==null?b:_a(I),b=new $(A,r+"leave",O,e,M),b.target=bt,b.relatedTarget=g,A=null,Xe(M)===m&&($=new $(d,r+"enter",I,e,M),$.target=g,$.relatedTarget=bt,A=$),bt=A,O&&I)l:{for($=O,d=I,r=0,g=$;g;g=pa(g))r++;for(g=0,A=d;A;A=pa(A))g++;for(;0<r-g;)$=pa($),r--;for(;0<g-r;)d=pa(d),g--;for(;r--;){if($===d||d!==null&&$===d.alternate)break l;$=pa($),d=pa(d)}$=null}else $=null;O!==null&&qo(R,b,O,$,!1),I!==null&&bt!==null&&qo(R,bt,I,$,!0)}}t:{if(b=m?_a(m):window,O=b.nodeName&&b.nodeName.toLowerCase(),O==="select"||O==="input"&&b.type==="file")var Q=Pc;else if(kc(b))if(Ic)Q=Bh;else{Q=qh;var ft=xh}else O=b.nodeName,!O||O.toLowerCase()!=="input"||b.type!=="checkbox"&&b.type!=="radio"?m&&fi(m.elementType)&&(Q=Pc):Q=Yh;if(Q&&(Q=Q(t,m))){Fc(R,Q,e,M);break t}ft&&ft(t,b,m),t==="focusout"&&m&&b.type==="number"&&m.memoizedProps.value!=null&&ii(b,"number",b.value)}switch(ft=m?_a(m):window,t){case"focusin":(kc(ft)||ft.contentEditable==="true")&&(We=ft,Oi=m,Ya=null);break;case"focusout":Ya=Oi=We=null;break;case"mousedown":Ti=!0;break;case"contextmenu":case"mouseup":case"dragend":Ti=!1,fr(R,e,M);break;case"selectionchange":if(Xh)break;case"keydown":case"keyup":fr(R,e,M)}var w;if(mi)t:{switch(t){case"compositionstart":var k="onCompositionStart";break t;case"compositionend":k="onCompositionEnd";break t;case"compositionupdate":k="onCompositionUpdate";break t}k=void 0}else Je?Wc(t,e)&&(k="onCompositionEnd"):t==="keydown"&&e.keyCode===229&&(k="onCompositionStart");k&&(Kc&&e.locale!=="ko"&&(Je||k!=="onCompositionStart"?k==="onCompositionEnd"&&Je&&(w=Gc()):(Wl=M,di="value"in Wl?Wl.value:Wl.textContent,Je=!0)),ft=An(m,k),0<ft.length&&(k=new Vc(k,t,null,e,M),R.push({event:k,listeners:ft}),w?k.data=w:(w=$c(e),w!==null&&(k.data=w)))),(w=Ah?Rh(t,e):Uh(t,e))&&(k=An(m,"onBeforeInput"),0<k.length&&(ft=new Vc("onBeforeInput","beforeinput",null,e,M),R.push({event:ft,listeners:k}),ft.data=w)),bv(R,t,m,e,M)}Ho(R,l)})}function ru(t,l,e){return{instance:t,listener:l,currentTarget:e}}function An(t,l){for(var e=l+"Capture",a=[];t!==null;){var u=t,n=u.stateNode;if(u=u.tag,u!==5&&u!==26&&u!==27||n===null||(u=Ma(t,e),u!=null&&a.unshift(ru(t,u,n)),u=Ma(t,l),u!=null&&a.push(ru(t,u,n))),t.tag===3)return a;t=t.return}return[]}function pa(t){if(t===null)return null;do t=t.return;while(t&&t.tag!==5&&t.tag!==27);return t||null}function qo(t,l,e,a,u){for(var n=l._reactName,i=[];e!==null&&e!==a;){var f=e,c=f.alternate,m=f.stateNode;if(f=f.tag,c!==null&&c===a)break;f!==5&&f!==26&&f!==27||m===null||(c=m,u?(m=Ma(e,n),m!=null&&i.unshift(ru(e,m,c))):u||(m=Ma(e,n),m!=null&&i.push(ru(e,m,c)))),e=e.return}i.length!==0&&t.push({event:l,listeners:i})}var Ev=/\r\n?/g,zv=/\u0000|\uFFFD/g;function Yo(t){return(typeof t=="string"?t:""+t).replace(Ev,`
`).replace(zv,"")}function Bo(t,l){return l=Yo(l),Yo(t)===l}function Rn(){}function St(t,l,e,a,u,n){switch(e){case"children":typeof a=="string"?l==="body"||l==="textarea"&&a===""||Le(t,a):(typeof a=="number"||typeof a=="bigint")&&l!=="body"&&Le(t,""+a);break;case"className":xu(t,"class",a);break;case"tabIndex":xu(t,"tabindex",a);break;case"dir":case"role":case"viewBox":case"width":case"height":xu(t,e,a);break;case"style":Cc(t,a,n);break;case"data":if(l!=="object"){xu(t,"data",a);break}case"src":case"href":if(a===""&&(l!=="a"||e!=="href")){t.removeAttribute(e);break}if(a==null||typeof a=="function"||typeof a=="symbol"||typeof a=="boolean"){t.removeAttribute(e);break}a=Bu(""+a),t.setAttribute(e,a);break;case"action":case"formAction":if(typeof a=="function"){t.setAttribute(e,"javascript:throw new Error('A React form was unexpectedly submitted. If you called form.submit() manually, consider using form.requestSubmit() instead. If you\\'re trying to use event.stopPropagation() in a submit event handler, consider also calling event.preventDefault().')");break}else typeof n=="function"&&(e==="formAction"?(l!=="input"&&St(t,l,"name",u.name,u,null),St(t,l,"formEncType",u.formEncType,u,null),St(t,l,"formMethod",u.formMethod,u,null),St(t,l,"formTarget",u.formTarget,u,null)):(St(t,l,"encType",u.encType,u,null),St(t,l,"method",u.method,u,null),St(t,l,"target",u.target,u,null)));if(a==null||typeof a=="symbol"||typeof a=="boolean"){t.removeAttribute(e);break}a=Bu(""+a),t.setAttribute(e,a);break;case"onClick":a!=null&&(t.onclick=Rn);break;case"onScroll":a!=null&&st("scroll",t);break;case"onScrollEnd":a!=null&&st("scrollend",t);break;case"dangerouslySetInnerHTML":if(a!=null){if(typeof a!="object"||!("__html"in a))throw Error(h(61));if(e=a.__html,e!=null){if(u.children!=null)throw Error(h(60));t.innerHTML=e}}break;case"multiple":t.multiple=a&&typeof a!="function"&&typeof a!="symbol";break;case"muted":t.muted=a&&typeof a!="function"&&typeof a!="symbol";break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"defaultValue":case"defaultChecked":case"innerHTML":case"ref":break;case"autoFocus":break;case"xlinkHref":if(a==null||typeof a=="function"||typeof a=="boolean"||typeof a=="symbol"){t.removeAttribute("xlink:href");break}e=Bu(""+a),t.setAttributeNS("http://www.w3.org/1999/xlink","xlink:href",e);break;case"contentEditable":case"spellCheck":case"draggable":case"value":case"autoReverse":case"externalResourcesRequired":case"focusable":case"preserveAlpha":a!=null&&typeof a!="function"&&typeof a!="symbol"?t.setAttribute(e,""+a):t.removeAttribute(e);break;case"inert":case"allowFullScreen":case"async":case"autoPlay":case"controls":case"default":case"defer":case"disabled":case"disablePictureInPicture":case"disableRemotePlayback":case"formNoValidate":case"hidden":case"loop":case"noModule":case"noValidate":case"open":case"playsInline":case"readOnly":case"required":case"reversed":case"scoped":case"seamless":case"itemScope":a&&typeof a!="function"&&typeof a!="symbol"?t.setAttribute(e,""):t.removeAttribute(e);break;case"capture":case"download":a===!0?t.setAttribute(e,""):a!==!1&&a!=null&&typeof a!="function"&&typeof a!="symbol"?t.setAttribute(e,a):t.removeAttribute(e);break;case"cols":case"rows":case"size":case"span":a!=null&&typeof a!="function"&&typeof a!="symbol"&&!isNaN(a)&&1<=a?t.setAttribute(e,a):t.removeAttribute(e);break;case"rowSpan":case"start":a==null||typeof a=="function"||typeof a=="symbol"||isNaN(a)?t.removeAttribute(e):t.setAttribute(e,a);break;case"popover":st("beforetoggle",t),st("toggle",t),Hu(t,"popover",a);break;case"xlinkActuate":Ul(t,"http://www.w3.org/1999/xlink","xlink:actuate",a);break;case"xlinkArcrole":Ul(t,"http://www.w3.org/1999/xlink","xlink:arcrole",a);break;case"xlinkRole":Ul(t,"http://www.w3.org/1999/xlink","xlink:role",a);break;case"xlinkShow":Ul(t,"http://www.w3.org/1999/xlink","xlink:show",a);break;case"xlinkTitle":Ul(t,"http://www.w3.org/1999/xlink","xlink:title",a);break;case"xlinkType":Ul(t,"http://www.w3.org/1999/xlink","xlink:type",a);break;case"xmlBase":Ul(t,"http://www.w3.org/XML/1998/namespace","xml:base",a);break;case"xmlLang":Ul(t,"http://www.w3.org/XML/1998/namespace","xml:lang",a);break;case"xmlSpace":Ul(t,"http://www.w3.org/XML/1998/namespace","xml:space",a);break;case"is":Hu(t,"is",a);break;case"innerText":case"textContent":break;default:(!(2<e.length)||e[0]!=="o"&&e[0]!=="O"||e[1]!=="n"&&e[1]!=="N")&&(e=lh.get(e)||e,Hu(t,e,a))}}function wf(t,l,e,a,u,n){switch(e){case"style":Cc(t,a,n);break;case"dangerouslySetInnerHTML":if(a!=null){if(typeof a!="object"||!("__html"in a))throw Error(h(61));if(e=a.__html,e!=null){if(u.children!=null)throw Error(h(60));t.innerHTML=e}}break;case"children":typeof a=="string"?Le(t,a):(typeof a=="number"||typeof a=="bigint")&&Le(t,""+a);break;case"onScroll":a!=null&&st("scroll",t);break;case"onScrollEnd":a!=null&&st("scrollend",t);break;case"onClick":a!=null&&(t.onclick=Rn);break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"innerHTML":case"ref":break;case"innerText":case"textContent":break;default:if(!_c.hasOwnProperty(e))t:{if(e[0]==="o"&&e[1]==="n"&&(u=e.endsWith("Capture"),l=e.slice(2,u?e.length-7:void 0),n=t[$t]||null,n=n!=null?n[e]:null,typeof n=="function"&&t.removeEventListener(l,n,u),typeof a=="function")){typeof n!="function"&&n!==null&&(e in t?t[e]=null:t.hasAttribute(e)&&t.removeAttribute(e)),t.addEventListener(l,a,u);break t}e in t?t[e]=a:a===!0?t.setAttribute(e,""):Hu(t,e,a)}}}function Lt(t,l,e){switch(l){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"img":st("error",t),st("load",t);var a=!1,u=!1,n;for(n in e)if(e.hasOwnProperty(n)){var i=e[n];if(i!=null)switch(n){case"src":a=!0;break;case"srcSet":u=!0;break;case"children":case"dangerouslySetInnerHTML":throw Error(h(137,l));default:St(t,l,n,i,e,null)}}u&&St(t,l,"srcSet",e.srcSet,e,null),a&&St(t,l,"src",e.src,e,null);return;case"input":st("invalid",t);var f=n=i=u=null,c=null,m=null;for(a in e)if(e.hasOwnProperty(a)){var M=e[a];if(M!=null)switch(a){case"name":u=M;break;case"type":i=M;break;case"checked":c=M;break;case"defaultChecked":m=M;break;case"value":n=M;break;case"defaultValue":f=M;break;case"children":case"dangerouslySetInnerHTML":if(M!=null)throw Error(h(137,l));break;default:St(t,l,a,M,e,null)}}xc(t,n,f,c,m,i,u,!1),qu(t);return;case"select":st("invalid",t),a=i=n=null;for(u in e)if(e.hasOwnProperty(u)&&(f=e[u],f!=null))switch(u){case"value":n=f;break;case"defaultValue":i=f;break;case"multiple":a=f;default:St(t,l,u,f,e,null)}l=n,e=i,t.multiple=!!a,l!=null?Ve(t,!!a,l,!1):e!=null&&Ve(t,!!a,e,!0);return;case"textarea":st("invalid",t),n=u=a=null;for(i in e)if(e.hasOwnProperty(i)&&(f=e[i],f!=null))switch(i){case"value":a=f;break;case"defaultValue":u=f;break;case"children":n=f;break;case"dangerouslySetInnerHTML":if(f!=null)throw Error(h(91));break;default:St(t,l,i,f,e,null)}Yc(t,a,u,n),qu(t);return;case"option":for(c in e)if(e.hasOwnProperty(c)&&(a=e[c],a!=null))switch(c){case"selected":t.selected=a&&typeof a!="function"&&typeof a!="symbol";break;default:St(t,l,c,a,e,null)}return;case"dialog":st("beforetoggle",t),st("toggle",t),st("cancel",t),st("close",t);break;case"iframe":case"object":st("load",t);break;case"video":case"audio":for(a=0;a<cu.length;a++)st(cu[a],t);break;case"image":st("error",t),st("load",t);break;case"details":st("toggle",t);break;case"embed":case"source":case"link":st("error",t),st("load",t);case"area":case"base":case"br":case"col":case"hr":case"keygen":case"meta":case"param":case"track":case"wbr":case"menuitem":for(m in e)if(e.hasOwnProperty(m)&&(a=e[m],a!=null))switch(m){case"children":case"dangerouslySetInnerHTML":throw Error(h(137,l));default:St(t,l,m,a,e,null)}return;default:if(fi(l)){for(M in e)e.hasOwnProperty(M)&&(a=e[M],a!==void 0&&wf(t,l,M,a,e,void 0));return}}for(f in e)e.hasOwnProperty(f)&&(a=e[f],a!=null&&St(t,l,f,a,e,null))}function _v(t,l,e,a){switch(l){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"input":var u=null,n=null,i=null,f=null,c=null,m=null,M=null;for(O in e){var R=e[O];if(e.hasOwnProperty(O)&&R!=null)switch(O){case"checked":break;case"value":break;case"defaultValue":c=R;default:a.hasOwnProperty(O)||St(t,l,O,null,a,R)}}for(var b in a){var O=a[b];if(R=e[b],a.hasOwnProperty(b)&&(O!=null||R!=null))switch(b){case"type":n=O;break;case"name":u=O;break;case"checked":m=O;break;case"defaultChecked":M=O;break;case"value":i=O;break;case"defaultValue":f=O;break;case"children":case"dangerouslySetInnerHTML":if(O!=null)throw Error(h(137,l));break;default:O!==R&&St(t,l,b,O,a,R)}}ni(t,i,f,c,m,M,n,u);return;case"select":O=i=f=b=null;for(n in e)if(c=e[n],e.hasOwnProperty(n)&&c!=null)switch(n){case"value":break;case"multiple":O=c;default:a.hasOwnProperty(n)||St(t,l,n,null,a,c)}for(u in a)if(n=a[u],c=e[u],a.hasOwnProperty(u)&&(n!=null||c!=null))switch(u){case"value":b=n;break;case"defaultValue":f=n;break;case"multiple":i=n;default:n!==c&&St(t,l,u,n,a,c)}l=f,e=i,a=O,b!=null?Ve(t,!!e,b,!1):!!a!=!!e&&(l!=null?Ve(t,!!e,l,!0):Ve(t,!!e,e?[]:"",!1));return;case"textarea":O=b=null;for(f in e)if(u=e[f],e.hasOwnProperty(f)&&u!=null&&!a.hasOwnProperty(f))switch(f){case"value":break;case"children":break;default:St(t,l,f,null,a,u)}for(i in a)if(u=a[i],n=e[i],a.hasOwnProperty(i)&&(u!=null||n!=null))switch(i){case"value":b=u;break;case"defaultValue":O=u;break;case"children":break;case"dangerouslySetInnerHTML":if(u!=null)throw Error(h(91));break;default:u!==n&&St(t,l,i,u,a,n)}qc(t,b,O);return;case"option":for(var I in e)if(b=e[I],e.hasOwnProperty(I)&&b!=null&&!a.hasOwnProperty(I))switch(I){case"selected":t.selected=!1;break;default:St(t,l,I,null,a,b)}for(c in a)if(b=a[c],O=e[c],a.hasOwnProperty(c)&&b!==O&&(b!=null||O!=null))switch(c){case"selected":t.selected=b&&typeof b!="function"&&typeof b!="symbol";break;default:St(t,l,c,b,a,O)}return;case"img":case"link":case"area":case"base":case"br":case"col":case"embed":case"hr":case"keygen":case"meta":case"param":case"source":case"track":case"wbr":case"menuitem":for(var $ in e)b=e[$],e.hasOwnProperty($)&&b!=null&&!a.hasOwnProperty($)&&St(t,l,$,null,a,b);for(m in a)if(b=a[m],O=e[m],a.hasOwnProperty(m)&&b!==O&&(b!=null||O!=null))switch(m){case"children":case"dangerouslySetInnerHTML":if(b!=null)throw Error(h(137,l));break;default:St(t,l,m,b,a,O)}return;default:if(fi(l)){for(var bt in e)b=e[bt],e.hasOwnProperty(bt)&&b!==void 0&&!a.hasOwnProperty(bt)&&wf(t,l,bt,void 0,a,b);for(M in a)b=a[M],O=e[M],!a.hasOwnProperty(M)||b===O||b===void 0&&O===void 0||wf(t,l,M,b,a,O);return}}for(var d in e)b=e[d],e.hasOwnProperty(d)&&b!=null&&!a.hasOwnProperty(d)&&St(t,l,d,null,a,b);for(R in a)b=a[R],O=e[R],!a.hasOwnProperty(R)||b===O||b==null&&O==null||St(t,l,R,b,a,O)}var Jf=null,Wf=null;function Un(t){return t.nodeType===9?t:t.ownerDocument}function Co(t){switch(t){case"http://www.w3.org/2000/svg":return 1;case"http://www.w3.org/1998/Math/MathML":return 2;default:return 0}}function Xo(t,l){if(t===0)switch(l){case"svg":return 1;case"math":return 2;default:return 0}return t===1&&l==="foreignObject"?0:t}function $f(t,l){return t==="textarea"||t==="noscript"||typeof l.children=="string"||typeof l.children=="number"||typeof l.children=="bigint"||typeof l.dangerouslySetInnerHTML=="object"&&l.dangerouslySetInnerHTML!==null&&l.dangerouslySetInnerHTML.__html!=null}var kf=null;function Mv(){var t=window.event;return t&&t.type==="popstate"?t===kf?!1:(kf=t,!0):(kf=null,!1)}var jo=typeof setTimeout=="function"?setTimeout:void 0,Av=typeof clearTimeout=="function"?clearTimeout:void 0,Go=typeof Promise=="function"?Promise:void 0,Rv=typeof queueMicrotask=="function"?queueMicrotask:typeof Go<"u"?function(t){return Go.resolve(null).then(t).catch(Uv)}:jo;function Uv(t){setTimeout(function(){throw t})}function se(t){return t==="head"}function Qo(t,l){var e=l,a=0,u=0;do{var n=e.nextSibling;if(t.removeChild(e),n&&n.nodeType===8)if(e=n.data,e==="/$"){if(0<a&&8>a){e=a;var i=t.ownerDocument;if(e&1&&su(i.documentElement),e&2&&su(i.body),e&4)for(e=i.head,su(e),i=e.firstChild;i;){var f=i.nextSibling,c=i.nodeName;i[za]||c==="SCRIPT"||c==="STYLE"||c==="LINK"&&i.rel.toLowerCase()==="stylesheet"||e.removeChild(i),i=f}}if(u===0){t.removeChild(n),pu(l);return}u--}else e==="$"||e==="$?"||e==="$!"?u++:a=e.charCodeAt(0)-48;else a=0;e=n}while(e);pu(l)}function Ff(t){var l=t.firstChild;for(l&&l.nodeType===10&&(l=l.nextSibling);l;){var e=l;switch(l=l.nextSibling,e.nodeName){case"HTML":case"HEAD":case"BODY":Ff(e),li(e);continue;case"SCRIPT":case"STYLE":continue;case"LINK":if(e.rel.toLowerCase()==="stylesheet")continue}t.removeChild(e)}}function Nv(t,l,e,a){for(;t.nodeType===1;){var u=e;if(t.nodeName.toLowerCase()!==l.toLowerCase()){if(!a&&(t.nodeName!=="INPUT"||t.type!=="hidden"))break}else if(a){if(!t[za])switch(l){case"meta":if(!t.hasAttribute("itemprop"))break;return t;case"link":if(n=t.getAttribute("rel"),n==="stylesheet"&&t.hasAttribute("data-precedence"))break;if(n!==u.rel||t.getAttribute("href")!==(u.href==null||u.href===""?null:u.href)||t.getAttribute("crossorigin")!==(u.crossOrigin==null?null:u.crossOrigin)||t.getAttribute("title")!==(u.title==null?null:u.title))break;return t;case"style":if(t.hasAttribute("data-precedence"))break;return t;case"script":if(n=t.getAttribute("src"),(n!==(u.src==null?null:u.src)||t.getAttribute("type")!==(u.type==null?null:u.type)||t.getAttribute("crossorigin")!==(u.crossOrigin==null?null:u.crossOrigin))&&n&&t.hasAttribute("async")&&!t.hasAttribute("itemprop"))break;return t;default:return t}}else if(l==="input"&&t.type==="hidden"){var n=u.name==null?null:""+u.name;if(u.type==="hidden"&&t.getAttribute("name")===n)return t}else return t;if(t=Tl(t.nextSibling),t===null)break}return null}function Hv(t,l,e){if(l==="")return null;for(;t.nodeType!==3;)if((t.nodeType!==1||t.nodeName!=="INPUT"||t.type!=="hidden")&&!e||(t=Tl(t.nextSibling),t===null))return null;return t}function Pf(t){return t.data==="$!"||t.data==="$?"&&t.ownerDocument.readyState==="complete"}function xv(t,l){var e=t.ownerDocument;if(t.data!=="$?"||e.readyState==="complete")l();else{var a=function(){l(),e.removeEventListener("DOMContentLoaded",a)};e.addEventListener("DOMContentLoaded",a),t._reactRetry=a}}function Tl(t){for(;t!=null;t=t.nextSibling){var l=t.nodeType;if(l===1||l===3)break;if(l===8){if(l=t.data,l==="$"||l==="$!"||l==="$?"||l==="F!"||l==="F")break;if(l==="/$")return null}}return t}var If=null;function Zo(t){t=t.previousSibling;for(var l=0;t;){if(t.nodeType===8){var e=t.data;if(e==="$"||e==="$!"||e==="$?"){if(l===0)return t;l--}else e==="/$"&&l++}t=t.previousSibling}return null}function Vo(t,l,e){switch(l=Un(e),t){case"html":if(t=l.documentElement,!t)throw Error(h(452));return t;case"head":if(t=l.head,!t)throw Error(h(453));return t;case"body":if(t=l.body,!t)throw Error(h(454));return t;default:throw Error(h(451))}}function su(t){for(var l=t.attributes;l.length;)t.removeAttributeNode(l[0]);li(t)}var pl=new Map,Lo=new Set;function Nn(t){return typeof t.getRootNode=="function"?t.getRootNode():t.nodeType===9?t:t.ownerDocument}var Ll=et.d;et.d={f:qv,r:Yv,D:Bv,C:Cv,L:Xv,m:jv,X:Qv,S:Gv,M:Zv};function qv(){var t=Ll.f(),l=Tn();return t||l}function Yv(t){var l=je(t);l!==null&&l.tag===5&&l.type==="form"?rs(l):Ll.r(t)}var Sa=typeof document>"u"?null:document;function Ko(t,l,e){var a=Sa;if(a&&typeof l=="string"&&l){var u=ol(l);u='link[rel="'+t+'"][href="'+u+'"]',typeof e=="string"&&(u+='[crossorigin="'+e+'"]'),Lo.has(u)||(Lo.add(u),t={rel:t,crossOrigin:e,href:l},a.querySelector(u)===null&&(l=a.createElement("link"),Lt(l,"link",t),Xt(l),a.head.appendChild(l)))}}function Bv(t){Ll.D(t),Ko("dns-prefetch",t,null)}function Cv(t,l){Ll.C(t,l),Ko("preconnect",t,l)}function Xv(t,l,e){Ll.L(t,l,e);var a=Sa;if(a&&t&&l){var u='link[rel="preload"][as="'+ol(l)+'"]';l==="image"&&e&&e.imageSrcSet?(u+='[imagesrcset="'+ol(e.imageSrcSet)+'"]',typeof e.imageSizes=="string"&&(u+='[imagesizes="'+ol(e.imageSizes)+'"]')):u+='[href="'+ol(t)+'"]';var n=u;switch(l){case"style":n=ba(t);break;case"script":n=Oa(t)}pl.has(n)||(t=H({rel:"preload",href:l==="image"&&e&&e.imageSrcSet?void 0:t,as:l},e),pl.set(n,t),a.querySelector(u)!==null||l==="style"&&a.querySelector(ou(n))||l==="script"&&a.querySelector(du(n))||(l=a.createElement("link"),Lt(l,"link",t),Xt(l),a.head.appendChild(l)))}}function jv(t,l){Ll.m(t,l);var e=Sa;if(e&&t){var a=l&&typeof l.as=="string"?l.as:"script",u='link[rel="modulepreload"][as="'+ol(a)+'"][href="'+ol(t)+'"]',n=u;switch(a){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":n=Oa(t)}if(!pl.has(n)&&(t=H({rel:"modulepreload",href:t},l),pl.set(n,t),e.querySelector(u)===null)){switch(a){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":if(e.querySelector(du(n)))return}a=e.createElement("link"),Lt(a,"link",t),Xt(a),e.head.appendChild(a)}}}function Gv(t,l,e){Ll.S(t,l,e);var a=Sa;if(a&&t){var u=Ge(a).hoistableStyles,n=ba(t);l=l||"default";var i=u.get(n);if(!i){var f={loading:0,preload:null};if(i=a.querySelector(ou(n)))f.loading=5;else{t=H({rel:"stylesheet",href:t,"data-precedence":l},e),(e=pl.get(n))&&tc(t,e);var c=i=a.createElement("link");Xt(c),Lt(c,"link",t),c._p=new Promise(function(m,M){c.onload=m,c.onerror=M}),c.addEventListener("load",function(){f.loading|=1}),c.addEventListener("error",function(){f.loading|=2}),f.loading|=4,Hn(i,l,a)}i={type:"stylesheet",instance:i,count:1,state:f},u.set(n,i)}}}function Qv(t,l){Ll.X(t,l);var e=Sa;if(e&&t){var a=Ge(e).hoistableScripts,u=Oa(t),n=a.get(u);n||(n=e.querySelector(du(u)),n||(t=H({src:t,async:!0},l),(l=pl.get(u))&&lc(t,l),n=e.createElement("script"),Xt(n),Lt(n,"link",t),e.head.appendChild(n)),n={type:"script",instance:n,count:1,state:null},a.set(u,n))}}function Zv(t,l){Ll.M(t,l);var e=Sa;if(e&&t){var a=Ge(e).hoistableScripts,u=Oa(t),n=a.get(u);n||(n=e.querySelector(du(u)),n||(t=H({src:t,async:!0,type:"module"},l),(l=pl.get(u))&&lc(t,l),n=e.createElement("script"),Xt(n),Lt(n,"link",t),e.head.appendChild(n)),n={type:"script",instance:n,count:1,state:null},a.set(u,n))}}function wo(t,l,e,a){var u=(u=at.current)?Nn(u):null;if(!u)throw Error(h(446));switch(t){case"meta":case"title":return null;case"style":return typeof e.precedence=="string"&&typeof e.href=="string"?(l=ba(e.href),e=Ge(u).hoistableStyles,a=e.get(l),a||(a={type:"style",instance:null,count:0,state:null},e.set(l,a)),a):{type:"void",instance:null,count:0,state:null};case"link":if(e.rel==="stylesheet"&&typeof e.href=="string"&&typeof e.precedence=="string"){t=ba(e.href);var n=Ge(u).hoistableStyles,i=n.get(t);if(i||(u=u.ownerDocument||u,i={type:"stylesheet",instance:null,count:0,state:{loading:0,preload:null}},n.set(t,i),(n=u.querySelector(ou(t)))&&!n._p&&(i.instance=n,i.state.loading=5),pl.has(t)||(e={rel:"preload",as:"style",href:e.href,crossOrigin:e.crossOrigin,integrity:e.integrity,media:e.media,hrefLang:e.hrefLang,referrerPolicy:e.referrerPolicy},pl.set(t,e),n||Vv(u,t,e,i.state))),l&&a===null)throw Error(h(528,""));return i}if(l&&a!==null)throw Error(h(529,""));return null;case"script":return l=e.async,e=e.src,typeof e=="string"&&l&&typeof l!="function"&&typeof l!="symbol"?(l=Oa(e),e=Ge(u).hoistableScripts,a=e.get(l),a||(a={type:"script",instance:null,count:0,state:null},e.set(l,a)),a):{type:"void",instance:null,count:0,state:null};default:throw Error(h(444,t))}}function ba(t){return'href="'+ol(t)+'"'}function ou(t){return'link[rel="stylesheet"]['+t+"]"}function Jo(t){return H({},t,{"data-precedence":t.precedence,precedence:null})}function Vv(t,l,e,a){t.querySelector('link[rel="preload"][as="style"]['+l+"]")?a.loading=1:(l=t.createElement("link"),a.preload=l,l.addEventListener("load",function(){return a.loading|=1}),l.addEventListener("error",function(){return a.loading|=2}),Lt(l,"link",e),Xt(l),t.head.appendChild(l))}function Oa(t){return'[src="'+ol(t)+'"]'}function du(t){return"script[async]"+t}function Wo(t,l,e){if(l.count++,l.instance===null)switch(l.type){case"style":var a=t.querySelector('style[data-href~="'+ol(e.href)+'"]');if(a)return l.instance=a,Xt(a),a;var u=H({},e,{"data-href":e.href,"data-precedence":e.precedence,href:null,precedence:null});return a=(t.ownerDocument||t).createElement("style"),Xt(a),Lt(a,"style",u),Hn(a,e.precedence,t),l.instance=a;case"stylesheet":u=ba(e.href);var n=t.querySelector(ou(u));if(n)return l.state.loading|=4,l.instance=n,Xt(n),n;a=Jo(e),(u=pl.get(u))&&tc(a,u),n=(t.ownerDocument||t).createElement("link"),Xt(n);var i=n;return i._p=new Promise(function(f,c){i.onload=f,i.onerror=c}),Lt(n,"link",a),l.state.loading|=4,Hn(n,e.precedence,t),l.instance=n;case"script":return n=Oa(e.src),(u=t.querySelector(du(n)))?(l.instance=u,Xt(u),u):(a=e,(u=pl.get(n))&&(a=H({},e),lc(a,u)),t=t.ownerDocument||t,u=t.createElement("script"),Xt(u),Lt(u,"link",a),t.head.appendChild(u),l.instance=u);case"void":return null;default:throw Error(h(443,l.type))}else l.type==="stylesheet"&&(l.state.loading&4)===0&&(a=l.instance,l.state.loading|=4,Hn(a,e.precedence,t));return l.instance}function Hn(t,l,e){for(var a=e.querySelectorAll('link[rel="stylesheet"][data-precedence],style[data-precedence]'),u=a.length?a[a.length-1]:null,n=u,i=0;i<a.length;i++){var f=a[i];if(f.dataset.precedence===l)n=f;else if(n!==u)break}n?n.parentNode.insertBefore(t,n.nextSibling):(l=e.nodeType===9?e.head:e,l.insertBefore(t,l.firstChild))}function tc(t,l){t.crossOrigin==null&&(t.crossOrigin=l.crossOrigin),t.referrerPolicy==null&&(t.referrerPolicy=l.referrerPolicy),t.title==null&&(t.title=l.title)}function lc(t,l){t.crossOrigin==null&&(t.crossOrigin=l.crossOrigin),t.referrerPolicy==null&&(t.referrerPolicy=l.referrerPolicy),t.integrity==null&&(t.integrity=l.integrity)}var xn=null;function $o(t,l,e){if(xn===null){var a=new Map,u=xn=new Map;u.set(e,a)}else u=xn,a=u.get(e),a||(a=new Map,u.set(e,a));if(a.has(t))return a;for(a.set(t,null),e=e.getElementsByTagName(t),u=0;u<e.length;u++){var n=e[u];if(!(n[za]||n[Kt]||t==="link"&&n.getAttribute("rel")==="stylesheet")&&n.namespaceURI!=="http://www.w3.org/2000/svg"){var i=n.getAttribute(l)||"";i=t+i;var f=a.get(i);f?f.push(n):a.set(i,[n])}}return a}function ko(t,l,e){t=t.ownerDocument||t,t.head.insertBefore(e,l==="title"?t.querySelector("head > title"):null)}function Lv(t,l,e){if(e===1||l.itemProp!=null)return!1;switch(t){case"meta":case"title":return!0;case"style":if(typeof l.precedence!="string"||typeof l.href!="string"||l.href==="")break;return!0;case"link":if(typeof l.rel!="string"||typeof l.href!="string"||l.href===""||l.onLoad||l.onError)break;switch(l.rel){case"stylesheet":return t=l.disabled,typeof l.precedence=="string"&&t==null;default:return!0}case"script":if(l.async&&typeof l.async!="function"&&typeof l.async!="symbol"&&!l.onLoad&&!l.onError&&l.src&&typeof l.src=="string")return!0}return!1}function Fo(t){return!(t.type==="stylesheet"&&(t.state.loading&3)===0)}var hu=null;function Kv(){}function wv(t,l,e){if(hu===null)throw Error(h(475));var a=hu;if(l.type==="stylesheet"&&(typeof e.media!="string"||matchMedia(e.media).matches!==!1)&&(l.state.loading&4)===0){if(l.instance===null){var u=ba(e.href),n=t.querySelector(ou(u));if(n){t=n._p,t!==null&&typeof t=="object"&&typeof t.then=="function"&&(a.count++,a=qn.bind(a),t.then(a,a)),l.state.loading|=4,l.instance=n,Xt(n);return}n=t.ownerDocument||t,e=Jo(e),(u=pl.get(u))&&tc(e,u),n=n.createElement("link"),Xt(n);var i=n;i._p=new Promise(function(f,c){i.onload=f,i.onerror=c}),Lt(n,"link",e),l.instance=n}a.stylesheets===null&&(a.stylesheets=new Map),a.stylesheets.set(l,t),(t=l.state.preload)&&(l.state.loading&3)===0&&(a.count++,l=qn.bind(a),t.addEventListener("load",l),t.addEventListener("error",l))}}function Jv(){if(hu===null)throw Error(h(475));var t=hu;return t.stylesheets&&t.count===0&&ec(t,t.stylesheets),0<t.count?function(l){var e=setTimeout(function(){if(t.stylesheets&&ec(t,t.stylesheets),t.unsuspend){var a=t.unsuspend;t.unsuspend=null,a()}},6e4);return t.unsuspend=l,function(){t.unsuspend=null,clearTimeout(e)}}:null}function qn(){if(this.count--,this.count===0){if(this.stylesheets)ec(this,this.stylesheets);else if(this.unsuspend){var t=this.unsuspend;this.unsuspend=null,t()}}}var Yn=null;function ec(t,l){t.stylesheets=null,t.unsuspend!==null&&(t.count++,Yn=new Map,l.forEach(Wv,t),Yn=null,qn.call(t))}function Wv(t,l){if(!(l.state.loading&4)){var e=Yn.get(t);if(e)var a=e.get(null);else{e=new Map,Yn.set(t,e);for(var u=t.querySelectorAll("link[data-precedence],style[data-precedence]"),n=0;n<u.length;n++){var i=u[n];(i.nodeName==="LINK"||i.getAttribute("media")!=="not all")&&(e.set(i.dataset.precedence,i),a=i)}a&&e.set(null,a)}u=l.instance,i=u.getAttribute("data-precedence"),n=e.get(i)||a,n===a&&e.set(null,u),e.set(i,u),this.count++,a=qn.bind(this),u.addEventListener("load",a),u.addEventListener("error",a),n?n.parentNode.insertBefore(u,n.nextSibling):(t=t.nodeType===9?t.head:t,t.insertBefore(u,t.firstChild)),l.state.loading|=4}}var vu={$$typeof:T,Provider:null,Consumer:null,_currentValue:xt,_currentValue2:xt,_threadCount:0};function $v(t,l,e,a,u,n,i,f){this.tag=1,this.containerInfo=t,this.pingCache=this.current=this.pendingChildren=null,this.timeoutHandle=-1,this.callbackNode=this.next=this.pendingContext=this.context=this.cancelPendingCommit=null,this.callbackPriority=0,this.expirationTimes=Fn(-1),this.entangledLanes=this.shellSuspendCounter=this.errorRecoveryDisabledLanes=this.expiredLanes=this.warmLanes=this.pingedLanes=this.suspendedLanes=this.pendingLanes=0,this.entanglements=Fn(0),this.hiddenUpdates=Fn(null),this.identifierPrefix=a,this.onUncaughtError=u,this.onCaughtError=n,this.onRecoverableError=i,this.pooledCache=null,this.pooledCacheLanes=0,this.formState=f,this.incompleteTransitions=new Map}function Po(t,l,e,a,u,n,i,f,c,m,M,R){return t=new $v(t,l,e,i,f,c,m,R),l=1,n===!0&&(l|=24),n=ul(3,null,null,l),t.current=n,n.stateNode=t,l=Bi(),l.refCount++,t.pooledCache=l,l.refCount++,n.memoizedState={element:a,isDehydrated:e,cache:l},Gi(n),t}function Io(t){return t?(t=Pe,t):Pe}function td(t,l,e,a,u,n){u=Io(u),a.context===null?a.context=u:a.pendingContext=u,a=Fl(l),a.payload={element:e},n=n===void 0?null:n,n!==null&&(a.callback=n),e=Pl(t,a,l),e!==null&&(rl(e,t,l),La(e,t,l))}function ld(t,l){if(t=t.memoizedState,t!==null&&t.dehydrated!==null){var e=t.retryLane;t.retryLane=e!==0&&e<l?e:l}}function ac(t,l){ld(t,l),(t=t.alternate)&&ld(t,l)}function ed(t){if(t.tag===13){var l=Fe(t,67108864);l!==null&&rl(l,t,67108864),ac(t,67108864)}}var Bn=!0;function kv(t,l,e,a){var u=C.T;C.T=null;var n=et.p;try{et.p=2,uc(t,l,e,a)}finally{et.p=n,C.T=u}}function Fv(t,l,e,a){var u=C.T;C.T=null;var n=et.p;try{et.p=8,uc(t,l,e,a)}finally{et.p=n,C.T=u}}function uc(t,l,e,a){if(Bn){var u=nc(a);if(u===null)Kf(t,l,a,Cn,e),ud(t,a);else if(Iv(u,t,l,e,a))a.stopPropagation();else if(ud(t,a),l&4&&-1<Pv.indexOf(t)){for(;u!==null;){var n=je(u);if(n!==null)switch(n.tag){case 3:if(n=n.stateNode,n.current.memoizedState.isDehydrated){var i=Se(n.pendingLanes);if(i!==0){var f=n;for(f.pendingLanes|=2,f.entangledLanes|=2;i;){var c=1<<31-el(i);f.entanglements[1]|=c,i&=~c}Al(n),(yt&6)===0&&(bn=Dl()+500,fu(0))}}break;case 13:f=Fe(n,2),f!==null&&rl(f,n,2),Tn(),ac(n,2)}if(n=nc(a),n===null&&Kf(t,l,a,Cn,e),n===u)break;u=n}u!==null&&a.stopPropagation()}else Kf(t,l,a,null,e)}}function nc(t){return t=ri(t),ic(t)}var Cn=null;function ic(t){if(Cn=null,t=Xe(t),t!==null){var l=Y(t);if(l===null)t=null;else{var e=l.tag;if(e===13){if(t=j(l),t!==null)return t;t=null}else if(e===3){if(l.stateNode.current.memoizedState.isDehydrated)return l.tag===3?l.stateNode.containerInfo:null;t=null}else l!==t&&(t=null)}}return Cn=t,null}function ad(t){switch(t){case"beforetoggle":case"cancel":case"click":case"close":case"contextmenu":case"copy":case"cut":case"auxclick":case"dblclick":case"dragend":case"dragstart":case"drop":case"focusin":case"focusout":case"input":case"invalid":case"keydown":case"keypress":case"keyup":case"mousedown":case"mouseup":case"paste":case"pause":case"play":case"pointercancel":case"pointerdown":case"pointerup":case"ratechange":case"reset":case"resize":case"seeked":case"submit":case"toggle":case"touchcancel":case"touchend":case"touchstart":case"volumechange":case"change":case"selectionchange":case"textInput":case"compositionstart":case"compositionend":case"compositionupdate":case"beforeblur":case"afterblur":case"beforeinput":case"blur":case"fullscreenchange":case"focus":case"hashchange":case"popstate":case"select":case"selectstart":return 2;case"drag":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"mousemove":case"mouseout":case"mouseover":case"pointermove":case"pointerout":case"pointerover":case"scroll":case"touchmove":case"wheel":case"mouseenter":case"mouseleave":case"pointerenter":case"pointerleave":return 8;case"message":switch(Cd()){case gc:return 2;case mc:return 8;case Au:case Xd:return 32;case pc:return 268435456;default:return 32}default:return 32}}var fc=!1,oe=null,de=null,he=null,yu=new Map,gu=new Map,ve=[],Pv="mousedown mouseup touchcancel touchend touchstart auxclick dblclick pointercancel pointerdown pointerup dragend dragstart drop compositionend compositionstart keydown keypress keyup input textInput copy cut paste click change contextmenu reset".split(" ");function ud(t,l){switch(t){case"focusin":case"focusout":oe=null;break;case"dragenter":case"dragleave":de=null;break;case"mouseover":case"mouseout":he=null;break;case"pointerover":case"pointerout":yu.delete(l.pointerId);break;case"gotpointercapture":case"lostpointercapture":gu.delete(l.pointerId)}}function mu(t,l,e,a,u,n){return t===null||t.nativeEvent!==n?(t={blockedOn:l,domEventName:e,eventSystemFlags:a,nativeEvent:n,targetContainers:[u]},l!==null&&(l=je(l),l!==null&&ed(l)),t):(t.eventSystemFlags|=a,l=t.targetContainers,u!==null&&l.indexOf(u)===-1&&l.push(u),t)}function Iv(t,l,e,a,u){switch(l){case"focusin":return oe=mu(oe,t,l,e,a,u),!0;case"dragenter":return de=mu(de,t,l,e,a,u),!0;case"mouseover":return he=mu(he,t,l,e,a,u),!0;case"pointerover":var n=u.pointerId;return yu.set(n,mu(yu.get(n)||null,t,l,e,a,u)),!0;case"gotpointercapture":return n=u.pointerId,gu.set(n,mu(gu.get(n)||null,t,l,e,a,u)),!0}return!1}function nd(t){var l=Xe(t.target);if(l!==null){var e=Y(l);if(e!==null){if(l=e.tag,l===13){if(l=j(e),l!==null){t.blockedOn=l,wd(t.priority,function(){if(e.tag===13){var a=cl();a=Pn(a);var u=Fe(e,a);u!==null&&rl(u,e,a),ac(e,a)}});return}}else if(l===3&&e.stateNode.current.memoizedState.isDehydrated){t.blockedOn=e.tag===3?e.stateNode.containerInfo:null;return}}}t.blockedOn=null}function Xn(t){if(t.blockedOn!==null)return!1;for(var l=t.targetContainers;0<l.length;){var e=nc(t.nativeEvent);if(e===null){e=t.nativeEvent;var a=new e.constructor(e.type,e);ci=a,e.target.dispatchEvent(a),ci=null}else return l=je(e),l!==null&&ed(l),t.blockedOn=e,!1;l.shift()}return!0}function id(t,l,e){Xn(t)&&e.delete(l)}function t0(){fc=!1,oe!==null&&Xn(oe)&&(oe=null),de!==null&&Xn(de)&&(de=null),he!==null&&Xn(he)&&(he=null),yu.forEach(id),gu.forEach(id)}function jn(t,l){t.blockedOn===l&&(t.blockedOn=null,fc||(fc=!0,D.unstable_scheduleCallback(D.unstable_NormalPriority,t0)))}var Gn=null;function fd(t){Gn!==t&&(Gn=t,D.unstable_scheduleCallback(D.unstable_NormalPriority,function(){Gn===t&&(Gn=null);for(var l=0;l<t.length;l+=3){var e=t[l],a=t[l+1],u=t[l+2];if(typeof a!="function"){if(ic(a||e)===null)continue;break}var n=je(e);n!==null&&(t.splice(l,3),l-=3,nf(n,{pending:!0,data:u,method:e.method,action:a},a,u))}}))}function pu(t){function l(c){return jn(c,t)}oe!==null&&jn(oe,t),de!==null&&jn(de,t),he!==null&&jn(he,t),yu.forEach(l),gu.forEach(l);for(var e=0;e<ve.length;e++){var a=ve[e];a.blockedOn===t&&(a.blockedOn=null)}for(;0<ve.length&&(e=ve[0],e.blockedOn===null);)nd(e),e.blockedOn===null&&ve.shift();if(e=(t.ownerDocument||t).$$reactFormReplay,e!=null)for(a=0;a<e.length;a+=3){var u=e[a],n=e[a+1],i=u[$t]||null;if(typeof n=="function")i||fd(e);else if(i){var f=null;if(n&&n.hasAttribute("formAction")){if(u=n,i=n[$t]||null)f=i.formAction;else if(ic(u)!==null)continue}else f=i.action;typeof f=="function"?e[a+1]=f:(e.splice(a,3),a-=3),fd(e)}}}function cc(t){this._internalRoot=t}Qn.prototype.render=cc.prototype.render=function(t){var l=this._internalRoot;if(l===null)throw Error(h(409));var e=l.current,a=cl();td(e,a,t,l,null,null)},Qn.prototype.unmount=cc.prototype.unmount=function(){var t=this._internalRoot;if(t!==null){this._internalRoot=null;var l=t.containerInfo;td(t.current,2,null,t,null,null),Tn(),l[Ce]=null}};function Qn(t){this._internalRoot=t}Qn.prototype.unstable_scheduleHydration=function(t){if(t){var l=Dc();t={blockedOn:null,target:t,priority:l};for(var e=0;e<ve.length&&l!==0&&l<ve[e].priority;e++);ve.splice(e,0,t),e===0&&nd(t)}};var cd=K.version;if(cd!=="19.1.1")throw Error(h(527,cd,"19.1.1"));et.findDOMNode=function(t){var l=t._reactInternals;if(l===void 0)throw typeof t.render=="function"?Error(h(188)):(t=Object.keys(t).join(","),Error(h(268,t)));return t=U(l),t=t!==null?S(t):null,t=t===null?null:t.stateNode,t};var l0={bundleType:0,version:"19.1.1",rendererPackageName:"react-dom",currentDispatcherRef:C,reconcilerVersion:"19.1.1"};if(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__<"u"){var Zn=__REACT_DEVTOOLS_GLOBAL_HOOK__;if(!Zn.isDisabled&&Zn.supportsFiber)try{Ta=Zn.inject(l0),ll=Zn}catch{}}return bu.createRoot=function(t,l){if(!F(t))throw Error(h(299));var e=!1,a="",u=Ds,n=Es,i=zs,f=null;return l!=null&&(l.unstable_strictMode===!0&&(e=!0),l.identifierPrefix!==void 0&&(a=l.identifierPrefix),l.onUncaughtError!==void 0&&(u=l.onUncaughtError),l.onCaughtError!==void 0&&(n=l.onCaughtError),l.onRecoverableError!==void 0&&(i=l.onRecoverableError),l.unstable_transitionCallbacks!==void 0&&(f=l.unstable_transitionCallbacks)),l=Po(t,1,!1,null,null,e,a,u,n,i,f,null),t[Ce]=l.current,Lf(t),new cc(l)},bu.hydrateRoot=function(t,l,e){if(!F(t))throw Error(h(299));var a=!1,u="",n=Ds,i=Es,f=zs,c=null,m=null;return e!=null&&(e.unstable_strictMode===!0&&(a=!0),e.identifierPrefix!==void 0&&(u=e.identifierPrefix),e.onUncaughtError!==void 0&&(n=e.onUncaughtError),e.onCaughtError!==void 0&&(i=e.onCaughtError),e.onRecoverableError!==void 0&&(f=e.onRecoverableError),e.unstable_transitionCallbacks!==void 0&&(c=e.unstable_transitionCallbacks),e.formState!==void 0&&(m=e.formState)),l=Po(t,1,!0,l,e??null,a,u,n,i,f,c,m),l.context=Io(null),e=l.current,a=cl(),a=Pn(a),u=Fl(a),u.callback=null,Pl(e,u,a),e=a,l.current.lanes=e,Ea(l,e),Al(l),t[Ce]=l.current,Lf(t),new Qn(l)},bu.version="19.1.1",bu}var gd;function d0(){if(gd)return oc.exports;gd=1;function D(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(D)}catch(K){console.error(K)}}return D(),oc.exports=o0(),oc.exports}var O0=d0(),Ou={exports:{}},hc={},Ht={},ge={},md;function wn(){if(md)return ge;md=1,Object.defineProperty(ge,"__esModule",{value:!0}),ge.dontSetMe=F,ge.findInArray=D,ge.int=h,ge.isFunction=K,ge.isNum=Z;function D(Y,j){for(let J=0,U=Y.length;J<U;J++)if(j.apply(j,[Y[J],J,Y]))return Y[J]}function K(Y){return typeof Y=="function"||Object.prototype.toString.call(Y)==="[object Function]"}function Z(Y){return typeof Y=="number"&&!isNaN(Y)}function h(Y){return parseInt(Y,10)}function F(Y,j,J){if(Y[j])return new Error(`Invalid prop ${j} passed to ${J} - do not set this, set it on the child.`)}return ge}var me={},pd;function h0(){if(pd)return me;pd=1,Object.defineProperty(me,"__esModule",{value:!0}),me.browserPrefixToKey=Z,me.browserPrefixToStyle=h,me.default=void 0,me.getPrefix=K;const D=["Moz","Webkit","O","ms"];function K(){let Y=arguments.length>0&&arguments[0]!==void 0?arguments[0]:"transform";if(typeof window>"u")return"";const j=window.document?.documentElement?.style;if(!j||Y in j)return"";for(let J=0;J<D.length;J++)if(Z(Y,D[J])in j)return D[J];return""}function Z(Y,j){return j?`${j}${F(Y)}`:Y}function h(Y,j){return j?`-${j.toLowerCase()}-${Y}`:Y}function F(Y){let j="",J=!0;for(let U=0;U<Y.length;U++)J?(j+=Y[U].toUpperCase(),J=!1):Y[U]==="-"?J=!0:j+=Y[U];return j}return me.default=K(),me}var Sd;function yc(){if(Sd)return Ht;Sd=1,Object.defineProperty(Ht,"__esModule",{value:!0}),Ht.addClassName=v,Ht.addEvent=j,Ht.addUserSelectStyles=y,Ht.createCSSTransform=W,Ht.createSVGTransform=tt,Ht.getTouch=x,Ht.getTouchIdentifier=_,Ht.getTranslation=V,Ht.innerHeight=H,Ht.innerWidth=B,Ht.matchesSelector=F,Ht.matchesSelectorAndParentsTo=Y,Ht.offsetXYFromParent=L,Ht.outerHeight=U,Ht.outerWidth=S,Ht.removeClassName=p,Ht.removeEvent=J,Ht.scheduleRemoveUserSelectStyles=T;var D=wn(),K=Z(h0());function Z(s,z){if(typeof WeakMap=="function")var q=new WeakMap,ut=new WeakMap;return(Z=function(P,ct){if(!ct&&P&&P.__esModule)return P;var mt,Et,Tt={__proto__:null,default:P};if(P===null||typeof P!="object"&&typeof P!="function")return Tt;if(mt=ct?ut:q){if(mt.has(P))return mt.get(P);mt.set(P,Tt)}for(const C in P)C!=="default"&&{}.hasOwnProperty.call(P,C)&&((Et=(mt=Object.defineProperty)&&Object.getOwnPropertyDescriptor(P,C))&&(Et.get||Et.set)?mt(Tt,C,Et):Tt[C]=P[C]);return Tt})(s,z)}let h="";function F(s,z){return h||(h=(0,D.findInArray)(["matches","webkitMatchesSelector","mozMatchesSelector","msMatchesSelector","oMatchesSelector"],function(q){return(0,D.isFunction)(s[q])})),(0,D.isFunction)(s[h])?s[h](z):!1}function Y(s,z,q){let ut=s;do{if(F(ut,z))return!0;if(ut===q)return!1;ut=ut.parentNode}while(ut);return!1}function j(s,z,q,ut){if(!s)return;const P={capture:!0,...ut};s.addEventListener?s.addEventListener(z,q,P):s.attachEvent?s.attachEvent("on"+z,q):s["on"+z]=q}function J(s,z,q,ut){if(!s)return;const P={capture:!0,...ut};s.removeEventListener?s.removeEventListener(z,q,P):s.detachEvent?s.detachEvent("on"+z,q):s["on"+z]=null}function U(s){let z=s.clientHeight;const q=s.ownerDocument.defaultView.getComputedStyle(s);return z+=(0,D.int)(q.borderTopWidth),z+=(0,D.int)(q.borderBottomWidth),z}function S(s){let z=s.clientWidth;const q=s.ownerDocument.defaultView.getComputedStyle(s);return z+=(0,D.int)(q.borderLeftWidth),z+=(0,D.int)(q.borderRightWidth),z}function H(s){let z=s.clientHeight;const q=s.ownerDocument.defaultView.getComputedStyle(s);return z-=(0,D.int)(q.paddingTop),z-=(0,D.int)(q.paddingBottom),z}function B(s){let z=s.clientWidth;const q=s.ownerDocument.defaultView.getComputedStyle(s);return z-=(0,D.int)(q.paddingLeft),z-=(0,D.int)(q.paddingRight),z}function L(s,z,q){const P=z===z.ownerDocument.body?{left:0,top:0}:z.getBoundingClientRect(),ct=(s.clientX+z.scrollLeft-P.left)/q,mt=(s.clientY+z.scrollTop-P.top)/q;return{x:ct,y:mt}}function W(s,z){const q=V(s,z,"px");return{[(0,K.browserPrefixToKey)("transform",K.default)]:q}}function tt(s,z){return V(s,z,"")}function V(s,z,q){let{x:ut,y:P}=s,ct=`translate(${ut}${q},${P}${q})`;if(z){const mt=`${typeof z.x=="string"?z.x:z.x+q}`,Et=`${typeof z.y=="string"?z.y:z.y+q}`;ct=`translate(${mt}, ${Et})`+ct}return ct}function x(s,z){return s.targetTouches&&(0,D.findInArray)(s.targetTouches,q=>z===q.identifier)||s.changedTouches&&(0,D.findInArray)(s.changedTouches,q=>z===q.identifier)}function _(s){if(s.targetTouches&&s.targetTouches[0])return s.targetTouches[0].identifier;if(s.changedTouches&&s.changedTouches[0])return s.changedTouches[0].identifier}function y(s){if(!s)return;let z=s.getElementById("react-draggable-style-el");z||(z=s.createElement("style"),z.type="text/css",z.id="react-draggable-style-el",z.innerHTML=`.react-draggable-transparent-selection *::-moz-selection {all: inherit;}
`,z.innerHTML+=`.react-draggable-transparent-selection *::selection {all: inherit;}
`,s.getElementsByTagName("head")[0].appendChild(z)),s.body&&v(s.body,"react-draggable-transparent-selection")}function T(s){window.requestAnimationFrame?window.requestAnimationFrame(()=>{E(s)}):E(s)}function E(s){if(s)try{if(s.body&&p(s.body,"react-draggable-transparent-selection"),s.selection)s.selection.empty();else{const z=(s.defaultView||window).getSelection();z&&z.type!=="Caret"&&z.removeAllRanges()}}catch{}}function v(s,z){s.classList?s.classList.add(z):s.className.match(new RegExp(`(?:^|\\s)${z}(?!\\S)`))||(s.className+=` ${z}`)}function p(s,z){s.classList?s.classList.remove(z):s.className=s.className.replace(new RegExp(`(?:^|\\s)${z}(?!\\S)`,"g"),"")}return Ht}var Rl={},bd;function Ud(){if(bd)return Rl;bd=1,Object.defineProperty(Rl,"__esModule",{value:!0}),Rl.canDragX=F,Rl.canDragY=Y,Rl.createCoreData=J,Rl.createDraggableData=U,Rl.getBoundPosition=Z,Rl.getControlPosition=j,Rl.snapToGrid=h;var D=wn(),K=yc();function Z(B,L,W){if(!B.props.bounds)return[L,W];let{bounds:tt}=B.props;tt=typeof tt=="string"?tt:S(tt);const V=H(B);if(typeof tt=="string"){const{ownerDocument:x}=V,_=x.defaultView;let y;if(tt==="parent"?y=V.parentNode:y=V.getRootNode().querySelector(tt),!(y instanceof _.HTMLElement))throw new Error('Bounds selector "'+tt+'" could not find an element.');const T=y,E=_.getComputedStyle(V),v=_.getComputedStyle(T);tt={left:-V.offsetLeft+(0,D.int)(v.paddingLeft)+(0,D.int)(E.marginLeft),top:-V.offsetTop+(0,D.int)(v.paddingTop)+(0,D.int)(E.marginTop),right:(0,K.innerWidth)(T)-(0,K.outerWidth)(V)-V.offsetLeft+(0,D.int)(v.paddingRight)-(0,D.int)(E.marginRight),bottom:(0,K.innerHeight)(T)-(0,K.outerHeight)(V)-V.offsetTop+(0,D.int)(v.paddingBottom)-(0,D.int)(E.marginBottom)}}return(0,D.isNum)(tt.right)&&(L=Math.min(L,tt.right)),(0,D.isNum)(tt.bottom)&&(W=Math.min(W,tt.bottom)),(0,D.isNum)(tt.left)&&(L=Math.max(L,tt.left)),(0,D.isNum)(tt.top)&&(W=Math.max(W,tt.top)),[L,W]}function h(B,L,W){const tt=Math.round(L/B[0])*B[0],V=Math.round(W/B[1])*B[1];return[tt,V]}function F(B){return B.props.axis==="both"||B.props.axis==="x"}function Y(B){return B.props.axis==="both"||B.props.axis==="y"}function j(B,L,W){const tt=typeof L=="number"?(0,K.getTouch)(B,L):null;if(typeof L=="number"&&!tt)return null;const V=H(W),x=W.props.offsetParent||V.offsetParent||V.ownerDocument.body;return(0,K.offsetXYFromParent)(tt||B,x,W.props.scale)}function J(B,L,W){const tt=!(0,D.isNum)(B.lastX),V=H(B);return tt?{node:V,deltaX:0,deltaY:0,lastX:L,lastY:W,x:L,y:W}:{node:V,deltaX:L-B.lastX,deltaY:W-B.lastY,lastX:B.lastX,lastY:B.lastY,x:L,y:W}}function U(B,L){const W=B.props.scale;return{node:L.node,x:B.state.x+L.deltaX/W,y:B.state.y+L.deltaY/W,deltaX:L.deltaX/W,deltaY:L.deltaY/W,lastX:B.state.x,lastY:B.state.y}}function S(B){return{left:B.left,top:B.top,right:B.right,bottom:B.bottom}}function H(B){const L=B.findDOMNode();if(!L)throw new Error("<DraggableCore>: Unmounted during event!");return L}return Rl}var Tu={},Vn={},Od;function Nd(){if(Od)return Vn;Od=1,Object.defineProperty(Vn,"__esModule",{value:!0}),Vn.default=D;function D(){}return Vn}var Td;function v0(){if(Td)return Tu;Td=1,Object.defineProperty(Tu,"__esModule",{value:!0}),Tu.default=void 0;var D=U(pe()),K=J(Kn()),Z=J(vc()),h=yc(),F=Ud(),Y=wn(),j=J(Nd());function J(V){return V&&V.__esModule?V:{default:V}}function U(V,x){if(typeof WeakMap=="function")var _=new WeakMap,y=new WeakMap;return(U=function(T,E){if(!E&&T&&T.__esModule)return T;var v,p,s={__proto__:null,default:T};if(T===null||typeof T!="object"&&typeof T!="function")return s;if(v=E?y:_){if(v.has(T))return v.get(T);v.set(T,s)}for(const z in T)z!=="default"&&{}.hasOwnProperty.call(T,z)&&((p=(v=Object.defineProperty)&&Object.getOwnPropertyDescriptor(T,z))&&(p.get||p.set)?v(s,z,p):s[z]=T[z]);return s})(V,x)}function S(V,x,_){return(x=H(x))in V?Object.defineProperty(V,x,{value:_,enumerable:!0,configurable:!0,writable:!0}):V[x]=_,V}function H(V){var x=B(V,"string");return typeof x=="symbol"?x:x+""}function B(V,x){if(typeof V!="object"||!V)return V;var _=V[Symbol.toPrimitive];if(_!==void 0){var y=_.call(V,x);if(typeof y!="object")return y;throw new TypeError("@@toPrimitive must return a primitive value.")}return(x==="string"?String:Number)(V)}const L={touch:{start:"touchstart",move:"touchmove",stop:"touchend"},mouse:{start:"mousedown",move:"mousemove",stop:"mouseup"}};let W=L.mouse,tt=class extends D.Component{constructor(){super(...arguments),S(this,"dragging",!1),S(this,"lastX",NaN),S(this,"lastY",NaN),S(this,"touchIdentifier",null),S(this,"mounted",!1),S(this,"handleDragStart",x=>{if(this.props.onMouseDown(x),!this.props.allowAnyClick&&typeof x.button=="number"&&x.button!==0)return!1;const _=this.findDOMNode();if(!_||!_.ownerDocument||!_.ownerDocument.body)throw new Error("<DraggableCore> not mounted on DragStart!");const{ownerDocument:y}=_;if(this.props.disabled||!(x.target instanceof y.defaultView.Node)||this.props.handle&&!(0,h.matchesSelectorAndParentsTo)(x.target,this.props.handle,_)||this.props.cancel&&(0,h.matchesSelectorAndParentsTo)(x.target,this.props.cancel,_))return;x.type==="touchstart"&&!this.props.allowMobileScroll&&x.preventDefault();const T=(0,h.getTouchIdentifier)(x);this.touchIdentifier=T;const E=(0,F.getControlPosition)(x,T,this);if(E==null)return;const{x:v,y:p}=E,s=(0,F.createCoreData)(this,v,p);(0,j.default)("DraggableCore: handleDragStart: %j",s),(0,j.default)("calling",this.props.onStart),!(this.props.onStart(x,s)===!1||this.mounted===!1)&&(this.props.enableUserSelectHack&&(0,h.addUserSelectStyles)(y),this.dragging=!0,this.lastX=v,this.lastY=p,(0,h.addEvent)(y,W.move,this.handleDrag),(0,h.addEvent)(y,W.stop,this.handleDragStop))}),S(this,"handleDrag",x=>{const _=(0,F.getControlPosition)(x,this.touchIdentifier,this);if(_==null)return;let{x:y,y:T}=_;if(Array.isArray(this.props.grid)){let p=y-this.lastX,s=T-this.lastY;if([p,s]=(0,F.snapToGrid)(this.props.grid,p,s),!p&&!s)return;y=this.lastX+p,T=this.lastY+s}const E=(0,F.createCoreData)(this,y,T);if((0,j.default)("DraggableCore: handleDrag: %j",E),this.props.onDrag(x,E)===!1||this.mounted===!1){try{this.handleDragStop(new MouseEvent("mouseup"))}catch{const s=document.createEvent("MouseEvents");s.initMouseEvent("mouseup",!0,!0,window,0,0,0,0,0,!1,!1,!1,!1,0,null),this.handleDragStop(s)}return}this.lastX=y,this.lastY=T}),S(this,"handleDragStop",x=>{if(!this.dragging)return;const _=(0,F.getControlPosition)(x,this.touchIdentifier,this);if(_==null)return;let{x:y,y:T}=_;if(Array.isArray(this.props.grid)){let s=y-this.lastX||0,z=T-this.lastY||0;[s,z]=(0,F.snapToGrid)(this.props.grid,s,z),y=this.lastX+s,T=this.lastY+z}const E=(0,F.createCoreData)(this,y,T);if(this.props.onStop(x,E)===!1||this.mounted===!1)return!1;const p=this.findDOMNode();p&&this.props.enableUserSelectHack&&(0,h.scheduleRemoveUserSelectStyles)(p.ownerDocument),(0,j.default)("DraggableCore: handleDragStop: %j",E),this.dragging=!1,this.lastX=NaN,this.lastY=NaN,p&&((0,j.default)("DraggableCore: Removing handlers"),(0,h.removeEvent)(p.ownerDocument,W.move,this.handleDrag),(0,h.removeEvent)(p.ownerDocument,W.stop,this.handleDragStop))}),S(this,"onMouseDown",x=>(W=L.mouse,this.handleDragStart(x))),S(this,"onMouseUp",x=>(W=L.mouse,this.handleDragStop(x))),S(this,"onTouchStart",x=>(W=L.touch,this.handleDragStart(x))),S(this,"onTouchEnd",x=>(W=L.touch,this.handleDragStop(x)))}componentDidMount(){this.mounted=!0;const x=this.findDOMNode();x&&(0,h.addEvent)(x,L.touch.start,this.onTouchStart,{passive:!1})}componentWillUnmount(){this.mounted=!1;const x=this.findDOMNode();if(x){const{ownerDocument:_}=x;(0,h.removeEvent)(_,L.mouse.move,this.handleDrag),(0,h.removeEvent)(_,L.touch.move,this.handleDrag),(0,h.removeEvent)(_,L.mouse.stop,this.handleDragStop),(0,h.removeEvent)(_,L.touch.stop,this.handleDragStop),(0,h.removeEvent)(x,L.touch.start,this.onTouchStart,{passive:!1}),this.props.enableUserSelectHack&&(0,h.scheduleRemoveUserSelectStyles)(_)}}findDOMNode(){return this.props?.nodeRef?this.props?.nodeRef?.current:Z.default.findDOMNode(this)}render(){return D.cloneElement(D.Children.only(this.props.children),{onMouseDown:this.onMouseDown,onMouseUp:this.onMouseUp,onTouchEnd:this.onTouchEnd})}};return Tu.default=tt,S(tt,"displayName","DraggableCore"),S(tt,"propTypes",{allowAnyClick:K.default.bool,allowMobileScroll:K.default.bool,children:K.default.node.isRequired,disabled:K.default.bool,enableUserSelectHack:K.default.bool,offsetParent:function(V,x){if(V[x]&&V[x].nodeType!==1)throw new Error("Draggable's offsetParent must be a DOM Node.")},grid:K.default.arrayOf(K.default.number),handle:K.default.string,cancel:K.default.string,nodeRef:K.default.object,onStart:K.default.func,onDrag:K.default.func,onStop:K.default.func,onMouseDown:K.default.func,scale:K.default.number,className:Y.dontSetMe,style:Y.dontSetMe,transform:Y.dontSetMe}),S(tt,"defaultProps",{allowAnyClick:!1,allowMobileScroll:!1,disabled:!1,enableUserSelectHack:!0,onStart:function(){},onDrag:function(){},onStop:function(){},onMouseDown:function(){},scale:1}),Tu}var Dd;function y0(){return Dd||(Dd=1,(function(D){Object.defineProperty(D,"__esModule",{value:!0}),Object.defineProperty(D,"DraggableCore",{enumerable:!0,get:function(){return U.default}}),D.default=void 0;var K=B(pe()),Z=H(Kn()),h=H(vc()),F=n0(),Y=yc(),j=Ud(),J=wn(),U=H(v0()),S=H(Nd());function H(_){return _&&_.__esModule?_:{default:_}}function B(_,y){if(typeof WeakMap=="function")var T=new WeakMap,E=new WeakMap;return(B=function(v,p){if(!p&&v&&v.__esModule)return v;var s,z,q={__proto__:null,default:v};if(v===null||typeof v!="object"&&typeof v!="function")return q;if(s=p?E:T){if(s.has(v))return s.get(v);s.set(v,q)}for(const ut in v)ut!=="default"&&{}.hasOwnProperty.call(v,ut)&&((z=(s=Object.defineProperty)&&Object.getOwnPropertyDescriptor(v,ut))&&(z.get||z.set)?s(q,ut,z):q[ut]=v[ut]);return q})(_,y)}function L(){return L=Object.assign?Object.assign.bind():function(_){for(var y=1;y<arguments.length;y++){var T=arguments[y];for(var E in T)({}).hasOwnProperty.call(T,E)&&(_[E]=T[E])}return _},L.apply(null,arguments)}function W(_,y,T){return(y=tt(y))in _?Object.defineProperty(_,y,{value:T,enumerable:!0,configurable:!0,writable:!0}):_[y]=T,_}function tt(_){var y=V(_,"string");return typeof y=="symbol"?y:y+""}function V(_,y){if(typeof _!="object"||!_)return _;var T=_[Symbol.toPrimitive];if(T!==void 0){var E=T.call(_,y);if(typeof E!="object")return E;throw new TypeError("@@toPrimitive must return a primitive value.")}return(y==="string"?String:Number)(_)}class x extends K.Component{static getDerivedStateFromProps(y,T){let{position:E}=y,{prevPropsPosition:v}=T;return E&&(!v||E.x!==v.x||E.y!==v.y)?((0,S.default)("Draggable: getDerivedStateFromProps %j",{position:E,prevPropsPosition:v}),{x:E.x,y:E.y,prevPropsPosition:{...E}}):null}constructor(y){super(y),W(this,"onDragStart",(T,E)=>{if((0,S.default)("Draggable: onDragStart: %j",E),this.props.onStart(T,(0,j.createDraggableData)(this,E))===!1)return!1;this.setState({dragging:!0,dragged:!0})}),W(this,"onDrag",(T,E)=>{if(!this.state.dragging)return!1;(0,S.default)("Draggable: onDrag: %j",E);const v=(0,j.createDraggableData)(this,E),p={x:v.x,y:v.y,slackX:0,slackY:0};if(this.props.bounds){const{x:z,y:q}=p;p.x+=this.state.slackX,p.y+=this.state.slackY;const[ut,P]=(0,j.getBoundPosition)(this,p.x,p.y);p.x=ut,p.y=P,p.slackX=this.state.slackX+(z-p.x),p.slackY=this.state.slackY+(q-p.y),v.x=p.x,v.y=p.y,v.deltaX=p.x-this.state.x,v.deltaY=p.y-this.state.y}if(this.props.onDrag(T,v)===!1)return!1;this.setState(p)}),W(this,"onDragStop",(T,E)=>{if(!this.state.dragging||this.props.onStop(T,(0,j.createDraggableData)(this,E))===!1)return!1;(0,S.default)("Draggable: onDragStop: %j",E);const p={dragging:!1,slackX:0,slackY:0};if(!!this.props.position){const{x:z,y:q}=this.props.position;p.x=z,p.y=q}this.setState(p)}),this.state={dragging:!1,dragged:!1,x:y.position?y.position.x:y.defaultPosition.x,y:y.position?y.position.y:y.defaultPosition.y,prevPropsPosition:{...y.position},slackX:0,slackY:0,isElementSVG:!1},y.position&&!(y.onDrag||y.onStop)&&console.warn("A `position` was applied to this <Draggable>, without drag handlers. This will make this component effectively undraggable. Please attach `onDrag` or `onStop` handlers so you can adjust the `position` of this element.")}componentDidMount(){typeof window.SVGElement<"u"&&this.findDOMNode()instanceof window.SVGElement&&this.setState({isElementSVG:!0})}componentWillUnmount(){this.state.dragging&&this.setState({dragging:!1})}findDOMNode(){return this.props?.nodeRef?.current??h.default.findDOMNode(this)}render(){const{axis:y,bounds:T,children:E,defaultPosition:v,defaultClassName:p,defaultClassNameDragging:s,defaultClassNameDragged:z,position:q,positionOffset:ut,scale:P,...ct}=this.props;let mt={},Et=null;const C=!!!q||this.state.dragging,et=q||v,xt={x:(0,j.canDragX)(this)&&C?this.state.x:et.x,y:(0,j.canDragY)(this)&&C?this.state.y:et.y};this.state.isElementSVG?Et=(0,Y.createSVGTransform)(xt,ut):mt=(0,Y.createCSSTransform)(xt,ut);const Sl=(0,F.clsx)(E.props.className||"",p,{[s]:this.state.dragging,[z]:this.state.dragged});return K.createElement(U.default,L({},ct,{onStart:this.onDragStart,onDrag:this.onDrag,onStop:this.onDragStop}),K.cloneElement(K.Children.only(E),{className:Sl,style:{...E.props.style,...mt},transform:Et}))}}D.default=x,W(x,"displayName","Draggable"),W(x,"propTypes",{...U.default.propTypes,axis:Z.default.oneOf(["both","x","y","none"]),bounds:Z.default.oneOfType([Z.default.shape({left:Z.default.number,right:Z.default.number,top:Z.default.number,bottom:Z.default.number}),Z.default.string,Z.default.oneOf([!1])]),defaultClassName:Z.default.string,defaultClassNameDragging:Z.default.string,defaultClassNameDragged:Z.default.string,defaultPosition:Z.default.shape({x:Z.default.number,y:Z.default.number}),positionOffset:Z.default.shape({x:Z.default.oneOfType([Z.default.number,Z.default.string]),y:Z.default.oneOfType([Z.default.number,Z.default.string])}),position:Z.default.shape({x:Z.default.number,y:Z.default.number}),className:J.dontSetMe,style:J.dontSetMe,transform:J.dontSetMe}),W(x,"defaultProps",{...U.default.defaultProps,axis:"both",bounds:!1,defaultClassName:"react-draggable",defaultClassNameDragging:"react-draggable-dragging",defaultClassNameDragged:"react-draggable-dragged",defaultPosition:{x:0,y:0},scale:1})})(hc)),hc}var Ed;function Hd(){if(Ed)return Ou.exports;Ed=1;const{default:D,DraggableCore:K}=y0();return Ou.exports=D,Ou.exports.default=D,Ou.exports.DraggableCore=K,Ou.exports}var Du={exports:{}},Eu={},Ln={},zd;function g0(){if(zd)return Ln;zd=1,Ln.__esModule=!0,Ln.cloneElement=J;var D=K(pe());function K(U){return U&&U.__esModule?U:{default:U}}function Z(U,S){var H=Object.keys(U);if(Object.getOwnPropertySymbols){var B=Object.getOwnPropertySymbols(U);S&&(B=B.filter(function(L){return Object.getOwnPropertyDescriptor(U,L).enumerable})),H.push.apply(H,B)}return H}function h(U){for(var S=1;S<arguments.length;S++){var H=arguments[S]!=null?arguments[S]:{};S%2?Z(Object(H),!0).forEach(function(B){F(U,B,H[B])}):Object.getOwnPropertyDescriptors?Object.defineProperties(U,Object.getOwnPropertyDescriptors(H)):Z(Object(H)).forEach(function(B){Object.defineProperty(U,B,Object.getOwnPropertyDescriptor(H,B))})}return U}function F(U,S,H){return S=Y(S),S in U?Object.defineProperty(U,S,{value:H,enumerable:!0,configurable:!0,writable:!0}):U[S]=H,U}function Y(U){var S=j(U,"string");return typeof S=="symbol"?S:String(S)}function j(U,S){if(typeof U!="object"||U===null)return U;var H=U[Symbol.toPrimitive];if(H!==void 0){var B=H.call(U,S);if(typeof B!="object")return B;throw new TypeError("@@toPrimitive must return a primitive value.")}return(S==="string"?String:Number)(U)}function J(U,S){return S.style&&U.props.style&&(S.style=h(h({},U.props.style),S.style)),S.className&&U.props.className&&(S.className=U.props.className+" "+S.className),D.default.cloneElement(U,S)}return Ln}var zu={},_d;function xd(){if(_d)return zu;_d=1,zu.__esModule=!0,zu.resizableProps=void 0;var D=K(Kn());Hd();function K(h){return h&&h.__esModule?h:{default:h}}var Z={axis:D.default.oneOf(["both","x","y","none"]),className:D.default.string,children:D.default.element.isRequired,draggableOpts:D.default.shape({allowAnyClick:D.default.bool,cancel:D.default.string,children:D.default.node,disabled:D.default.bool,enableUserSelectHack:D.default.bool,offsetParent:D.default.node,grid:D.default.arrayOf(D.default.number),handle:D.default.string,nodeRef:D.default.object,onStart:D.default.func,onDrag:D.default.func,onStop:D.default.func,onMouseDown:D.default.func,scale:D.default.number}),height:function(){for(var F=arguments.length,Y=new Array(F),j=0;j<F;j++)Y[j]=arguments[j];var J=Y[0];if(J.axis==="both"||J.axis==="y"){var U;return(U=D.default.number).isRequired.apply(U,Y)}return D.default.number.apply(D.default,Y)},handle:D.default.oneOfType([D.default.node,D.default.func]),handleSize:D.default.arrayOf(D.default.number),lockAspectRatio:D.default.bool,maxConstraints:D.default.arrayOf(D.default.number),minConstraints:D.default.arrayOf(D.default.number),onResizeStop:D.default.func,onResizeStart:D.default.func,onResize:D.default.func,resizeHandles:D.default.arrayOf(D.default.oneOf(["s","w","e","n","sw","nw","se","ne"])),transformScale:D.default.number,width:function(){for(var F=arguments.length,Y=new Array(F),j=0;j<F;j++)Y[j]=arguments[j];var J=Y[0];if(J.axis==="both"||J.axis==="x"){var U;return(U=D.default.number).isRequired.apply(U,Y)}return D.default.number.apply(D.default,Y)}};return zu.resizableProps=Z,zu}var Md;function qd(){if(Md)return Eu;Md=1,Eu.__esModule=!0,Eu.default=void 0;var D=j(pe()),K=Hd(),Z=g0(),h=xd(),F=["children","className","draggableOpts","width","height","handle","handleSize","lockAspectRatio","axis","minConstraints","maxConstraints","onResize","onResizeStop","onResizeStart","resizeHandles","transformScale"];function Y(_){if(typeof WeakMap!="function")return null;var y=new WeakMap,T=new WeakMap;return(Y=function(v){return v?T:y})(_)}function j(_,y){if(_&&_.__esModule)return _;if(_===null||typeof _!="object"&&typeof _!="function")return{default:_};var T=Y(y);if(T&&T.has(_))return T.get(_);var E={},v=Object.defineProperty&&Object.getOwnPropertyDescriptor;for(var p in _)if(p!=="default"&&Object.prototype.hasOwnProperty.call(_,p)){var s=v?Object.getOwnPropertyDescriptor(_,p):null;s&&(s.get||s.set)?Object.defineProperty(E,p,s):E[p]=_[p]}return E.default=_,T&&T.set(_,E),E}function J(){return J=Object.assign?Object.assign.bind():function(_){for(var y=1;y<arguments.length;y++){var T=arguments[y];for(var E in T)Object.prototype.hasOwnProperty.call(T,E)&&(_[E]=T[E])}return _},J.apply(this,arguments)}function U(_,y){if(_==null)return{};var T={},E=Object.keys(_),v,p;for(p=0;p<E.length;p++)v=E[p],!(y.indexOf(v)>=0)&&(T[v]=_[v]);return T}function S(_,y){var T=Object.keys(_);if(Object.getOwnPropertySymbols){var E=Object.getOwnPropertySymbols(_);y&&(E=E.filter(function(v){return Object.getOwnPropertyDescriptor(_,v).enumerable})),T.push.apply(T,E)}return T}function H(_){for(var y=1;y<arguments.length;y++){var T=arguments[y]!=null?arguments[y]:{};y%2?S(Object(T),!0).forEach(function(E){B(_,E,T[E])}):Object.getOwnPropertyDescriptors?Object.defineProperties(_,Object.getOwnPropertyDescriptors(T)):S(Object(T)).forEach(function(E){Object.defineProperty(_,E,Object.getOwnPropertyDescriptor(T,E))})}return _}function B(_,y,T){return y=L(y),y in _?Object.defineProperty(_,y,{value:T,enumerable:!0,configurable:!0,writable:!0}):_[y]=T,_}function L(_){var y=W(_,"string");return typeof y=="symbol"?y:String(y)}function W(_,y){if(typeof _!="object"||_===null)return _;var T=_[Symbol.toPrimitive];if(T!==void 0){var E=T.call(_,y);if(typeof E!="object")return E;throw new TypeError("@@toPrimitive must return a primitive value.")}return(y==="string"?String:Number)(_)}function tt(_,y){_.prototype=Object.create(y.prototype),_.prototype.constructor=_,V(_,y)}function V(_,y){return V=Object.setPrototypeOf?Object.setPrototypeOf.bind():function(E,v){return E.__proto__=v,E},V(_,y)}var x=(function(_){tt(y,_);function y(){for(var E,v=arguments.length,p=new Array(v),s=0;s<v;s++)p[s]=arguments[s];return E=_.call.apply(_,[this].concat(p))||this,E.handleRefs={},E.lastHandleRect=null,E.slack=null,E}var T=y.prototype;return T.componentWillUnmount=function(){this.resetData()},T.resetData=function(){this.lastHandleRect=this.slack=null},T.runConstraints=function(v,p){var s=this.props,z=s.minConstraints,q=s.maxConstraints,ut=s.lockAspectRatio;if(!z&&!q&&!ut)return[v,p];if(ut){var P=this.props.width/this.props.height,ct=v-this.props.width,mt=p-this.props.height;Math.abs(ct)>Math.abs(mt*P)?p=v/P:v=p*P}var Et=v,Tt=p,C=this.slack||[0,0],et=C[0],xt=C[1];return v+=et,p+=xt,z&&(v=Math.max(z[0],v),p=Math.max(z[1],p)),q&&(v=Math.min(q[0],v),p=Math.min(q[1],p)),this.slack=[et+(Et-v),xt+(Tt-p)],[v,p]},T.resizeHandler=function(v,p){var s=this;return function(z,q){var ut=q.node,P=q.deltaX,ct=q.deltaY;v==="onResizeStart"&&s.resetData();var mt=(s.props.axis==="both"||s.props.axis==="x")&&p!=="n"&&p!=="s",Et=(s.props.axis==="both"||s.props.axis==="y")&&p!=="e"&&p!=="w";if(!(!mt&&!Et)){var Tt=p[0],C=p[p.length-1],et=ut.getBoundingClientRect();if(s.lastHandleRect!=null){if(C==="w"){var xt=et.left-s.lastHandleRect.left;P+=xt}if(Tt==="n"){var Sl=et.top-s.lastHandleRect.top;ct+=Sl}}s.lastHandleRect=et,C==="w"&&(P=-P),Tt==="n"&&(ct=-ct);var o=s.props.width+(mt?P/s.props.transformScale:0),N=s.props.height+(Et?ct/s.props.transformScale:0),G=s.runConstraints(o,N);o=G[0],N=G[1];var X=o!==s.props.width||N!==s.props.height,lt=typeof s.props[v]=="function"?s.props[v]:null,vt=v==="onResize"&&!X;lt&&!vt&&(z.persist==null||z.persist(),lt(z,{node:ut,size:{width:o,height:N},handle:p})),v==="onResizeStop"&&s.resetData()}}},T.renderResizeHandle=function(v,p){var s=this.props.handle;if(!s)return D.createElement("span",{className:"react-resizable-handle react-resizable-handle-"+v,ref:p});if(typeof s=="function")return s(v,p);var z=typeof s.type=="string",q=H({ref:p},z?{}:{handleAxis:v});return D.cloneElement(s,q)},T.render=function(){var v=this,p=this.props,s=p.children,z=p.className,q=p.draggableOpts;p.width,p.height,p.handle,p.handleSize,p.lockAspectRatio,p.axis,p.minConstraints,p.maxConstraints,p.onResize,p.onResizeStop,p.onResizeStart;var ut=p.resizeHandles;p.transformScale;var P=U(p,F);return(0,Z.cloneElement)(s,H(H({},P),{},{className:(z?z+" ":"")+"react-resizable",children:[].concat(s.props.children,ut.map(function(ct){var mt,Et=(mt=v.handleRefs[ct])!=null?mt:v.handleRefs[ct]=D.createRef();return D.createElement(K.DraggableCore,J({},q,{nodeRef:Et,key:"resizableHandle-"+ct,onStop:v.resizeHandler("onResizeStop",ct),onStart:v.resizeHandler("onResizeStart",ct),onDrag:v.resizeHandler("onResize",ct)}),v.renderResizeHandle(ct,Et))}))}))},y})(D.Component);return Eu.default=x,x.propTypes=h.resizableProps,x.defaultProps={axis:"both",handleSize:[20,20],lockAspectRatio:!1,minConstraints:[20,20],maxConstraints:[1/0,1/0],resizeHandles:["se"],transformScale:1},Eu}var _u={},Ad;function m0(){if(Ad)return _u;Ad=1,_u.__esModule=!0,_u.default=void 0;var D=J(pe()),K=Y(Kn()),Z=Y(qd()),h=xd(),F=["handle","handleSize","onResize","onResizeStart","onResizeStop","draggableOpts","minConstraints","maxConstraints","lockAspectRatio","axis","width","height","resizeHandles","style","transformScale"];function Y(y){return y&&y.__esModule?y:{default:y}}function j(y){if(typeof WeakMap!="function")return null;var T=new WeakMap,E=new WeakMap;return(j=function(p){return p?E:T})(y)}function J(y,T){if(y&&y.__esModule)return y;if(y===null||typeof y!="object"&&typeof y!="function")return{default:y};var E=j(T);if(E&&E.has(y))return E.get(y);var v={},p=Object.defineProperty&&Object.getOwnPropertyDescriptor;for(var s in y)if(s!=="default"&&Object.prototype.hasOwnProperty.call(y,s)){var z=p?Object.getOwnPropertyDescriptor(y,s):null;z&&(z.get||z.set)?Object.defineProperty(v,s,z):v[s]=y[s]}return v.default=y,E&&E.set(y,v),v}function U(){return U=Object.assign?Object.assign.bind():function(y){for(var T=1;T<arguments.length;T++){var E=arguments[T];for(var v in E)Object.prototype.hasOwnProperty.call(E,v)&&(y[v]=E[v])}return y},U.apply(this,arguments)}function S(y,T){var E=Object.keys(y);if(Object.getOwnPropertySymbols){var v=Object.getOwnPropertySymbols(y);T&&(v=v.filter(function(p){return Object.getOwnPropertyDescriptor(y,p).enumerable})),E.push.apply(E,v)}return E}function H(y){for(var T=1;T<arguments.length;T++){var E=arguments[T]!=null?arguments[T]:{};T%2?S(Object(E),!0).forEach(function(v){B(y,v,E[v])}):Object.getOwnPropertyDescriptors?Object.defineProperties(y,Object.getOwnPropertyDescriptors(E)):S(Object(E)).forEach(function(v){Object.defineProperty(y,v,Object.getOwnPropertyDescriptor(E,v))})}return y}function B(y,T,E){return T=L(T),T in y?Object.defineProperty(y,T,{value:E,enumerable:!0,configurable:!0,writable:!0}):y[T]=E,y}function L(y){var T=W(y,"string");return typeof T=="symbol"?T:String(T)}function W(y,T){if(typeof y!="object"||y===null)return y;var E=y[Symbol.toPrimitive];if(E!==void 0){var v=E.call(y,T);if(typeof v!="object")return v;throw new TypeError("@@toPrimitive must return a primitive value.")}return(T==="string"?String:Number)(y)}function tt(y,T){if(y==null)return{};var E={},v=Object.keys(y),p,s;for(s=0;s<v.length;s++)p=v[s],!(T.indexOf(p)>=0)&&(E[p]=y[p]);return E}function V(y,T){y.prototype=Object.create(T.prototype),y.prototype.constructor=y,x(y,T)}function x(y,T){return x=Object.setPrototypeOf?Object.setPrototypeOf.bind():function(v,p){return v.__proto__=p,v},x(y,T)}var _=(function(y){V(T,y);function T(){for(var v,p=arguments.length,s=new Array(p),z=0;z<p;z++)s[z]=arguments[z];return v=y.call.apply(y,[this].concat(s))||this,v.state={width:v.props.width,height:v.props.height,propsWidth:v.props.width,propsHeight:v.props.height},v.onResize=function(q,ut){var P=ut.size;v.props.onResize?(q.persist==null||q.persist(),v.setState(P,function(){return v.props.onResize&&v.props.onResize(q,ut)})):v.setState(P)},v}T.getDerivedStateFromProps=function(p,s){return s.propsWidth!==p.width||s.propsHeight!==p.height?{width:p.width,height:p.height,propsWidth:p.width,propsHeight:p.height}:null};var E=T.prototype;return E.render=function(){var p=this.props,s=p.handle,z=p.handleSize;p.onResize;var q=p.onResizeStart,ut=p.onResizeStop,P=p.draggableOpts,ct=p.minConstraints,mt=p.maxConstraints,Et=p.lockAspectRatio,Tt=p.axis;p.width,p.height;var C=p.resizeHandles,et=p.style,xt=p.transformScale,Sl=tt(p,F);return D.createElement(Z.default,{axis:Tt,draggableOpts:P,handle:s,handleSize:z,height:this.state.height,lockAspectRatio:Et,maxConstraints:mt,minConstraints:ct,onResizeStart:q,onResize:this.onResize,onResizeStop:ut,resizeHandles:C,transformScale:xt,width:this.state.width},D.createElement("div",U({},Sl,{style:H(H({},et),{},{width:this.state.width+"px",height:this.state.height+"px"})})))},T})(D.Component);return _u.default=_,_.propTypes=H(H({},h.resizableProps),{},{children:K.default.element}),_u}var Rd;function D0(){return Rd||(Rd=1,Du.exports=function(){throw new Error("Don't instantiate Resizable directly! Use require('react-resizable').Resizable")},Du.exports.Resizable=qd().default,Du.exports.ResizableBox=m0().default),Du.exports}export{b0 as R,pe as a,vc as b,Hd as c,D0 as d,O0 as e,S0 as j,r0 as r};
